Class: Aws::WAFV2::Types::APIKeySummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Information for a single API key.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#api_keyString

The generated, encrypted API key. You can copy this for use in your JavaScript CAPTCHA integration.

For information about how to use this in your CAPTCHA JavaScript integration, see [WAF client application integration] in the *WAF Developer Guide*.

[1]: docs.aws.amazon.com/waf/latest/developerguide/waf-application-integration.html

Returns:

  • (String)


42
43
44
45
46
47
48
49
# File 'lib/aws-sdk-wafv2/types.rb', line 42

class APIKeySummary < Struct.new(
  :token_domains,
  :api_key,
  :creation_timestamp,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timestampTime

The date and time that the key was created.

Returns:

  • (Time)


42
43
44
45
46
47
48
49
# File 'lib/aws-sdk-wafv2/types.rb', line 42

class APIKeySummary < Struct.new(
  :token_domains,
  :api_key,
  :creation_timestamp,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#token_domainsArray<String>

The token domains that are defined in this API key.

Returns:

  • (Array<String>)


42
43
44
45
46
47
48
49
# File 'lib/aws-sdk-wafv2/types.rb', line 42

class APIKeySummary < Struct.new(
  :token_domains,
  :api_key,
  :creation_timestamp,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#versionInteger

Internal value used by WAF to manage the key.

Returns:

  • (Integer)


42
43
44
45
46
47
48
49
# File 'lib/aws-sdk-wafv2/types.rb', line 42

class APIKeySummary < Struct.new(
  :token_domains,
  :api_key,
  :creation_timestamp,
  :version)
  SENSITIVE = []
  include Aws::Structure
end