Class: Aws::WAFV2::Types::AWSManagedRulesATPRuleSet

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Details for your use of the account takeover prevention managed rule group, ‘AWSManagedRulesATPRuleSet`. This configuration is used in `ManagedRuleGroupConfig`.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enable_regex_in_pathBoolean

Allow the use of regular expressions in the login page path.

Returns:

  • (Boolean)


161
162
163
164
165
166
167
168
# File 'lib/aws-sdk-wafv2/types.rb', line 161

class AWSManagedRulesATPRuleSet < Struct.new(
  :login_path,
  :request_inspection,
  :response_inspection,
  :enable_regex_in_path)
  SENSITIVE = []
  include Aws::Structure
end

#login_pathString

The path of the login endpoint for your application. For example, for the URL ‘example.com/web/login`, you would provide the path `/web/login`.

The rule group inspects only HTTP ‘POST` requests to your specified login endpoint.

Returns:

  • (String)


161
162
163
164
165
166
167
168
# File 'lib/aws-sdk-wafv2/types.rb', line 161

class AWSManagedRulesATPRuleSet < Struct.new(
  :login_path,
  :request_inspection,
  :response_inspection,
  :enable_regex_in_path)
  SENSITIVE = []
  include Aws::Structure
end

#request_inspectionTypes::RequestInspection

The criteria for inspecting login requests, used by the ATP rule group to validate credentials usage.



161
162
163
164
165
166
167
168
# File 'lib/aws-sdk-wafv2/types.rb', line 161

class AWSManagedRulesATPRuleSet < Struct.new(
  :login_path,
  :request_inspection,
  :response_inspection,
  :enable_regex_in_path)
  SENSITIVE = []
  include Aws::Structure
end

#response_inspectionTypes::ResponseInspection

The criteria for inspecting responses to login requests, used by the ATP rule group to track login failure rates.

<note markdown=“1”> Response inspection is available only in web ACLs that protect Amazon CloudFront distributions.

</note>

The ATP rule group evaluates the responses that your protected resources send back to client login attempts, keeping count of successful and failed attempts for each IP address and client session. Using this information, the rule group labels and mitigates requests from client sessions and IP addresses that have had too many failed login attempts in a short amount of time.



161
162
163
164
165
166
167
168
# File 'lib/aws-sdk-wafv2/types.rb', line 161

class AWSManagedRulesATPRuleSet < Struct.new(
  :login_path,
  :request_inspection,
  :response_inspection,
  :enable_regex_in_path)
  SENSITIVE = []
  include Aws::Structure
end