Class: Aws::WAFV2::Types::ActionCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ActionCondition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
A single action condition for a Condition in a logging filter.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action setting that a log record must contain in order to meet the condition.
Instance Attribute Details
#action ⇒ String
The action setting that a log record must contain in order to meet the condition. This is the action that WAF applied to the web request.
For rule groups, this is either the configured rule action setting, or if you’ve applied a rule action override to the rule, it’s the override action. The value ‘EXCLUDED_AS_COUNT` matches on excluded rules and also on rules that have a rule action override of Count.
97 98 99 100 101 |
# File 'lib/aws-sdk-wafv2/types.rb', line 97 class ActionCondition < Struct.new( :action) SENSITIVE = [] include Aws::Structure end |