Class: Aws::WAFV2::Types::All Private

Inherits:
EmptyStructure
  • Object
show all
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.

Inspect all of the elements that WAF has parsed and extracted from the web request JSON body that are within the JsonBody `MatchScope`. This is used with the FieldToMatch option `JsonBody`.

This is used only to indicate the web request component for WAF to inspect, in the FieldToMatch specification.

JSON specification: `“All”: {}`