Class: Aws::WAFV2::Types::AssociateWebACLRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::AssociateWebACLRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the resource to associate with the web ACL.
-
#web_acl_arn ⇒ String
The Amazon Resource Name (ARN) of the web ACL that you want to associate with the resource.
Instance Attribute Details
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the resource to associate with the web ACL.
The ARN must be in one of the following formats:
-
For an Application Load Balancer:
arn:partition:elasticloadbalancing:region:account-id:loadbalancer/app/load-balancer-name/load-balancer-id -
For an Amazon API Gateway REST API:
arn:partition:apigateway:region::/restapis/api-id/stages/stage-name -
For an AppSync GraphQL API:
arn:partition:appsync:region:account-id:apis/GraphQLApiId -
For an Amazon Cognito user pool:
arn:partition:cognito-idp:region:account-id:userpool/user-pool-id -
For an App Runner service:
arn:partition:apprunner:region:account-id:service/apprunner-service-name/apprunner-service-id -
For an Amazon Web Services Verified Access instance:
arn:partition:ec2:region:account-id:verified-access-instance/instance-id -
For an Amplify application:
arn:partition:amplify:region:account-id:apps/app-id -
For an Amazon Bedrock AgentCore Gateway:
arn:partition:bedrock-agentcore:region:account-id:gateway/gateway-id
564 565 566 567 568 569 |
# File 'lib/aws-sdk-wafv2/types.rb', line 564 class AssociateWebACLRequest < Struct.new( :web_acl_arn, :resource_arn) SENSITIVE = [] include Aws::Structure end |
#web_acl_arn ⇒ String
The Amazon Resource Name (ARN) of the web ACL that you want to associate with the resource.
564 565 566 567 568 569 |
# File 'lib/aws-sdk-wafv2/types.rb', line 564 class AssociateWebACLRequest < Struct.new( :web_acl_arn, :resource_arn) SENSITIVE = [] include Aws::Structure end |