Class: Aws::WAFV2::Types::AssociationConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Specifies custom configurations for the associations between the web ACL and protected resources.

Use this to customize the maximum size of the request body that your protected CloudFront distributions forward to WAF for inspection. The default is 16 KB (16,384 bytes).

<note markdown=“1”> You are charged additional fees when your protected resources forward body sizes that are larger than the default. For more information, see [WAF Pricing].

</note>

[1]: aws.amazon.com/waf/pricing/

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#request_bodyHash<String,Types::RequestBodyAssociatedResourceTypeConfig>

Customizes the maximum size of the request body that your protected CloudFront distributions forward to WAF for inspection. The default size is 16 KB (16,384 bytes).

<note markdown=“1”> You are charged additional fees when your protected resources forward body sizes that are larger than the default. For more information, see [WAF Pricing].

</note>

[1]: aws.amazon.com/waf/pricing/



433
434
435
436
437
# File 'lib/aws-sdk-wafv2/types.rb', line 433

class AssociationConfig < Struct.new(
  :request_body)
  SENSITIVE = []
  include Aws::Structure
end