Class: Aws::WAFV2::Types::BlockAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::BlockAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Note:
When making an API call, you may pass BlockAction data as a hash:
{
custom_response: {
response_code: 1, # required
custom_response_body_key: "EntityName",
response_headers: [
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
},
}
Specifies that WAF should block the request and optionally defines additional custom handling for the response to the web request.
This is used in the context of other settings, for example to specify values for RuleAction and web ACL DefaultAction.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_response ⇒ Types::CustomResponse
Defines a custom response for the web request.
Instance Attribute Details
#custom_response ⇒ Types::CustomResponse
Defines a custom response for the web request.
For information about customizing web requests and responses, see
- Customizing web requests and responses in WAF][1
-
in the [WAF
Developer Guide].
[1]: docs.aws.amazon.com/waf/latest/developerguide/waf-custom-request-response.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html
641 642 643 644 645 |
# File 'lib/aws-sdk-wafv2/types.rb', line 641 class BlockAction < Struct.new( :custom_response) SENSITIVE = [] include Aws::Structure end |