Class: Aws::WAFV2::Types::Body

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass Body data as a hash:

{
  oversize_handling: "CONTINUE", # accepts CONTINUE, MATCH, NO_MATCH
}

Inspect the body of the web request. The body immediately follows the request headers.

This is used to indicate the web request component to inspect, in the FieldToMatch specification.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#oversize_handlingString

What WAF should do if the body is larger than WAF can inspect. WAF does not support inspecting the entire contents of the body of a web request when the body exceeds 8 KB (8192 bytes). Only the first 8 KB of the request body are forwarded to WAF by the underlying host service.

The options for oversize handling are the following:

  • `CONTINUE` - Inspect the body normally, according to the rule inspection criteria.

  • `MATCH` - Treat the web request as matching the rule statement. WAF applies the rule action to the request.

  • `NO_MATCH` - Treat the web request as not matching the rule statement.

You can combine the `MATCH` or `NO_MATCH` settings for oversize handling with your rule and web ACL action settings, so that you block any request whose body is over 8 KB.

Default: `CONTINUE`

Returns:

  • (String)


687
688
689
690
691
# File 'lib/aws-sdk-wafv2/types.rb', line 687

class Body < Struct.new(
  :oversize_handling)
  SENSITIVE = []
  include Aws::Structure
end