Class: Aws::WAFV2::Types::CaptchaConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::CaptchaConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Specifies how WAF should handle CAPTCHA evaluations. This is available at the web ACL level and in each rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#immunity_time_property ⇒ Types::ImmunityTimeProperty
Determines how long a
CAPTCHAtimestamp in the token remains valid after the client successfully solves aCAPTCHApuzzle.
Instance Attribute Details
#immunity_time_property ⇒ Types::ImmunityTimeProperty
Determines how long a CAPTCHA timestamp in the token remains valid after the client successfully solves a CAPTCHA puzzle.
923 924 925 926 927 |
# File 'lib/aws-sdk-wafv2/types.rb', line 923 class CaptchaConfig < Struct.new( :immunity_time_property) SENSITIVE = [] include Aws::Structure end |