Class: Aws::WAFV2::Types::CaptchaResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

The result from the inspection of the web request for a valid CAPTCHA token.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failure_reasonString

The reason for failure, populated when the evaluation of the token fails.

Returns:

  • (String)


953
954
955
956
957
958
959
# File 'lib/aws-sdk-wafv2/types.rb', line 953

class CaptchaResponse < Struct.new(
  :response_code,
  :solve_timestamp,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#response_codeInteger

The HTTP response code indicating the status of the CAPTCHA token in the web request. If the token is missing, invalid, or expired, this code is 405 Method Not Allowed.

Returns:

  • (Integer)


953
954
955
956
957
958
959
# File 'lib/aws-sdk-wafv2/types.rb', line 953

class CaptchaResponse < Struct.new(
  :response_code,
  :solve_timestamp,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end

#solve_timestampInteger

The time that the CAPTCHA was last solved for the supplied token.

Returns:

  • (Integer)


953
954
955
956
957
958
959
# File 'lib/aws-sdk-wafv2/types.rb', line 953

class CaptchaResponse < Struct.new(
  :response_code,
  :solve_timestamp,
  :failure_reason)
  SENSITIVE = []
  include Aws::Structure
end