Class: Aws::WAFV2::Types::ChallengeConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass ChallengeConfig data as a hash:

{
  immunity_time_property: {
    immunity_time: 1, # required
  },
}

Specifies how WAF should handle `Challenge` evaluations. This is available at the web ACL level and in each rule.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#immunity_time_propertyTypes::ImmunityTimeProperty

Determines how long a challenge timestamp in the token remains valid after the client successfully responds to a challenge.



1237
1238
1239
1240
1241
# File 'lib/aws-sdk-wafv2/types.rb', line 1237

class ChallengeConfig < Struct.new(
  :immunity_time_property)
  SENSITIVE = []
  include Aws::Structure
end