Class: Aws::WAFV2::Types::ClientSideActionConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ClientSideActionConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
This is part of the configuration for the managed rules
AWSManagedRulesAntiDDoSRuleSet in ManagedRuleGroupConfig.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#challenge ⇒ Types::ClientSideAction
Configuration for the use of the
AWSManagedRulesAntiDDoSRuleSetrulesChallengeAllDuringEventandChallengeDDoSRequests.
Instance Attribute Details
#challenge ⇒ Types::ClientSideAction
Configuration for the use of the AWSManagedRulesAntiDDoSRuleSet
rules ChallengeAllDuringEvent and ChallengeDDoSRequests.
Challenge
action itself. It only configures the use of the two anti-DDoS rules
named here.
You can enable or disable the use of these rules, and you can configure how to use them when they are enabled.
1231 1232 1233 1234 1235 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1231 class ClientSideActionConfig < Struct.new( :challenge) SENSITIVE = [] include Aws::Structure end |