Class: Aws::WAFV2::Types::CookieMatchPattern
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::CookieMatchPattern
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Note:
When making an API call, you may pass CookieMatchPattern data as a hash:
{
all: {
},
included_cookies: ["SingleCookieName"],
excluded_cookies: ["SingleCookieName"],
}
The filter to use to identify the subset of cookies to inspect in a web request.
You must specify exactly one setting: either `All`, `IncludedCookies`, or `ExcludedCookies`.
Example JSON: `“MatchPattern”: { “IncludedCookies”: “KeyToInclude2”, “KeyToInclude3” }`
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#all ⇒ Types::All
Inspect all cookies.
-
#excluded_cookies ⇒ Array<String>
Inspect only the cookies whose keys don't match any of the strings specified here.
-
#included_cookies ⇒ Array<String>
Inspect only the cookies that have a key that matches one of the strings specified here.
Instance Attribute Details
#all ⇒ Types::All
Inspect all cookies.
2038 2039 2040 2041 2042 2043 2044 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2038 class CookieMatchPattern < Struct.new( :all, :included_cookies, :excluded_cookies) SENSITIVE = [] include Aws::Structure end |
#excluded_cookies ⇒ Array<String>
Inspect only the cookies whose keys don't match any of the strings specified here.
2038 2039 2040 2041 2042 2043 2044 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2038 class CookieMatchPattern < Struct.new( :all, :included_cookies, :excluded_cookies) SENSITIVE = [] include Aws::Structure end |
#included_cookies ⇒ Array<String>
Inspect only the cookies that have a key that matches one of the strings specified here.
2038 2039 2040 2041 2042 2043 2044 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2038 class CookieMatchPattern < Struct.new( :all, :included_cookies, :excluded_cookies) SENSITIVE = [] include Aws::Structure end |