Class: Aws::WAFV2::Types::CountAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::CountAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Specifies that WAF should count the request. Optionally defines additional custom handling for the request.
This is used in the context of other settings, for example to specify values for RuleAction and web ACL DefaultAction.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_request_handling ⇒ Types::CustomRequestHandling
Defines custom handling for the web request.
Instance Attribute Details
#custom_request_handling ⇒ Types::CustomRequestHandling
Defines custom handling for the web request.
For information about customizing web requests and responses, see
- Customizing web requests and responses in WAF][1
-
in the *WAF
Developer Guide*.
[1]: docs.aws.amazon.com/waf/latest/developerguide/waf-custom-request-response.html
1372 1373 1374 1375 1376 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1372 class CountAction < Struct.new( :custom_request_handling) SENSITIVE = [] include Aws::Structure end |