Class: Aws::WAFV2::Types::CreateAPIKeyResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#api_keyString

The generated, encrypted API key. You can copy this for use in your JavaScript CAPTCHA integration.

For information about how to use this in your CAPTCHA JavaScript integration, see [WAF client application integration] in the *WAF Developer Guide*.

[1]: docs.aws.amazon.com/waf/latest/developerguide/waf-application-integration.html

Returns:

  • (String)


904
905
906
907
908
# File 'lib/aws-sdk-wafv2/types.rb', line 904

class CreateAPIKeyResponse < Struct.new(
  :api_key)
  SENSITIVE = []
  include Aws::Structure
end