Class: Aws::WAFV2::Types::CreateIPSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::CreateIPSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#addresses ⇒ Array<String>
Contains an array of strings that specifies zero or more IP addresses or blocks of IP addresses that you want WAF to inspect for in incoming requests.
-
#description ⇒ String
A description of the IP set that helps with identification.
-
#ip_address_version ⇒ String
The version of the IP addresses, either
IPV4orIPV6. -
#name ⇒ String
The name of the IP set.
-
#scope ⇒ String
Specifies whether this is for a global resource type, such as a Amazon CloudFront distribution.
-
#tags ⇒ Array<Types::Tag>
An array of key:value pairs to associate with the resource.
Instance Attribute Details
#addresses ⇒ Array<String>
Contains an array of strings that specifies zero or more IP addresses or blocks of IP addresses that you want WAF to inspect for in incoming requests. All addresses must be specified using Classless Inter-Domain Routing (CIDR) notation. WAF supports all IPv4 and IPv6 CIDR ranges except for /0.
Example address strings:
-
For requests that originated from the IP address 192.0.2.44, specify
192.0.2.44/32. -
For requests that originated from IP addresses from 192.0.2.0 to 192.0.2.255, specify
192.0.2.0/24. -
For requests that originated from the IP address 1111:0000:0000:0000:0000:0000:0000:0111, specify
1111:0000:0000:0000:0000:0000:0000:0111/128. -
For requests that originated from IP addresses 1111:0000:0000:0000:0000:0000:0000:0000 to 1111:0000:0000:0000:ffff:ffff:ffff:ffff, specify
1111:0000:0000:0000:0000:0000:0000:0000/64.
For more information about CIDR notation, see the Wikipedia entry [Classless Inter-Domain Routing].
Example JSON Addresses specifications:
-
Empty array: ‘“Addresses”: []`
-
Array with one address: ‘“Addresses”: [“192.0.2.44/32”]`
-
Array with three addresses: ‘“Addresses”: [“192.0.2.44/32”, “192.0.2.0/24”, “192.0.0.0/16”]`
-
INVALID specification: ‘“Addresses”: [“”]` INVALID
1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1500 class CreateIPSetRequest < Struct.new( :name, :scope, :description, :ip_address_version, :addresses, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the IP set that helps with identification.
1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1500 class CreateIPSetRequest < Struct.new( :name, :scope, :description, :ip_address_version, :addresses, :tags) SENSITIVE = [] include Aws::Structure end |
#ip_address_version ⇒ String
The version of the IP addresses, either IPV4 or IPV6.
1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1500 class CreateIPSetRequest < Struct.new( :name, :scope, :description, :ip_address_version, :addresses, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the IP set. You cannot change the name of an IPSet after you create it.
1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1500 class CreateIPSetRequest < Struct.new( :name, :scope, :description, :ip_address_version, :addresses, :tags) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for a global resource type, such as a Amazon CloudFront distribution. For an Amplify application, use CLOUDFRONT.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope: ‘–scope=CLOUDFRONT –region=us-east-1`.
-
API and SDKs - For all calls, use the Region endpoint us-east-1.
1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1500 class CreateIPSetRequest < Struct.new( :name, :scope, :description, :ip_address_version, :addresses, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of key:value pairs to associate with the resource.
1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1500 class CreateIPSetRequest < Struct.new( :name, :scope, :description, :ip_address_version, :addresses, :tags) SENSITIVE = [] include Aws::Structure end |