Class: Aws::WAFV2::Types::CreateIPSetResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#summaryTypes::IPSetSummary

High-level information about an IPSet, returned by operations like create and list. This provides information like the ID, that you can use to retrieve and manage an IPSet, and the ARN, that you provide to the IPSetReferenceStatement to use the address set in a Rule.

Returns:



1520
1521
1522
1523
1524
# File 'lib/aws-sdk-wafv2/types.rb', line 1520

class CreateIPSetResponse < Struct.new(
  :summary)
  SENSITIVE = []
  include Aws::Structure
end