Class: Aws::WAFV2::Types::CreateRuleGroupResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::CreateRuleGroupResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#summary ⇒ Types::RuleGroupSummary
High-level information about a RuleGroup, returned by operations like create and list.
Instance Attribute Details
#summary ⇒ Types::RuleGroupSummary
High-level information about a RuleGroup, returned by operations like create and list. This provides information like the ID, that you can use to retrieve and manage a `RuleGroup`, and the ARN, that you provide to the RuleGroupReferenceStatement to use the rule group in a Rule.
2006 2007 2008 2009 2010 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2006 class CreateRuleGroupResponse < Struct.new( :summary) SENSITIVE = [] include Aws::Structure end |