Class: Aws::WAFV2::Types::CreateWebACLRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#association_configTypes::AssociationConfig

Specifies custom configurations for the associations between the web ACL and protected resources.

Use this to customize the maximum size of the request body that your protected CloudFront distributions forward to WAF for inspection. The default is 16 KB (16,384 kilobytes).

<note markdown=“1”> You are charged additional fees when your protected resources forward body sizes that are larger than the default. For more information, see [WAF Pricing].

</note>

[1]: aws.amazon.com/waf/pricing/



1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-wafv2/types.rb', line 1435

class CreateWebACLRequest < Struct.new(
  :name,
  :scope,
  :default_action,
  :description,
  :rules,
  :visibility_config,
  :tags,
  :custom_response_bodies,
  :captcha_config,
  :challenge_config,
  :token_domains,
  :association_config)
  SENSITIVE = []
  include Aws::Structure
end

#captcha_configTypes::CaptchaConfig

Specifies how WAF should handle ‘CAPTCHA` evaluations for rules that don’t have their own ‘CaptchaConfig` settings. If you don’t specify this, WAF uses its default settings for ‘CaptchaConfig`.



1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-wafv2/types.rb', line 1435

class CreateWebACLRequest < Struct.new(
  :name,
  :scope,
  :default_action,
  :description,
  :rules,
  :visibility_config,
  :tags,
  :custom_response_bodies,
  :captcha_config,
  :challenge_config,
  :token_domains,
  :association_config)
  SENSITIVE = []
  include Aws::Structure
end

#challenge_configTypes::ChallengeConfig

Specifies how WAF should handle challenge evaluations for rules that don’t have their own ‘ChallengeConfig` settings. If you don’t specify this, WAF uses its default settings for ‘ChallengeConfig`.



1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-wafv2/types.rb', line 1435

class CreateWebACLRequest < Struct.new(
  :name,
  :scope,
  :default_action,
  :description,
  :rules,
  :visibility_config,
  :tags,
  :custom_response_bodies,
  :captcha_config,
  :challenge_config,
  :token_domains,
  :association_config)
  SENSITIVE = []
  include Aws::Structure
end

#custom_response_bodiesHash<String,Types::CustomResponseBody>

A map of custom response keys and content bodies. When you create a rule with a block action, you can send a custom response to the web request. You define these for the web ACL, and then use them in the rules and default actions that you define in the web ACL.

For information about customizing web requests and responses, see

Customizing web requests and responses in WAF][1

in the *WAF

Developer Guide*.

For information about the limits on count and size for custom request and response settings, see [WAF quotas] in the *WAF Developer Guide*.

[1]: docs.aws.amazon.com/waf/latest/developerguide/waf-custom-request-response.html [2]: docs.aws.amazon.com/waf/latest/developerguide/limits.html

Returns:



1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-wafv2/types.rb', line 1435

class CreateWebACLRequest < Struct.new(
  :name,
  :scope,
  :default_action,
  :description,
  :rules,
  :visibility_config,
  :tags,
  :custom_response_bodies,
  :captcha_config,
  :challenge_config,
  :token_domains,
  :association_config)
  SENSITIVE = []
  include Aws::Structure
end

#default_actionTypes::DefaultAction

The action to perform if none of the ‘Rules` contained in the `WebACL` match.



1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-wafv2/types.rb', line 1435

class CreateWebACLRequest < Struct.new(
  :name,
  :scope,
  :default_action,
  :description,
  :rules,
  :visibility_config,
  :tags,
  :custom_response_bodies,
  :captcha_config,
  :challenge_config,
  :token_domains,
  :association_config)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the web ACL that helps with identification.

Returns:

  • (String)


1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-wafv2/types.rb', line 1435

class CreateWebACLRequest < Struct.new(
  :name,
  :scope,
  :default_action,
  :description,
  :rules,
  :visibility_config,
  :tags,
  :custom_response_bodies,
  :captcha_config,
  :challenge_config,
  :token_domains,
  :association_config)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the web ACL. You cannot change the name of a web ACL after you create it.

Returns:

  • (String)


1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-wafv2/types.rb', line 1435

class CreateWebACLRequest < Struct.new(
  :name,
  :scope,
  :default_action,
  :description,
  :rules,
  :visibility_config,
  :tags,
  :custom_response_bodies,
  :captcha_config,
  :challenge_config,
  :token_domains,
  :association_config)
  SENSITIVE = []
  include Aws::Structure
end

#rulesArray<Types::Rule>

The Rule statements used to identify the web requests that you want to allow, block, or count. Each rule includes one top-level statement that WAF uses to identify matching web requests, and parameters that govern how WAF handles them.

Returns:



1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-wafv2/types.rb', line 1435

class CreateWebACLRequest < Struct.new(
  :name,
  :scope,
  :default_action,
  :description,
  :rules,
  :visibility_config,
  :tags,
  :custom_response_bodies,
  :captcha_config,
  :challenge_config,
  :token_domains,
  :association_config)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, an Amazon Cognito user pool, an App Runner service, or an Amazon Web Services Verified Access instance.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: ‘–scope=CLOUDFRONT –region=us-east-1`.

  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Returns:

  • (String)


1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-wafv2/types.rb', line 1435

class CreateWebACLRequest < Struct.new(
  :name,
  :scope,
  :default_action,
  :description,
  :rules,
  :visibility_config,
  :tags,
  :custom_response_bodies,
  :captcha_config,
  :challenge_config,
  :token_domains,
  :association_config)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of key:value pairs to associate with the resource.

Returns:



1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-wafv2/types.rb', line 1435

class CreateWebACLRequest < Struct.new(
  :name,
  :scope,
  :default_action,
  :description,
  :rules,
  :visibility_config,
  :tags,
  :custom_response_bodies,
  :captcha_config,
  :challenge_config,
  :token_domains,
  :association_config)
  SENSITIVE = []
  include Aws::Structure
end

#token_domainsArray<String>

Specifies the domains that WAF should accept in a web request token. This enables the use of tokens across multiple protected websites. When WAF provides a token, it uses the domain of the Amazon Web Services resource that the web ACL is protecting. If you don’t specify a list of token domains, WAF accepts tokens only for the domain of the protected resource. With a token domain list, WAF accepts the resource’s host domain plus all domains in the token domain list, including their prefixed subdomains.

Example JSON: ‘“TokenDomains”: { “mywebsite.com”, “myotherwebsite.com” }`

Public suffixes aren’t allowed. For example, you can’t use ‘usa.gov` or `co.uk` as token domains.

Returns:

  • (Array<String>)


1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-wafv2/types.rb', line 1435

class CreateWebACLRequest < Struct.new(
  :name,
  :scope,
  :default_action,
  :description,
  :rules,
  :visibility_config,
  :tags,
  :custom_response_bodies,
  :captcha_config,
  :challenge_config,
  :token_domains,
  :association_config)
  SENSITIVE = []
  include Aws::Structure
end

#visibility_configTypes::VisibilityConfig

Defines and enables Amazon CloudWatch metrics and web request sample collection.



1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
# File 'lib/aws-sdk-wafv2/types.rb', line 1435

class CreateWebACLRequest < Struct.new(
  :name,
  :scope,
  :default_action,
  :description,
  :rules,
  :visibility_config,
  :tags,
  :custom_response_bodies,
  :captcha_config,
  :challenge_config,
  :token_domains,
  :association_config)
  SENSITIVE = []
  include Aws::Structure
end