Class: Aws::WAFV2::Types::CustomRequestHandling

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass CustomRequestHandling data as a hash:

{
  insert_headers: [ # required
    {
      name: "CustomHTTPHeaderName", # required
      value: "CustomHTTPHeaderValue", # required
    },
  ],
}

Custom request handling behavior that inserts custom headers into a web request. You can add custom request handling for WAF to use when the rule action doesn't block the request. For example, `CaptchaAction` for requests with valid t okens, and `AllowAction`.

For information about customizing web requests and responses, see

Customizing web requests and responses in WAF][1

in the [WAF

Developer Guide].

[1]: docs.aws.amazon.com/waf/latest/developerguide/waf-custom-request-response.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#insert_headersArray<Types::CustomHTTPHeader>

The HTTP headers to insert into the request. Duplicate header names are not allowed.

For information about the limits on count and size for custom request and response settings, see [WAF quotas] in the [WAF Developer Guide].

[1]: docs.aws.amazon.com/waf/latest/developerguide/limits.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html

Returns:



4054
4055
4056
4057
4058
# File 'lib/aws-sdk-wafv2/types.rb', line 4054

class CustomRequestHandling < Struct.new(
  :insert_headers)
  SENSITIVE = []
  include Aws::Structure
end