Class: Aws::WAFV2::Types::DefaultAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::DefaultAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Note:
When making an API call, you may pass DefaultAction data as a hash:
{
block: {
custom_response: {
response_code: 1, # required
custom_response_body_key: "EntityName",
response_headers: [
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
},
},
allow: {
custom_request_handling: {
insert_headers: [ # required
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
},
},
}
In a WebACL, this is the action that you want WAF to perform when a web request doesn't match any of the rules in the `WebACL`. The default action must be a terminating action, so you can't use count.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allow ⇒ Types::AllowAction
Specifies that WAF should allow requests by default.
-
#block ⇒ Types::BlockAction
Specifies that WAF should block requests by default.
Instance Attribute Details
#allow ⇒ Types::AllowAction
Specifies that WAF should allow requests by default.
2788 2789 2790 2791 2792 2793 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2788 class DefaultAction < Struct.new( :block, :allow) SENSITIVE = [] include Aws::Structure end |
#block ⇒ Types::BlockAction
Specifies that WAF should block requests by default.
2788 2789 2790 2791 2792 2793 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2788 class DefaultAction < Struct.new( :block, :allow) SENSITIVE = [] include Aws::Structure end |