Class: Aws::WAFV2::Types::DeleteFirewallManagerRuleGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::DeleteFirewallManagerRuleGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#web_acl_arn ⇒ String
The Amazon Resource Name (ARN) of the web ACL.
-
#web_acl_lock_token ⇒ String
A token used for optimistic locking.
Instance Attribute Details
#web_acl_arn ⇒ String
The Amazon Resource Name (ARN) of the web ACL.
2185 2186 2187 2188 2189 2190 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2185 class DeleteFirewallManagerRuleGroupsRequest < Struct.new( :web_acl_arn, :web_acl_lock_token) SENSITIVE = [] include Aws::Structure end |
#web_acl_lock_token ⇒ String
A token used for optimistic locking. WAF returns a token to your get and list requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like update and delete. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a WAFOptimisticLockException. If this happens, perform another get, and use the new token returned by that operation.
2185 2186 2187 2188 2189 2190 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2185 class DeleteFirewallManagerRuleGroupsRequest < Struct.new( :web_acl_arn, :web_acl_lock_token) SENSITIVE = [] include Aws::Structure end |