Class: Aws::WAFV2::Types::DeleteIPSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::DeleteIPSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
A unique identifier for the set.
-
#lock_token ⇒ String
A token used for optimistic locking.
-
#name ⇒ String
The name of the IP set.
-
#scope ⇒ String
Specifies whether this is for a global resource type, such as a Amazon CloudFront distribution.
Instance Attribute Details
#id ⇒ String
A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
1956 1957 1958 1959 1960 1961 1962 1963 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1956 class DeleteIPSetRequest < Struct.new( :name, :scope, :id, :lock_token) SENSITIVE = [] include Aws::Structure end |
#lock_token ⇒ String
A token used for optimistic locking. WAF returns a token to your ‘get` and `list` requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like `update` and `delete`. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a `WAFOptimisticLockException`. If this happens, perform another `get`, and use the new token returned by that operation.
1956 1957 1958 1959 1960 1961 1962 1963 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1956 class DeleteIPSetRequest < Struct.new( :name, :scope, :id, :lock_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the IP set. You cannot change the name of an ‘IPSet` after you create it.
1956 1957 1958 1959 1960 1961 1962 1963 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1956 class DeleteIPSetRequest < Struct.new( :name, :scope, :id, :lock_token) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for a global resource type, such as a Amazon CloudFront distribution. For an Amplify application, use ‘CLOUDFRONT`.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope: ‘–scope=CLOUDFRONT –region=us-east-1`.
-
API and SDKs - For all calls, use the Region endpoint us-east-1.
1956 1957 1958 1959 1960 1961 1962 1963 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1956 class DeleteIPSetRequest < Struct.new( :name, :scope, :id, :lock_token) SENSITIVE = [] include Aws::Structure end |