Class: Aws::WAFV2::Types::DescribeManagedRuleGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::DescribeManagedRuleGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the managed rule group.
-
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application.
-
#vendor_name ⇒ String
The name of the managed rule group vendor.
-
#version_name ⇒ String
The version of the rule group.
Instance Attribute Details
#name ⇒ String
The name of the managed rule group. You use this, along with the vendor name, to identify the rule group.
1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1850 class DescribeManagedRuleGroupRequest < Struct.new( :vendor_name, :name, :scope, :version_name) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, an Amazon Cognito user pool, an App Runner service, or an Amazon Web Services Verified Access instance.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope: ‘–scope=CLOUDFRONT –region=us-east-1`.
-
API and SDKs - For all calls, use the Region endpoint us-east-1.
1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1850 class DescribeManagedRuleGroupRequest < Struct.new( :vendor_name, :name, :scope, :version_name) SENSITIVE = [] include Aws::Structure end |
#vendor_name ⇒ String
The name of the managed rule group vendor. You use this, along with the rule group name, to identify the rule group.
1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1850 class DescribeManagedRuleGroupRequest < Struct.new( :vendor_name, :name, :scope, :version_name) SENSITIVE = [] include Aws::Structure end |
#version_name ⇒ String
The version of the rule group. You can only use a version that is not scheduled for expiration. If you don’t provide this, WAF uses the vendor’s default version.
1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1850 class DescribeManagedRuleGroupRequest < Struct.new( :vendor_name, :name, :scope, :version_name) SENSITIVE = [] include Aws::Structure end |