Class: Aws::WAFV2::Types::DisassociateWebACLRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass DisassociateWebACLRequest data as a hash:

{
  resource_arn: "ResourceArn", # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The Amazon Resource Name (ARN) of the resource to disassociate from the web ACL.

The ARN must be in one of the following formats:

  • For an Application Load Balancer: `arn:aws:elasticloadbalancing:region:account-id:loadbalancer/app/load-balancer-name/load-balancer-id `

  • For an Amazon API Gateway REST API: `arn:aws:apigateway:region::/restapis/api-id/stages/stage-name `

  • For an AppSync GraphQL API: `arn:aws:appsync:region:account-id:apis/GraphQLApiId `

  • For an Amazon Cognito user pool: `arn:aws:cognito-idp:region:account-id:userpool/user-pool-id `

Returns:

  • (String)


4007
4008
4009
4010
4011
# File 'lib/aws-sdk-wafv2/types.rb', line 4007

class DisassociateWebACLRequest < Struct.new(
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end