Class: Aws::WAFV2::Types::ExcludedRule
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ExcludedRule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Specifies a single rule in a rule group whose action you want to override to Count.
<note markdown=“1”> Instead of this option, use RuleActionOverrides. It accepts any valid action setting, including Count.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the rule whose action you want to override to
Count.
Instance Attribute Details
#name ⇒ String
The name of the rule whose action you want to override to Count.
2806 2807 2808 2809 2810 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2806 class ExcludedRule < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |