Class: Aws::WAFV2::Types::FirewallManagerStatement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

The processing guidance for an Firewall Manager rule. This is like a regular rule Statement, but it can only contain a rule group reference.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#managed_rule_group_statementTypes::ManagedRuleGroupStatement

A rule statement used to run the rules that are defined in a managed rule group. To use this, provide the vendor name and the name of the rule group in this statement. You can retrieve the required names by calling ListAvailableManagedRuleGroups.

You cannot nest a `ManagedRuleGroupStatement`, for example for use inside a `NotStatement` or `OrStatement`. It can only be referenced as a top-level statement within a rule.

<note markdown=“1”> You are charged additional fees when you use the WAF Bot Control managed rule group `AWSManagedRulesBotControlRuleSet` or the WAF Fraud Control account takeover prevention (ATP) managed rule group `AWSManagedRulesATPRuleSet`. For more information, see [WAF Pricing].

</note>

[1]: aws.amazon.com/waf/pricing/



4355
4356
4357
4358
4359
4360
# File 'lib/aws-sdk-wafv2/types.rb', line 4355

class FirewallManagerStatement < Struct.new(
  :managed_rule_group_statement,
  :rule_group_reference_statement)
  SENSITIVE = []
  include Aws::Structure
end

#rule_group_reference_statementTypes::RuleGroupReferenceStatement

A rule statement used to run the rules that are defined in a RuleGroup. To use this, create a rule group with your rules, then provide the ARN of the rule group in this statement.

You cannot nest a `RuleGroupReferenceStatement`, for example for use inside a `NotStatement` or `OrStatement`. You can only use a rule group reference statement at the top level inside a web ACL.



4355
4356
4357
4358
4359
4360
# File 'lib/aws-sdk-wafv2/types.rb', line 4355

class FirewallManagerStatement < Struct.new(
  :managed_rule_group_statement,
  :rule_group_reference_statement)
  SENSITIVE = []
  include Aws::Structure
end