Class: Aws::WAFV2::Types::GetLoggingConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetLoggingConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Note:
When making an API call, you may pass GetLoggingConfigurationRequest data as a hash:
{
resource_arn: "ResourceArn", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the web ACL for which you want to get the LoggingConfiguration.
Instance Attribute Details
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the web ACL for which you want to get the LoggingConfiguration.
3732 3733 3734 3735 3736 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3732 class GetLoggingConfigurationRequest < Struct.new( :resource_arn) SENSITIVE = [] include Aws::Structure end |