Class: Aws::WAFV2::Types::GetManagedRuleSetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetManagedRuleSetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lock_token ⇒ String
A token used for optimistic locking.
-
#managed_rule_set ⇒ Types::ManagedRuleSet
The managed rule set that you requested.
Instance Attribute Details
#lock_token ⇒ String
A token used for optimistic locking. WAF returns a token to your get and list requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like update and delete. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a WAFOptimisticLockException. If this happens, perform another get, and use the new token returned by that operation.
3603 3604 3605 3606 3607 3608 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3603 class GetManagedRuleSetResponse < Struct.new( :managed_rule_set, :lock_token) SENSITIVE = [] include Aws::Structure end |
#managed_rule_set ⇒ Types::ManagedRuleSet
The managed rule set that you requested.
3603 3604 3605 3606 3607 3608 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3603 class GetManagedRuleSetResponse < Struct.new( :managed_rule_set, :lock_token) SENSITIVE = [] include Aws::Structure end |