Class: Aws::WAFV2::Types::GetPermissionPolicyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetPermissionPolicyResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy ⇒ String
The IAM policy that is attached to the specified rule group.
Instance Attribute Details
#policy ⇒ String
The IAM policy that is attached to the specified rule group.
5474 5475 5476 5477 5478 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5474 class GetPermissionPolicyResponse < Struct.new( :policy) SENSITIVE = [] include Aws::Structure end |