Class: Aws::WAFV2::Types::GetRateBasedStatementManagedKeysRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#rule_group_rule_nameString

The name of the rule group reference statement in your web ACL. This is required only when you have the rate-based rule nested inside a rule group.



3706
3707
3708
3709
3710
3711
3712
3713
3714
# File 'lib/aws-sdk-wafv2/types.rb', line 3706

class GetRateBasedStatementManagedKeysRequest < Struct.new(
  :scope,
  :web_acl_name,
  :web_acl_id,
  :rule_group_rule_name,
  :rule_name)
  SENSITIVE = []
  include Aws::Structure
end

#rule_nameString

The name of the rate-based rule to get the keys for. If you have the rule defined inside a rule group that you’re using in your web ACL, also provide the name of the rule group reference statement in the request parameter RuleGroupRuleName.



3706
3707
3708
3709
3710
3711
3712
3713
3714
# File 'lib/aws-sdk-wafv2/types.rb', line 3706

class GetRateBasedStatementManagedKeysRequest < Struct.new(
  :scope,
  :web_acl_name,
  :web_acl_id,
  :rule_group_rule_name,
  :rule_name)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether this is for a global resource type, such as a Amazon CloudFront distribution. For an Amplify application, use CLOUDFRONT.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: ‘–scope=CLOUDFRONT –region=us-east-1`.

  • API and SDKs - For all calls, use the Region endpoint us-east-1.



3706
3707
3708
3709
3710
3711
3712
3713
3714
# File 'lib/aws-sdk-wafv2/types.rb', line 3706

class GetRateBasedStatementManagedKeysRequest < Struct.new(
  :scope,
  :web_acl_name,
  :web_acl_id,
  :rule_group_rule_name,
  :rule_name)
  SENSITIVE = []
  include Aws::Structure
end

#web_acl_idString

The unique identifier for the web ACL. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.



3706
3707
3708
3709
3710
3711
3712
3713
3714
# File 'lib/aws-sdk-wafv2/types.rb', line 3706

class GetRateBasedStatementManagedKeysRequest < Struct.new(
  :scope,
  :web_acl_name,
  :web_acl_id,
  :rule_group_rule_name,
  :rule_name)
  SENSITIVE = []
  include Aws::Structure
end

#web_acl_nameString

The name of the web ACL. You cannot change the name of a web ACL after you create it.



3706
3707
3708
3709
3710
3711
3712
3713
3714
# File 'lib/aws-sdk-wafv2/types.rb', line 3706

class GetRateBasedStatementManagedKeysRequest < Struct.new(
  :scope,
  :web_acl_name,
  :web_acl_id,
  :rule_group_rule_name,
  :rule_name)
  SENSITIVE = []
  include Aws::Structure
end