Class: Aws::WAFV2::Types::GetRegexPatternSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetRegexPatternSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
A unique identifier for the set.
-
#name ⇒ String
The name of the set.
-
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application.
Instance Attribute Details
#id ⇒ String
A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
3017 3018 3019 3020 3021 3022 3023 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3017 class GetRegexPatternSetRequest < Struct.new( :name, :scope, :id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the set. You cannot change the name after you create the set.
3017 3018 3019 3020 3021 3022 3023 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3017 class GetRegexPatternSetRequest < Struct.new( :name, :scope, :id) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, an Amazon Cognito user pool, an App Runner service, or an Amazon Web Services Verified Access instance.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope: ‘–scope=CLOUDFRONT –region=us-east-1`.
-
API and SDKs - For all calls, use the Region endpoint us-east-1.
3017 3018 3019 3020 3021 3022 3023 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3017 class GetRegexPatternSetRequest < Struct.new( :name, :scope, :id) SENSITIVE = [] include Aws::Structure end |