Class: Aws::WAFV2::Types::GetRevenueStatisticsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetRevenueStatisticsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_marker ⇒ String
When you get a paginated response, this marker indicates that additional results are available.
-
#revenue_path_statistics ⇒ Array<Types::RevenuePathStatistics>
Statistics for top revenue paths.
-
#source_statistics ⇒ Array<Types::SourceStatistics>
Statistics for top revenue sources (AI bots).
Instance Attribute Details
#next_marker ⇒ String
When you get a paginated response, this marker indicates that additional results are available.
3957 3958 3959 3960 3961 3962 3963 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3957 class GetRevenueStatisticsResponse < Struct.new( :source_statistics, :revenue_path_statistics, :next_marker) SENSITIVE = [] include Aws::Structure end |
#revenue_path_statistics ⇒ Array<Types::RevenuePathStatistics>
Statistics for top revenue paths. Populated when ‘StatisticType` is `TOP_PATHS_BY_REVENUE`.
3957 3958 3959 3960 3961 3962 3963 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3957 class GetRevenueStatisticsResponse < Struct.new( :source_statistics, :revenue_path_statistics, :next_marker) SENSITIVE = [] include Aws::Structure end |
#source_statistics ⇒ Array<Types::SourceStatistics>
Statistics for top revenue sources (AI bots). Populated when ‘StatisticType` is `TOP_SOURCES_BY_REVENUE`.
3957 3958 3959 3960 3961 3962 3963 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3957 class GetRevenueStatisticsResponse < Struct.new( :source_statistics, :revenue_path_statistics, :next_marker) SENSITIVE = [] include Aws::Structure end |