Class: Aws::WAFV2::Types::GetRuleGroupResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetRuleGroupResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lock_token ⇒ String
A token used for optimistic locking.
- #rule_group ⇒ Types::RuleGroup
Instance Attribute Details
#lock_token ⇒ String
A token used for optimistic locking. WAF returns a token to your get and list requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like update and delete. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a WAFOptimisticLockException. If this happens, perform another get, and use the new token returned by that operation.
3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3849 class GetRuleGroupResponse < Struct.new( :rule_group, :lock_token) SENSITIVE = [] include Aws::Structure end |
#rule_group ⇒ Types::RuleGroup
3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3849 class GetRuleGroupResponse < Struct.new( :rule_group, :lock_token) SENSITIVE = [] include Aws::Structure end |