Class: Aws::WAFV2::Types::GetSampledRequestsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_itemsInteger

The number of requests that you want WAF to return from among the first 5,000 requests that your Amazon Web Services resource received during the time range. If your resource received fewer requests than the value of ‘MaxItems`, `GetSampledRequests` returns information about all of them.

Returns:

  • (Integer)


2747
2748
2749
2750
2751
2752
2753
2754
2755
# File 'lib/aws-sdk-wafv2/types.rb', line 2747

class GetSampledRequestsRequest < Struct.new(
  :web_acl_arn,
  :rule_metric_name,
  :scope,
  :time_window,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#rule_metric_nameString

The metric name assigned to the ‘Rule` or `RuleGroup` dimension for which you want a sample of requests.

Returns:

  • (String)


2747
2748
2749
2750
2751
2752
2753
2754
2755
# File 'lib/aws-sdk-wafv2/types.rb', line 2747

class GetSampledRequestsRequest < Struct.new(
  :web_acl_arn,
  :rule_metric_name,
  :scope,
  :time_window,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, an Amazon Cognito user pool, or an App Runner service.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: ‘–scope=CLOUDFRONT –region=us-east-1`.

  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Returns:

  • (String)


2747
2748
2749
2750
2751
2752
2753
2754
2755
# File 'lib/aws-sdk-wafv2/types.rb', line 2747

class GetSampledRequestsRequest < Struct.new(
  :web_acl_arn,
  :rule_metric_name,
  :scope,
  :time_window,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#time_windowTypes::TimeWindow

The start date and time and the end date and time of the range for which you want ‘GetSampledRequests` to return a sample of requests. You must specify the times in Coordinated Universal Time (UTC) format. UTC format includes the special designator, `Z`. For example, `“2016-09-27T14:50Z”`. You can specify any time range in the previous three hours. If you specify a start time that’s earlier than three hours ago, WAF sets it to three hours ago.

Returns:



2747
2748
2749
2750
2751
2752
2753
2754
2755
# File 'lib/aws-sdk-wafv2/types.rb', line 2747

class GetSampledRequestsRequest < Struct.new(
  :web_acl_arn,
  :rule_metric_name,
  :scope,
  :time_window,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#web_acl_arnString

The Amazon resource name (ARN) of the ‘WebACL` for which you want a sample of requests.

Returns:

  • (String)


2747
2748
2749
2750
2751
2752
2753
2754
2755
# File 'lib/aws-sdk-wafv2/types.rb', line 2747

class GetSampledRequestsRequest < Struct.new(
  :web_acl_arn,
  :rule_metric_name,
  :scope,
  :time_window,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end