Class: Aws::WAFV2::Types::GetTopPathStatisticsByTrafficRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bot_categoryString

Filters the results to include only traffic from bots in the specified category. For example, you can filter by ai to see only AI crawler traffic, or search_engine to see only search engine bot traffic. When you apply this filter, the Source field is populated in the response.

Returns:

  • (String)


4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
# File 'lib/aws-sdk-wafv2/types.rb', line 4010

class GetTopPathStatisticsByTrafficRequest < Struct.new(
  :web_acl_arn,
  :scope,
  :uri_path_prefix,
  :time_window,
  :bot_category,
  :bot_organization,
  :bot_name,
  :limit,
  :number_of_top_traffic_bots_per_path,
  :next_marker)
  SENSITIVE = []
  include Aws::Structure
end

#bot_nameString

Filters the results to include only traffic from the specified bot. For example, you can filter by gptbot or googlebot. When you apply this filter, the Source field is populated in the response.

Returns:

  • (String)


4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
# File 'lib/aws-sdk-wafv2/types.rb', line 4010

class GetTopPathStatisticsByTrafficRequest < Struct.new(
  :web_acl_arn,
  :scope,
  :uri_path_prefix,
  :time_window,
  :bot_category,
  :bot_organization,
  :bot_name,
  :limit,
  :number_of_top_traffic_bots_per_path,
  :next_marker)
  SENSITIVE = []
  include Aws::Structure
end

#bot_organizationString

Filters the results to include only traffic from bots belonging to the specified organization. For example, you can filter by openai or google. When you apply this filter, the Source field is populated in the response.

Returns:

  • (String)


4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
# File 'lib/aws-sdk-wafv2/types.rb', line 4010

class GetTopPathStatisticsByTrafficRequest < Struct.new(
  :web_acl_arn,
  :scope,
  :uri_path_prefix,
  :time_window,
  :bot_category,
  :bot_organization,
  :bot_name,
  :limit,
  :number_of_top_traffic_bots_per_path,
  :next_marker)
  SENSITIVE = []
  include Aws::Structure
end

#limitInteger

The maximum number of path statistics to return. Valid values are 1 to 100.

Returns:

  • (Integer)


4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
# File 'lib/aws-sdk-wafv2/types.rb', line 4010

class GetTopPathStatisticsByTrafficRequest < Struct.new(
  :web_acl_arn,
  :scope,
  :uri_path_prefix,
  :time_window,
  :bot_category,
  :bot_organization,
  :bot_name,
  :limit,
  :number_of_top_traffic_bots_per_path,
  :next_marker)
  SENSITIVE = []
  include Aws::Structure
end

#next_markerString

When you request a list of objects with a Limit setting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns a NextMarker value in the response. To retrieve the next batch of objects, provide the marker from the prior call in your next request.

Returns:

  • (String)


4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
# File 'lib/aws-sdk-wafv2/types.rb', line 4010

class GetTopPathStatisticsByTrafficRequest < Struct.new(
  :web_acl_arn,
  :scope,
  :uri_path_prefix,
  :time_window,
  :bot_category,
  :bot_organization,
  :bot_name,
  :limit,
  :number_of_top_traffic_bots_per_path,
  :next_marker)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_top_traffic_bots_per_pathInteger

The maximum number of top bots to include in the statistics for each path. Valid values are 1 to 10.

Returns:

  • (Integer)


4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
# File 'lib/aws-sdk-wafv2/types.rb', line 4010

class GetTopPathStatisticsByTrafficRequest < Struct.new(
  :web_acl_arn,
  :scope,
  :uri_path_prefix,
  :time_window,
  :bot_category,
  :bot_organization,
  :bot_name,
  :limit,
  :number_of_top_traffic_bots_per_path,
  :next_marker)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether the web ACL is for an Amazon Web Services CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer, an AppSync GraphQL API, an Amazon Cognito user pool, an Amazon Web Services App Runner service, or an Amazon Web Services Verified Access instance.

Returns:

  • (String)


4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
# File 'lib/aws-sdk-wafv2/types.rb', line 4010

class GetTopPathStatisticsByTrafficRequest < Struct.new(
  :web_acl_arn,
  :scope,
  :uri_path_prefix,
  :time_window,
  :bot_category,
  :bot_organization,
  :bot_name,
  :limit,
  :number_of_top_traffic_bots_per_path,
  :next_marker)
  SENSITIVE = []
  include Aws::Structure
end

#time_windowTypes::TimeWindow

The time window for which you want to retrieve path statistics. The time window must be within the data retention period for your web ACL.

Returns:



4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
# File 'lib/aws-sdk-wafv2/types.rb', line 4010

class GetTopPathStatisticsByTrafficRequest < Struct.new(
  :web_acl_arn,
  :scope,
  :uri_path_prefix,
  :time_window,
  :bot_category,
  :bot_organization,
  :bot_name,
  :limit,
  :number_of_top_traffic_bots_per_path,
  :next_marker)
  SENSITIVE = []
  include Aws::Structure
end

#uri_path_prefixString

A URI path prefix to filter the results. When you specify this parameter, the operation returns statistics for individual URIs within the specified path prefix. For example, if you specify /api, the response includes statistics for paths like /api/v1/users and /api/v2/orders. If you don’t specify this parameter, the operation returns top-level path statistics.

Returns:

  • (String)


4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
# File 'lib/aws-sdk-wafv2/types.rb', line 4010

class GetTopPathStatisticsByTrafficRequest < Struct.new(
  :web_acl_arn,
  :scope,
  :uri_path_prefix,
  :time_window,
  :bot_category,
  :bot_organization,
  :bot_name,
  :limit,
  :number_of_top_traffic_bots_per_path,
  :next_marker)
  SENSITIVE = []
  include Aws::Structure
end

#web_acl_arnString

The Amazon Resource Name (ARN) of the web ACL for which you want to retrieve path statistics.

Returns:

  • (String)


4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
# File 'lib/aws-sdk-wafv2/types.rb', line 4010

class GetTopPathStatisticsByTrafficRequest < Struct.new(
  :web_acl_arn,
  :scope,
  :uri_path_prefix,
  :time_window,
  :bot_category,
  :bot_organization,
  :bot_name,
  :limit,
  :number_of_top_traffic_bots_per_path,
  :next_marker)
  SENSITIVE = []
  include Aws::Structure
end