Class: Aws::WAFV2::Types::GetWebACLRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetWebACLRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the web ACL that you want to retrieve.
-
#id ⇒ String
The unique identifier for the web ACL.
-
#name ⇒ String
The name of the web ACL.
-
#scope ⇒ String
Specifies whether this is for a global resource type, such as a Amazon CloudFront distribution.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the web ACL that you want to retrieve.
4455 4456 4457 4458 4459 4460 4461 4462 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4455 class GetWebACLRequest < Struct.new( :name, :scope, :id, :arn) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier for the web ACL. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
4455 4456 4457 4458 4459 4460 4461 4462 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4455 class GetWebACLRequest < Struct.new( :name, :scope, :id, :arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the web ACL. You cannot change the name of a web ACL after you create it.
4455 4456 4457 4458 4459 4460 4461 4462 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4455 class GetWebACLRequest < Struct.new( :name, :scope, :id, :arn) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for a global resource type, such as a
Amazon CloudFront distribution. For an Amplify application, use
CLOUDFRONT.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope:
--scope=CLOUDFRONT --region=us-east-1. -
API and SDKs - For all calls, use the Region endpoint us-east-1.
4455 4456 4457 4458 4459 4460 4461 4462 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4455 class GetWebACLRequest < Struct.new( :name, :scope, :id, :arn) SENSITIVE = [] include Aws::Structure end |