Class: Aws::WAFV2::Types::GetWebACLResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lock_tokenString

A token used for optimistic locking. WAF returns a token to your `get` and `list` requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like `update` and `delete`. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a `WAFOptimisticLockException`. If this happens, perform another `get`, and use the new token returned by that operation.

Returns:

  • (String)


4274
4275
4276
4277
4278
4279
# File 'lib/aws-sdk-wafv2/types.rb', line 4274

class GetWebACLResponse < Struct.new(
  :web_acl,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end

#web_aclTypes::WebACL

The web ACL specification. You can modify the settings in this web ACL and use it to update this web ACL or create a new one.

Returns:



4274
4275
4276
4277
4278
4279
# File 'lib/aws-sdk-wafv2/types.rb', line 4274

class GetWebACLResponse < Struct.new(
  :web_acl,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end