Method: Aws::WAFV2::Types::GetWebACLResponse#lock_token

Defined in:
lib/aws-sdk-wafv2/types.rb

#lock_tokenString

A token used for optimistic locking. WAF returns a token to your get and list requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like update and delete. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a WAFOptimisticLockException. If this happens, perform another get, and use the new token returned by that operation.

Returns:

  • (String)


4192
4193
4194
4195
4196
4197
4198
# File 'lib/aws-sdk-wafv2/types.rb', line 4192

class GetWebACLResponse < Struct.new(
  :web_acl,
  :lock_token,
  :application_integration_url)
  SENSITIVE = []
  include Aws::Structure
end