Class: Aws::WAFV2::Types::HTTPHeader

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Part of the response from GetSampledRequests. This is a complex type that appears as Headers in the response syntax. HTTPHeader contains the names and values of all of the headers that appear in one of the web requests.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the HTTP header.

Returns:



4215
4216
4217
4218
4219
4220
# File 'lib/aws-sdk-wafv2/types.rb', line 4215

class HTTPHeader < Struct.new(
  :name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value of the HTTP header.

Returns:



4215
4216
4217
4218
4219
4220
# File 'lib/aws-sdk-wafv2/types.rb', line 4215

class HTTPHeader < Struct.new(
  :name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end