Class: Aws::WAFV2::Types::HeaderMatchPattern
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::HeaderMatchPattern
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
The filter to use to identify the subset of headers to inspect in a web request.
You must specify exactly one setting: either ‘All`, `IncludedHeaders`, or `ExcludedHeaders`.
Example JSON: ‘“MatchPattern”: { “ExcludedHeaders”: “KeyToExclude2” }`
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#all ⇒ Types::All
Inspect all headers.
-
#excluded_headers ⇒ Array<String>
Inspect only the headers whose keys don’t match any of the strings specified here.
-
#included_headers ⇒ Array<String>
Inspect only the headers that have a key that matches one of the strings specified here.
Instance Attribute Details
#all ⇒ Types::All
Inspect all headers.
3018 3019 3020 3021 3022 3023 3024 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3018 class HeaderMatchPattern < Struct.new( :all, :included_headers, :excluded_headers) SENSITIVE = [] include Aws::Structure end |
#excluded_headers ⇒ Array<String>
Inspect only the headers whose keys don’t match any of the strings specified here.
3018 3019 3020 3021 3022 3023 3024 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3018 class HeaderMatchPattern < Struct.new( :all, :included_headers, :excluded_headers) SENSITIVE = [] include Aws::Structure end |
#included_headers ⇒ Array<String>
Inspect only the headers that have a key that matches one of the strings specified here.
3018 3019 3020 3021 3022 3023 3024 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3018 class HeaderMatchPattern < Struct.new( :all, :included_headers, :excluded_headers) SENSITIVE = [] include Aws::Structure end |