Class: Aws::WAFV2::Types::Headers

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Inspect all headers in the web request. You can specify the parts of the headers to inspect and you can narrow the set of headers to inspect by including or excluding specific keys.

This is used to indicate the web request component to inspect, in the FieldToMatch specification.

If you want to inspect just the value of a single header, use the ‘SingleHeader` `FieldToMatch` setting instead.

Example JSON: ‘“Headers”: { “MatchPattern”: { “All”: {} }, “MatchScope”: “KEY”, “OversizeHandling”: “MATCH” }`

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#match_patternTypes::HeaderMatchPattern

The filter to use to identify the subset of headers to inspect in a web request.

You must specify exactly one setting: either ‘All`, `IncludedHeaders`, or `ExcludedHeaders`.

Example JSON: ‘“MatchPattern”: { “ExcludedHeaders”: “KeyToExclude2” }`



3277
3278
3279
3280
3281
3282
3283
# File 'lib/aws-sdk-wafv2/types.rb', line 3277

class Headers < Struct.new(
  :match_pattern,
  :match_scope,
  :oversize_handling)
  SENSITIVE = []
  include Aws::Structure
end

#match_scopeString

The parts of the headers to match with the rule inspection criteria. If you specify ‘All`, WAF inspects both keys and values.

Returns:

  • (String)


3277
3278
3279
3280
3281
3282
3283
# File 'lib/aws-sdk-wafv2/types.rb', line 3277

class Headers < Struct.new(
  :match_pattern,
  :match_scope,
  :oversize_handling)
  SENSITIVE = []
  include Aws::Structure
end

#oversize_handlingString

What WAF should do if the headers of the request are more numerous or larger than WAF can inspect. WAF does not support inspecting the entire contents of request headers when they exceed 8 KB (8192 bytes) or 200 total headers. The underlying host service forwards a maximum of 200 headers and at most 8 KB of header contents to WAF.

The options for oversize handling are the following:

  • ‘CONTINUE` - Inspect the available headers normally, according to the rule inspection criteria.

  • ‘MATCH` - Treat the web request as matching the rule statement. WAF applies the rule action to the request.

  • ‘NO_MATCH` - Treat the web request as not matching the rule statement.

Returns:

  • (String)


3277
3278
3279
3280
3281
3282
3283
# File 'lib/aws-sdk-wafv2/types.rb', line 3277

class Headers < Struct.new(
  :match_pattern,
  :match_scope,
  :oversize_handling)
  SENSITIVE = []
  include Aws::Structure
end