Class: Aws::WAFV2::Types::IPSet

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Contains zero or more IP addresses or blocks of IP addresses specified in Classless Inter-Domain Routing (CIDR) notation. WAF supports all IPv4 and IPv6 CIDR ranges except for /0. For information about CIDR notation, see the Wikipedia entry [Classless Inter-Domain Routing].

WAF assigns an ARN to each ‘IPSet` that you create. To use an IP set in a rule, you provide the ARN to the Rule statement IPSetReferenceStatement.

[1]: en.wikipedia.org/wiki/Classless_Inter-Domain_Routing

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#addressesArray<String>

Contains an array of strings that specifies zero or more IP addresses or blocks of IP addresses. All addresses must be specified using Classless Inter-Domain Routing (CIDR) notation. WAF supports all IPv4 and IPv6 CIDR ranges except for ‘/0`.

Example address strings:

  • To configure WAF to allow, block, or count requests that originated from the IP address 192.0.2.44, specify ‘192.0.2.44/32`.

  • To configure WAF to allow, block, or count requests that originated from IP addresses from 192.0.2.0 to 192.0.2.255, specify ‘192.0.2.0/24`.

  • To configure WAF to allow, block, or count requests that originated from the IP address 1111:0000:0000:0000:0000:0000:0000:0111, specify ‘1111:0000:0000:0000:0000:0000:0000:0111/128`.

  • To configure WAF to allow, block, or count requests that originated from IP addresses 1111:0000:0000:0000:0000:0000:0000:0000 to 1111:0000:0000:0000:ffff:ffff:ffff:ffff, specify ‘1111:0000:0000:0000:0000:0000:0000:0000/64`.

For more information about CIDR notation, see the Wikipedia entry [Classless Inter-Domain Routing].

Example JSON ‘Addresses` specifications:

  • Empty array: ‘“Addresses”: []`

  • Array with one address: ‘“Addresses”: [“192.0.2.44/32”]`

  • Array with three addresses: ‘“Addresses”: [“192.0.2.44/32”, “192.0.2.0/24”, “192.0.0.0/16”]`

  • INVALID specification: ‘“Addresses”: [“”]` INVALID

[1]: en.wikipedia.org/wiki/Classless_Inter-Domain_Routing

Returns:

  • (Array<String>)


3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
# File 'lib/aws-sdk-wafv2/types.rb', line 3303

class IPSet < Struct.new(
  :name,
  :id,
  :arn,
  :description,
  :ip_address_version,
  :addresses)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the entity.

Returns:

  • (String)


3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
# File 'lib/aws-sdk-wafv2/types.rb', line 3303

class IPSet < Struct.new(
  :name,
  :id,
  :arn,
  :description,
  :ip_address_version,
  :addresses)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the IP set that helps with identification.

Returns:

  • (String)


3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
# File 'lib/aws-sdk-wafv2/types.rb', line 3303

class IPSet < Struct.new(
  :name,
  :id,
  :arn,
  :description,
  :ip_address_version,
  :addresses)
  SENSITIVE = []
  include Aws::Structure
end

#idString

A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.

Returns:

  • (String)


3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
# File 'lib/aws-sdk-wafv2/types.rb', line 3303

class IPSet < Struct.new(
  :name,
  :id,
  :arn,
  :description,
  :ip_address_version,
  :addresses)
  SENSITIVE = []
  include Aws::Structure
end

#ip_address_versionString

The version of the IP addresses, either ‘IPV4` or `IPV6`.

Returns:

  • (String)


3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
# File 'lib/aws-sdk-wafv2/types.rb', line 3303

class IPSet < Struct.new(
  :name,
  :id,
  :arn,
  :description,
  :ip_address_version,
  :addresses)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the IP set. You cannot change the name of an ‘IPSet` after you create it.

Returns:

  • (String)


3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
# File 'lib/aws-sdk-wafv2/types.rb', line 3303

class IPSet < Struct.new(
  :name,
  :id,
  :arn,
  :description,
  :ip_address_version,
  :addresses)
  SENSITIVE = []
  include Aws::Structure
end