Class: Aws::WAFV2::Types::ImmunityTimeProperty
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ImmunityTimeProperty
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Note:
When making an API call, you may pass ImmunityTimeProperty data as a hash:
{
immunity_time: 1, # required
}
Determines how long a `CAPTCHA` token remains valid after the client successfully solves a `CAPTCHA` puzzle.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#immunity_time ⇒ Integer
The amount of time, in seconds, that a `CAPTCHA` token is valid.
Instance Attribute Details
#immunity_time ⇒ Integer
The amount of time, in seconds, that a `CAPTCHA` token is valid. The default setting is 300.
5657 5658 5659 5660 5661 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5657 class ImmunityTimeProperty < Struct.new( :immunity_time) SENSITIVE = [] include Aws::Structure end |