Class: Aws::WAFV2::Types::Label
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::Label
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
A single label container. This is used as an element of a label array in multiple contexts, for example, in RuleLabels inside a Rule and in Labels inside a SampledHTTPRequest.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The label string.
Instance Attribute Details
#name ⇒ String
The label string.
4945 4946 4947 4948 4949 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4945 class Label < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |