Class: Aws::WAFV2::Types::LabelSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::LabelSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
List of labels used by one or more of the rules of a RuleGroup. This summary object is used for the following rule group lists:
-
AvailableLabels- Labels that rules add to matching requests. These labels are defined in theRuleLabelsfor a Rule. -
ConsumedLabels- Labels that rules match against. These labels are defined in aLabelMatchStatementspecification, in the Statement definition of a rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
An individual label specification.
Instance Attribute Details
#name ⇒ String
An individual label specification.
5029 5030 5031 5032 5033 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5029 class LabelSummary < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |