Class: Aws::WAFV2::Types::ListLoggingConfigurationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ListLoggingConfigurationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#limit ⇒ Integer
The maximum number of objects that you want WAF to return for this request.
-
#log_scope ⇒ String
The owner of the logging configuration, which must be set to
CUSTOMERfor the configurations that you manage. -
#next_marker ⇒ String
When you request a list of objects with a
Limitsetting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns aNextMarkervalue in the response. -
#scope ⇒ String
Specifies whether this is for a global resource type, such as a Amazon CloudFront distribution.
Instance Attribute Details
#limit ⇒ Integer
The maximum number of objects that you want WAF to return for this request. If more objects are available, in the response, WAF provides a NextMarker value that you can use in a subsequent call to get the next batch of objects.
5182 5183 5184 5185 5186 5187 5188 5189 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5182 class ListLoggingConfigurationsRequest < Struct.new( :scope, :next_marker, :limit, :log_scope) SENSITIVE = [] include Aws::Structure end |
#log_scope ⇒ String
The owner of the logging configuration, which must be set to CUSTOMER for the configurations that you manage.
The log scope SECURITY_LAKE indicates a configuration that is managed through Amazon Security Lake. You can use Security Lake to collect log and event data from various sources for normalization, analysis, and management. For information, see [Collecting data from Amazon Web Services services] in the *Amazon Security Lake user guide*.
The log scope CLOUDWATCH_TELEMETRY_RULE_MANAGED indicates a configuration that is managed through Amazon CloudWatch Logs for telemetry data collection and analysis. For information, see [What is Amazon CloudWatch Logs ?][2] in the *Amazon CloudWatch Logs user guide*.
Default: CUSTOMER
[1]: docs.aws.amazon.com/security-lake/latest/userguide/internal-sources.html [2]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/WhatIsCloudWatchLogs.html
5182 5183 5184 5185 5186 5187 5188 5189 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5182 class ListLoggingConfigurationsRequest < Struct.new( :scope, :next_marker, :limit, :log_scope) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
When you request a list of objects with a Limit setting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns a NextMarker value in the response. To retrieve the next batch of objects, provide the marker from the prior call in your next request.
5182 5183 5184 5185 5186 5187 5188 5189 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5182 class ListLoggingConfigurationsRequest < Struct.new( :scope, :next_marker, :limit, :log_scope) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for a global resource type, such as a Amazon CloudFront distribution. For an Amplify application, use CLOUDFRONT.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope: ‘–scope=CLOUDFRONT –region=us-east-1`.
-
API and SDKs - For all calls, use the Region endpoint us-east-1.
5182 5183 5184 5185 5186 5187 5188 5189 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5182 class ListLoggingConfigurationsRequest < Struct.new( :scope, :next_marker, :limit, :log_scope) SENSITIVE = [] include Aws::Structure end |