Class: Aws::WAFV2::Types::ListRegexPatternSetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ListRegexPatternSetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#limit ⇒ Integer
The maximum number of objects that you want WAF to return for this request.
-
#next_marker ⇒ String
When you request a list of objects with a
Limitsetting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns aNextMarkervalue in the response. -
#scope ⇒ String
Specifies whether this is for a global resource type, such as a Amazon CloudFront distribution.
Instance Attribute Details
#limit ⇒ Integer
The maximum number of objects that you want WAF to return for this request. If more objects are available, in the response, WAF provides a NextMarker value that you can use in a subsequent call to get the next batch of objects.
5534 5535 5536 5537 5538 5539 5540 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5534 class ListRegexPatternSetsRequest < Struct.new( :scope, :next_marker, :limit) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
When you request a list of objects with a Limit setting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns a NextMarker value in the response. To retrieve the next batch of objects, provide the marker from the prior call in your next request.
5534 5535 5536 5537 5538 5539 5540 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5534 class ListRegexPatternSetsRequest < Struct.new( :scope, :next_marker, :limit) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for a global resource type, such as a Amazon CloudFront distribution. For an Amplify application, use CLOUDFRONT.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope: ‘–scope=CLOUDFRONT –region=us-east-1`.
-
API and SDKs - For all calls, use the Region endpoint us-east-1.
5534 5535 5536 5537 5538 5539 5540 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5534 class ListRegexPatternSetsRequest < Struct.new( :scope, :next_marker, :limit) SENSITIVE = [] include Aws::Structure end |