Class: Aws::WAFV2::Types::ListRuleGroupsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_markerString

When you request a list of objects with a Limit setting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns a NextMarker value in the response. To retrieve the next batch of objects, provide the marker from the prior call in your next request.

Returns:

  • (String)


5664
5665
5666
5667
5668
5669
# File 'lib/aws-sdk-wafv2/types.rb', line 5664

class ListRuleGroupsResponse < Struct.new(
  :next_marker,
  :rule_groups)
  SENSITIVE = []
  include Aws::Structure
end

#rule_groupsArray<Types::RuleGroupSummary>

Array of rule groups. If you specified a Limit in your request, this might not be the full list.

Returns:



5664
5665
5666
5667
5668
5669
# File 'lib/aws-sdk-wafv2/types.rb', line 5664

class ListRuleGroupsResponse < Struct.new(
  :next_marker,
  :rule_groups)
  SENSITIVE = []
  include Aws::Structure
end