Class: Aws::WAFV2::Types::ManagedRuleGroupStatement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

A rule statement used to run the rules that are defined in a managed rule group. To use this, provide the vendor name and the name of the rule group in this statement. You can retrieve the required names by calling ListAvailableManagedRuleGroups.

You cannot nest a ‘ManagedRuleGroupStatement`, for example for use inside a `NotStatement` or `OrStatement`. It can only be referenced as a top-level statement within a rule.

<note markdown=“1”> You are charged additional fees when you use the WAF Bot Control managed rule group ‘AWSManagedRulesBotControlRuleSet` or the WAF Fraud Control account takeover prevention (ATP) managed rule group `AWSManagedRulesATPRuleSet`. For more information, see [WAF Pricing].

</note>

[1]: aws.amazon.com/waf/pricing/

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#excluded_rulesArray<Types::ExcludedRule>

Rules in the referenced rule group whose actions are set to ‘Count`.

<note markdown=“1”> Instead of this option, use ‘RuleActionOverrides`. It accepts any valid action setting, including `Count`.

</note>

Returns:



4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
# File 'lib/aws-sdk-wafv2/types.rb', line 4825

class ManagedRuleGroupStatement < Struct.new(
  :vendor_name,
  :name,
  :version,
  :excluded_rules,
  :scope_down_statement,
  :managed_rule_group_configs,
  :rule_action_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#managed_rule_group_configsArray<Types::ManagedRuleGroupConfig>

Additional information that’s used by a managed rule group. Many managed rule groups don’t require this.

Use the ‘AWSManagedRulesATPRuleSet` configuration object for the account takeover prevention managed rule group, to provide information such as the sign-in page of your application and the type of content to accept or reject from the client.

Use the ‘AWSManagedRulesBotControlRuleSet` configuration object to configure the protection level that you want the Bot Control rule group to use.

Returns:



4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
# File 'lib/aws-sdk-wafv2/types.rb', line 4825

class ManagedRuleGroupStatement < Struct.new(
  :vendor_name,
  :name,
  :version,
  :excluded_rules,
  :scope_down_statement,
  :managed_rule_group_configs,
  :rule_action_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the managed rule group. You use this, along with the vendor name, to identify the rule group.

Returns:

  • (String)


4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
# File 'lib/aws-sdk-wafv2/types.rb', line 4825

class ManagedRuleGroupStatement < Struct.new(
  :vendor_name,
  :name,
  :version,
  :excluded_rules,
  :scope_down_statement,
  :managed_rule_group_configs,
  :rule_action_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#rule_action_overridesArray<Types::RuleActionOverride>

Action settings to use in the place of the rule actions that are configured inside the rule group. You specify one override for each rule whose action you want to change.

You can use overrides for testing, for example you can override all of rule actions to ‘Count` and then monitor the resulting count metrics to understand how the rule group would handle your web traffic. You can also permanently override some or all actions, to modify how the rule group manages your web traffic.

Returns:



4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
# File 'lib/aws-sdk-wafv2/types.rb', line 4825

class ManagedRuleGroupStatement < Struct.new(
  :vendor_name,
  :name,
  :version,
  :excluded_rules,
  :scope_down_statement,
  :managed_rule_group_configs,
  :rule_action_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#scope_down_statementTypes::Statement

An optional nested statement that narrows the scope of the web requests that are evaluated by the managed rule group. Requests are only evaluated by the rule group if they match the scope-down statement. You can use any nestable Statement in the scope-down statement, and you can nest statements at any level, the same as you can for a rule statement.

Returns:



4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
# File 'lib/aws-sdk-wafv2/types.rb', line 4825

class ManagedRuleGroupStatement < Struct.new(
  :vendor_name,
  :name,
  :version,
  :excluded_rules,
  :scope_down_statement,
  :managed_rule_group_configs,
  :rule_action_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#vendor_nameString

The name of the managed rule group vendor. You use this, along with the rule group name, to identify the rule group.

Returns:

  • (String)


4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
# File 'lib/aws-sdk-wafv2/types.rb', line 4825

class ManagedRuleGroupStatement < Struct.new(
  :vendor_name,
  :name,
  :version,
  :excluded_rules,
  :scope_down_statement,
  :managed_rule_group_configs,
  :rule_action_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version of the managed rule group to use. If you specify this, the version setting is fixed until you change it. If you don’t specify this, WAF uses the vendor’s default version, and then keeps the version at the vendor’s default when the vendor updates the managed rule group settings.

Returns:

  • (String)


4825
4826
4827
4828
4829
4830
4831
4832
4833
4834
4835
# File 'lib/aws-sdk-wafv2/types.rb', line 4825

class ManagedRuleGroupStatement < Struct.new(
  :vendor_name,
  :name,
  :version,
  :excluded_rules,
  :scope_down_statement,
  :managed_rule_group_configs,
  :rule_action_overrides)
  SENSITIVE = []
  include Aws::Structure
end