Class: Aws::WAFV2::Types::ManagedRuleGroupSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ManagedRuleGroupSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
High-level information about a managed rule group, returned by ListAvailableManagedRuleGroups. This provides information like the name and vendor name, that you provide when you add a ManagedRuleGroupStatement to a web ACL. Managed rule groups include Amazon Web Services Managed Rules rule groups, which are free of charge to WAF customers, and Amazon Web Services Marketplace managed rule groups, which you can subscribe to through Amazon Web Services Marketplace.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the managed rule group, provided by Amazon Web Services Managed Rules or the Amazon Web Services Marketplace seller who manages it.
-
#name ⇒ String
The name of the managed rule group.
-
#vendor_name ⇒ String
The name of the managed rule group vendor.
-
#versioning_supported ⇒ Boolean
Indicates whether the managed rule group is versioned.
Instance Attribute Details
#description ⇒ String
The description of the managed rule group, provided by Amazon Web Services Managed Rules or the Amazon Web Services Marketplace seller who manages it.
4817 4818 4819 4820 4821 4822 4823 4824 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4817 class ManagedRuleGroupSummary < Struct.new( :vendor_name, :name, :versioning_supported, :description) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the managed rule group. You use this, along with the vendor name, to identify the rule group.
4817 4818 4819 4820 4821 4822 4823 4824 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4817 class ManagedRuleGroupSummary < Struct.new( :vendor_name, :name, :versioning_supported, :description) SENSITIVE = [] include Aws::Structure end |
#vendor_name ⇒ String
The name of the managed rule group vendor. You use this, along with the rule group name, to identify the rule group.
4817 4818 4819 4820 4821 4822 4823 4824 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4817 class ManagedRuleGroupSummary < Struct.new( :vendor_name, :name, :versioning_supported, :description) SENSITIVE = [] include Aws::Structure end |
#versioning_supported ⇒ Boolean
Indicates whether the managed rule group is versioned. If it is, you can retrieve the versions list by calling ListAvailableManagedRuleGroupVersions.
4817 4818 4819 4820 4821 4822 4823 4824 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4817 class ManagedRuleGroupSummary < Struct.new( :vendor_name, :name, :versioning_supported, :description) SENSITIVE = [] include Aws::Structure end |