Class: Aws::WAFV2::Types::ManagedRuleSetVersion
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ManagedRuleSetVersion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Information for a single version of a managed rule set.
<note markdown=“1”> This is intended for use only by vendors of managed rule sets. Vendors are Amazon Web Services and Amazon Web Services Marketplace sellers.
Vendors, you can use the managed rule set APIs to provide controlled
rollout of your versioned managed rule group offerings for your customers. The APIs are `ListManagedRuleSets`, `GetManagedRuleSet`, `PutManagedRuleSetVersions`, and `UpdateManagedRuleSetVersionExpiryDate`.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_rule_group_arn ⇒ String
The Amazon Resource Name (ARN) of the vendor rule group that's used to define the published version of your managed rule group.
-
#capacity ⇒ Integer
The web ACL capacity units (WCUs) required for this rule group.
-
#expiry_timestamp ⇒ Time
The time that this version is set to expire.
-
#forecasted_lifetime ⇒ Integer
The amount of time you expect this version of your managed rule group to last, in days.
-
#last_update_timestamp ⇒ Time
The last time that you updated this version.
-
#publish_timestamp ⇒ Time
The time that you first published this version.
Instance Attribute Details
#associated_rule_group_arn ⇒ String
The Amazon Resource Name (ARN) of the vendor rule group that's used to define the published version of your managed rule group.
6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6360 class ManagedRuleSetVersion < Struct.new( :associated_rule_group_arn, :capacity, :forecasted_lifetime, :publish_timestamp, :last_update_timestamp, :expiry_timestamp) SENSITIVE = [] include Aws::Structure end |
#capacity ⇒ Integer
The web ACL capacity units (WCUs) required for this rule group.
WAF uses WCUs to calculate and control the operating resources that are used to run your rules, rule groups, and web ACLs. WAF calculates capacity differently for each rule type, to reflect the relative cost of each rule. Simple rules that cost little to run use fewer WCUs than more complex rules that use more processing power. Rule group capacity is fixed at creation, which helps users plan their web ACL WCU usage when they use a rule group. The WCU limit for web ACLs is 1,500.
6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6360 class ManagedRuleSetVersion < Struct.new( :associated_rule_group_arn, :capacity, :forecasted_lifetime, :publish_timestamp, :last_update_timestamp, :expiry_timestamp) SENSITIVE = [] include Aws::Structure end |
#expiry_timestamp ⇒ Time
The time that this version is set to expire.
Times are in Coordinated Universal Time (UTC) format. UTC format includes the special designator, Z. For example, “2016-09-27T14:50Z”.
6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6360 class ManagedRuleSetVersion < Struct.new( :associated_rule_group_arn, :capacity, :forecasted_lifetime, :publish_timestamp, :last_update_timestamp, :expiry_timestamp) SENSITIVE = [] include Aws::Structure end |
#forecasted_lifetime ⇒ Integer
The amount of time you expect this version of your managed rule group to last, in days.
6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6360 class ManagedRuleSetVersion < Struct.new( :associated_rule_group_arn, :capacity, :forecasted_lifetime, :publish_timestamp, :last_update_timestamp, :expiry_timestamp) SENSITIVE = [] include Aws::Structure end |
#last_update_timestamp ⇒ Time
The last time that you updated this version.
Times are in Coordinated Universal Time (UTC) format. UTC format includes the special designator, Z. For example, “2016-09-27T14:50Z”.
6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6360 class ManagedRuleSetVersion < Struct.new( :associated_rule_group_arn, :capacity, :forecasted_lifetime, :publish_timestamp, :last_update_timestamp, :expiry_timestamp) SENSITIVE = [] include Aws::Structure end |
#publish_timestamp ⇒ Time
The time that you first published this version.
Times are in Coordinated Universal Time (UTC) format. UTC format includes the special designator, Z. For example, “2016-09-27T14:50Z”.
6360 6361 6362 6363 6364 6365 6366 6367 6368 6369 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6360 class ManagedRuleSetVersion < Struct.new( :associated_rule_group_arn, :capacity, :forecasted_lifetime, :publish_timestamp, :last_update_timestamp, :expiry_timestamp) SENSITIVE = [] include Aws::Structure end |