Class: Aws::WAFV2::Types::Method Private
- Inherits:
-
EmptyStructure
- Object
- EmptyStructure
- Aws::WAFV2::Types::Method
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
The HTTP method of a web request. The method indicates the type of operation that the request is asking the origin to perform.
This is used only to indicate the web request component for WAF to inspect, in the FieldToMatch specification.
JSON specification: `“Method”: {}`