Class: Aws::WAFV2::Types::OnSourceDDoSProtectionConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::OnSourceDDoSProtectionConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Configures the level of DDoS protection that applies to web ACLs associated with Application Load Balancers.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alb_low_reputation_mode ⇒ String
The level of DDoS protection that applies to web ACLs associated with Application Load Balancers.
Instance Attribute Details
#alb_low_reputation_mode ⇒ String
The level of DDoS protection that applies to web ACLs associated with Application Load Balancers. ACTIVE_UNDER_DDOS protection is enabled by default whenever a web ACL is associated with an Application Load Balancer. In the event that an Application Load Balancer experiences high-load conditions or suspected DDoS attacks, the ACTIVE_UNDER_DDOS protection automatically rate limits traffic from known low reputation sources without disrupting Application Load Balancer availability. ALWAYS_ON protection provides constant, always-on monitoring of known low reputation sources for suspected DDoS attacks. While this provides a higher level of protection, there may be potential impacts on legitimate traffic.
6711 6712 6713 6714 6715 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6711 class OnSourceDDoSProtectionConfig < Struct.new( :alb_low_reputation_mode) SENSITIVE = [] include Aws::Structure end |