Class: Aws::WAFV2::Types::OrStatement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

A logical rule statement used to combine other rule statements with OR logic. You provide more than one Statement within the OrStatement.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#statementsArray<Types::Statement>

The statements to combine with OR logic. You can use any statements that can be nested.

Returns:



7251
7252
7253
7254
7255
# File 'lib/aws-sdk-wafv2/types.rb', line 7251

class OrStatement < Struct.new(
  :statements)
  SENSITIVE = []
  include Aws::Structure
end