Class: Aws::WAFV2::Types::OverrideAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::OverrideAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
When making an API call, you may pass OverrideAction data as a hash:
{
count: {
custom_request_handling: {
insert_headers: [ # required
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
},
},
none: {
},
}
The action to use in the place of the action that results from the rule group evaluation. Set the override action to none to leave the result of the rule group alone. Set it to count to override the result to count only.
You can only use this for rule statements that reference a rule group, like `RuleGroupReferenceStatement` and `ManagedRuleGroupStatement`.
<note markdown=“1”> This option is usually set to none. It does not affect how the rules in the rule group are evaluated. If you want the rules in the rule group to only count matches, do not use this and instead use the rule action override option, with `Count` action, in your rule group reference statement settings.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#count ⇒ Types::CountAction
Override the rule group evaluation result to count only.
-
#none ⇒ Types::NoneAction
Don't override the rule group evaluation result.
Instance Attribute Details
#count ⇒ Types::CountAction
Override the rule group evaluation result to count only.
<note markdown=“1”> This option is usually set to none. It does not affect how the rules in the rule group are evaluated. If you want the rules in the rule group to only count matches, do not use this and instead use the rule action override option, with `Count` action, in your rule group reference statement settings.
</note>
10033 10034 10035 10036 10037 10038 |
# File 'lib/aws-sdk-wafv2/types.rb', line 10033 class OverrideAction < Struct.new( :count, :none) SENSITIVE = [] include Aws::Structure end |
#none ⇒ Types::NoneAction
Don't override the rule group evaluation result. This is the most common setting.
10033 10034 10035 10036 10037 10038 |
# File 'lib/aws-sdk-wafv2/types.rb', line 10033 class OverrideAction < Struct.new( :count, :none) SENSITIVE = [] include Aws::Structure end |