Class: Aws::WAFV2::Types::PasswordField
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::PasswordField
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
The name of the field in the request payload that contains your customer’s password.
This data type is used in the RequestInspection and RequestInspectionACFP data types.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identifier ⇒ String
The name of the password field.
Instance Attribute Details
#identifier ⇒ String
The name of the password field.
How you specify this depends on the request inspection payload type.
-
For JSON payloads, specify the field name in JSON pointer syntax. For information about the JSON Pointer syntax, see the Internet Engineering Task Force (IETF) documentation [JavaScript Object Notation (JSON) Pointer].
For example, for the JSON payload ‘{ “form”: { “password”: “THE_PASSWORD” } }`, the password field specification is
/form/password. -
For form encoded payload types, use the HTML form names.
For example, for an HTML form with the input element named
password1, the password field specification ispassword1.
6807 6808 6809 6810 6811 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6807 class PasswordField < Struct.new( :identifier) SENSITIVE = [] include Aws::Structure end |