Class: Aws::WAFV2::Types::Price

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

The price per request for a payment network, specifying the amount and cryptocurrency.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amountString

The price per request as a decimal string in the specified currency. Minimum: 0.001. Maximum: 999999999.999. Supports up to 3 decimal places.

Returns:

  • (String)


7451
7452
7453
7454
7455
7456
# File 'lib/aws-sdk-wafv2/types.rb', line 7451

class Price < Struct.new(
  :amount,
  :currency)
  SENSITIVE = []
  include Aws::Structure
end

#currencyString

The cryptocurrency for payment. Currently only ‘USDC` is supported.

Returns:

  • (String)


7451
7452
7453
7454
7455
7456
# File 'lib/aws-sdk-wafv2/types.rb', line 7451

class Price < Struct.new(
  :amount,
  :currency)
  SENSITIVE = []
  include Aws::Structure
end