Class: Aws::WAFV2::Types::PutManagedRuleSetVersionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::PutManagedRuleSetVersionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
When making an API call, you may pass PutManagedRuleSetVersionsRequest data as a hash:
{
name: "EntityName", # required
scope: "CLOUDFRONT", # required, accepts CLOUDFRONT, REGIONAL
id: "EntityId", # required
lock_token: "LockToken", # required
recommended_version: "VersionKeyString",
versions_to_publish: {
"VersionKeyString" => {
associated_rule_group_arn: "ResourceArn",
forecasted_lifetime: 1,
},
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
A unique identifier for the managed rule set.
-
#lock_token ⇒ String
A token used for optimistic locking.
-
#name ⇒ String
The name of the managed rule set.
-
#recommended_version ⇒ String
The version of the named managed rule group that you'd like your customers to choose, from among your version offerings.
-
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application.
-
#versions_to_publish ⇒ Hash<String,Types::VersionToPublish>
The versions of the named managed rule group that you want to offer to your customers.
Instance Attribute Details
#id ⇒ String
A unique identifier for the managed rule set. The ID is returned in the responses to commands like `list`. You provide it to operations like `get` and `update`.
8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8993 class PutManagedRuleSetVersionsRequest < Struct.new( :name, :scope, :id, :lock_token, :recommended_version, :versions_to_publish) SENSITIVE = [] include Aws::Structure end |
#lock_token ⇒ String
A token used for optimistic locking. WAF returns a token to your `get` and `list` requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like `update` and `delete`. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a `WAFOptimisticLockException`. If this happens, perform another `get`, and use the new token returned by that operation.
8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8993 class PutManagedRuleSetVersionsRequest < Struct.new( :name, :scope, :id, :lock_token, :recommended_version, :versions_to_publish) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the managed rule set. You use this, along with the rule set ID, to identify the rule set.
This name is assigned to the corresponding managed rule group, which your customers can access and use.
8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8993 class PutManagedRuleSetVersionsRequest < Struct.new( :name, :scope, :id, :lock_token, :recommended_version, :versions_to_publish) SENSITIVE = [] include Aws::Structure end |
#recommended_version ⇒ String
The version of the named managed rule group that you'd like your customers to choose, from among your version offerings.
8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8993 class PutManagedRuleSetVersionsRequest < Struct.new( :name, :scope, :id, :lock_token, :recommended_version, :versions_to_publish) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope: `–scope=CLOUDFRONT –region=us-east-1`.
-
API and SDKs - For all calls, use the Region endpoint us-east-1.
8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8993 class PutManagedRuleSetVersionsRequest < Struct.new( :name, :scope, :id, :lock_token, :recommended_version, :versions_to_publish) SENSITIVE = [] include Aws::Structure end |
#versions_to_publish ⇒ Hash<String,Types::VersionToPublish>
The versions of the named managed rule group that you want to offer to your customers.
8993 8994 8995 8996 8997 8998 8999 9000 9001 9002 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8993 class PutManagedRuleSetVersionsRequest < Struct.new( :name, :scope, :id, :lock_token, :recommended_version, :versions_to_publish) SENSITIVE = [] include Aws::Structure end |