Class: Aws::WAFV2::Types::PutManagedRuleSetVersionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::PutManagedRuleSetVersionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_lock_token ⇒ String
A token used for optimistic locking.
Instance Attribute Details
#next_lock_token ⇒ String
A token used for optimistic locking. WAF returns a token to your get and list requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like update and delete. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a WAFOptimisticLockException. If this happens, perform another get, and use the new token returned by that operation.
6995 6996 6997 6998 6999 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6995 class PutManagedRuleSetVersionsResponse < Struct.new( :next_lock_token) SENSITIVE = [] include Aws::Structure end |