Class: Aws::WAFV2::Types::PutPermissionPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass PutPermissionPolicyRequest data as a hash:

{
  resource_arn: "ResourceArn", # required
  policy: "PolicyString", # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policyString

The policy to attach to the specified rule group.

The policy specifications must conform to the following:

  • The policy must be composed using IAM Policy version 2012-10-17 or version 2015-01-01.

  • The policy must include specifications for `Effect`, `Action`, and `Principal`.

  • `Effect` must specify `Allow`.

  • `Action` must specify `wafv2:CreateWebACL`, `wafv2:UpdateWebACL`, and `wafv2:PutFirewallManagerRuleGroups` and may optionally specify `wafv2:GetRuleGroup`. WAF rejects any extra actions or wildcard actions in the policy.

  • The policy must not include a `Resource` parameter.

For more information, see [IAM Policies].

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html

Returns:

  • (String)


9099
9100
9101
9102
9103
9104
# File 'lib/aws-sdk-wafv2/types.rb', line 9099

class PutPermissionPolicyRequest < Struct.new(
  :resource_arn,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

The Amazon Resource Name (ARN) of the RuleGroup to which you want to attach the policy.

Returns:

  • (String)


9099
9100
9101
9102
9103
9104
# File 'lib/aws-sdk-wafv2/types.rb', line 9099

class PutPermissionPolicyRequest < Struct.new(
  :resource_arn,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end