Class: Aws::WAFV2::Types::Regex

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

A single regular expression. This is used in a RegexPatternSet and also in the configuration for the Amazon Web Services Managed Rules rule group AWSManagedRulesAntiDDoSRuleSet.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#regex_stringString

The string representing the regular expression. WAF enforces a quota on the maximum number of characters in a regex pattern. For the current limit, see WAF quotas in the WAF Developer Guide.

Returns:

  • (String)


8358
8359
8360
8361
8362
# File 'lib/aws-sdk-wafv2/types.rb', line 8358

class Regex < Struct.new(
  :regex_string)
  SENSITIVE = []
  include Aws::Structure
end