Class: Aws::WAFV2::Types::RegexMatchStatement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

A rule statement used to search web request components for a match against a single regular expression.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#field_to_matchTypes::FieldToMatch

The part of the web request that you want WAF to inspect.

Returns:



8404
8405
8406
8407
8408
8409
8410
8411
# File 'lib/aws-sdk-wafv2/types.rb', line 8404

class RegexMatchStatement < Struct.new(
  :regex_string,
  :field_to_match,
  :text_transformations,
  :pre_parse_text_transformations)
  SENSITIVE = []
  include Aws::Structure
end

#pre_parse_text_transformationsArray<Types::PreParseTextTransformation>

Pre-parse text transformations normalize the raw query string before WAF parses it into individual query arguments. They are applied before the standard text transformations. Pre-parse text transformations are only supported when FieldToMatch is SingleQueryArgument or AllQueryArguments. You can specify up to 3 pre-parse text transformations per rule statement.



8404
8405
8406
8407
8408
8409
8410
8411
# File 'lib/aws-sdk-wafv2/types.rb', line 8404

class RegexMatchStatement < Struct.new(
  :regex_string,
  :field_to_match,
  :text_transformations,
  :pre_parse_text_transformations)
  SENSITIVE = []
  include Aws::Structure
end

#regex_stringString

The string representing the regular expression. WAF enforces a quota on the maximum number of characters in a regex pattern. For the current limit, see WAF quotas in the WAF Developer Guide.

Returns:

  • (String)


8404
8405
8406
8407
8408
8409
8410
8411
# File 'lib/aws-sdk-wafv2/types.rb', line 8404

class RegexMatchStatement < Struct.new(
  :regex_string,
  :field_to_match,
  :text_transformations,
  :pre_parse_text_transformations)
  SENSITIVE = []
  include Aws::Structure
end

#text_transformationsArray<Types::TextTransformation>

Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. Text transformations are used in rule match statements, to transform the FieldToMatch request component before inspecting it, and they're used in rate-based rule statements, to transform request components before using them as custom aggregation keys. If you specify one or more transformations to apply, WAF performs all transformations on the specified content, starting from the lowest priority setting, and then uses the transformed component contents.

Returns:



8404
8405
8406
8407
8408
8409
8410
8411
# File 'lib/aws-sdk-wafv2/types.rb', line 8404

class RegexMatchStatement < Struct.new(
  :regex_string,
  :field_to_match,
  :text_transformations,
  :pre_parse_text_transformations)
  SENSITIVE = []
  include Aws::Structure
end