Class: Aws::WAFV2::Types::RegexPatternSetReferenceStatement
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::RegexPatternSetReferenceStatement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
A rule statement used to search web request components for matches with regular expressions. To use this, create a RegexPatternSet that specifies the expressions that you want to detect, then use the ARN of that set in this statement. A web request matches the pattern set rule statement if the request component matches any of the patterns in the set. To create a regex pattern set, see CreateRegexPatternSet.
Each regex pattern set rule statement references a regex pattern set. You create and maintain the set independent of your rules. This allows you to use the single set in multiple rules. When you update the referenced set, WAF automatically updates all rules that reference it.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the RegexPatternSet that this statement references.
-
#field_to_match ⇒ Types::FieldToMatch
The part of the web request that you want WAF to inspect.
-
#pre_parse_text_transformations ⇒ Array<Types::PreParseTextTransformation>
Pre-parse text transformations normalize the raw query string before WAF parses it into individual query arguments.
-
#text_transformations ⇒ Array<Types::TextTransformation>
Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the RegexPatternSet that this statement references.
8498 8499 8500 8501 8502 8503 8504 8505 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8498 class RegexPatternSetReferenceStatement < Struct.new( :arn, :field_to_match, :text_transformations, :pre_parse_text_transformations) SENSITIVE = [] include Aws::Structure end |
#field_to_match ⇒ Types::FieldToMatch
The part of the web request that you want WAF to inspect.
8498 8499 8500 8501 8502 8503 8504 8505 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8498 class RegexPatternSetReferenceStatement < Struct.new( :arn, :field_to_match, :text_transformations, :pre_parse_text_transformations) SENSITIVE = [] include Aws::Structure end |
#pre_parse_text_transformations ⇒ Array<Types::PreParseTextTransformation>
Pre-parse text transformations normalize the raw query string before
WAF parses it into individual query arguments. They are applied
before the standard text transformations. Pre-parse text
transformations are only supported when FieldToMatch is
SingleQueryArgument or AllQueryArguments. You can specify up to
3 pre-parse text transformations per rule statement.
8498 8499 8500 8501 8502 8503 8504 8505 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8498 class RegexPatternSetReferenceStatement < Struct.new( :arn, :field_to_match, :text_transformations, :pre_parse_text_transformations) SENSITIVE = [] include Aws::Structure end |
#text_transformations ⇒ Array<Types::TextTransformation>
Text transformations eliminate some of the unusual formatting that
attackers use in web requests in an effort to bypass detection. Text
transformations are used in rule match statements, to transform the
FieldToMatch request component before inspecting it, and they're
used in rate-based rule statements, to transform request components
before using them as custom aggregation keys. If you specify one or
more transformations to apply, WAF performs all transformations on
the specified content, starting from the lowest priority setting,
and then uses the transformed component contents.
8498 8499 8500 8501 8502 8503 8504 8505 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8498 class RegexPatternSetReferenceStatement < Struct.new( :arn, :field_to_match, :text_transformations, :pre_parse_text_transformations) SENSITIVE = [] include Aws::Structure end |