Class: Aws::WAFV2::Types::RegexPatternSetSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

High-level information about a RegexPatternSet, returned by operations like create and list. This provides information like the ID, that you can use to retrieve and manage a RegexPatternSet, and the ARN, that you provide to the RegexPatternSetReferenceStatement to use the pattern set in a Rule.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the entity.

Returns:

  • (String)


7904
7905
7906
7907
7908
7909
7910
7911
7912
# File 'lib/aws-sdk-wafv2/types.rb', line 7904

class RegexPatternSetSummary < Struct.new(
  :name,
  :id,
  :description,
  :lock_token,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the set that helps with identification.

Returns:

  • (String)


7904
7905
7906
7907
7908
7909
7910
7911
7912
# File 'lib/aws-sdk-wafv2/types.rb', line 7904

class RegexPatternSetSummary < Struct.new(
  :name,
  :id,
  :description,
  :lock_token,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#idString

A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.

Returns:

  • (String)


7904
7905
7906
7907
7908
7909
7910
7911
7912
# File 'lib/aws-sdk-wafv2/types.rb', line 7904

class RegexPatternSetSummary < Struct.new(
  :name,
  :id,
  :description,
  :lock_token,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#lock_tokenString

A token used for optimistic locking. WAF returns a token to your get and list requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like update and delete. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a WAFOptimisticLockException. If this happens, perform another get, and use the new token returned by that operation.

Returns:

  • (String)


7904
7905
7906
7907
7908
7909
7910
7911
7912
# File 'lib/aws-sdk-wafv2/types.rb', line 7904

class RegexPatternSetSummary < Struct.new(
  :name,
  :id,
  :description,
  :lock_token,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the data type instance. You cannot change the name after you create the instance.

Returns:

  • (String)


7904
7905
7906
7907
7908
7909
7910
7911
7912
# File 'lib/aws-sdk-wafv2/types.rb', line 7904

class RegexPatternSetSummary < Struct.new(
  :name,
  :id,
  :description,
  :lock_token,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end