Class: Aws::WAFV2::Types::RequestBodyAssociatedResourceTypeConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Customizes the maximum size of the request body that your protected CloudFront distributions forward to WAF for inspection. The default size is 16 KB (16,384 bytes).

<note markdown=“1”> You are charged additional fees when your protected resources forward body sizes that are larger than the default. For more information, see [WAF Pricing].

</note>

This is used in the ‘AssociationConfig` of the web ACL.

[1]: aws.amazon.com/waf/pricing/

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_size_inspection_limitString

Specifies the maximum size of the web request body component that an associated CloudFront distribution should send to WAF for inspection. This applies to statements in the web ACL that inspect the body or JSON body.

Default: ‘16 KB (16,384 bytes)`

Returns:

  • (String)


6814
6815
6816
6817
6818
# File 'lib/aws-sdk-wafv2/types.rb', line 6814

class RequestBodyAssociatedResourceTypeConfig < Struct.new(
  :default_size_inspection_limit)
  SENSITIVE = []
  include Aws::Structure
end