Class: Aws::WAFV2::Types::ResponseInspection
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ResponseInspection
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
The criteria for inspecting responses to login requests, used by the ATP rule group to track login failure rates.
The ATP rule group evaluates the responses that your protected resources send back to client login attempts, keeping count of successful and failed attempts from each IP address and client session. Using this information, the rule group labels and mitigates requests from client sessions and IP addresses that submit too many failed login attempts in a short amount of time.
<note markdown=“1”> Response inspection is available only in web ACLs that protect Amazon CloudFront distributions.
</note>
This is part of the ‘AWSManagedRulesATPRuleSet` configuration in `ManagedRuleGroupConfig`.
Enable login response inspection by configuring exactly one component of the response to inspect. You can’t configure more than one. If you don’t configure any of the response inspection options, response inspection is disabled.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#body_contains ⇒ Types::ResponseInspectionBodyContains
Configures inspection of the response body.
-
#header ⇒ Types::ResponseInspectionHeader
Configures inspection of the response header.
-
#json ⇒ Types::ResponseInspectionJson
Configures inspection of the response JSON.
-
#status_code ⇒ Types::ResponseInspectionStatusCode
Configures inspection of the response status code.
Instance Attribute Details
#body_contains ⇒ Types::ResponseInspectionBodyContains
Configures inspection of the response body. WAF can inspect the first 65,536 bytes (64 KB) of the response body.
5862 5863 5864 5865 5866 5867 5868 5869 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5862 class ResponseInspection < Struct.new( :status_code, :header, :body_contains, :json) SENSITIVE = [] include Aws::Structure end |
#header ⇒ Types::ResponseInspectionHeader
Configures inspection of the response header.
5862 5863 5864 5865 5866 5867 5868 5869 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5862 class ResponseInspection < Struct.new( :status_code, :header, :body_contains, :json) SENSITIVE = [] include Aws::Structure end |
#json ⇒ Types::ResponseInspectionJson
Configures inspection of the response JSON. WAF can inspect the first 65,536 bytes (64 KB) of the response JSON.
5862 5863 5864 5865 5866 5867 5868 5869 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5862 class ResponseInspection < Struct.new( :status_code, :header, :body_contains, :json) SENSITIVE = [] include Aws::Structure end |
#status_code ⇒ Types::ResponseInspectionStatusCode
Configures inspection of the response status code.
5862 5863 5864 5865 5866 5867 5868 5869 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5862 class ResponseInspection < Struct.new( :status_code, :header, :body_contains, :json) SENSITIVE = [] include Aws::Structure end |