Class: Aws::WAFV2::Types::ResponseInspectionHeader

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Configures inspection of the response header. This is part of the ResponseInspection configuration for AWSManagedRulesATPRuleSet and AWSManagedRulesACFPRuleSet.

Response inspection is available only in web ACLs that protect Amazon CloudFront distributions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failure_valuesArray<String>

Values in the response header with the specified name that indicate a failed login or account creation attempt. To be counted as a failure, the value must be an exact match, including case. Each value must be unique among the success and failure values.

JSON examples: "FailureValues": [ "LoginFailed", "Failed login" ] and "FailureValues": [ "AccountCreationFailed" ]

Returns:

  • (Array<String>)


9001
9002
9003
9004
9005
9006
9007
# File 'lib/aws-sdk-wafv2/types.rb', line 9001

class ResponseInspectionHeader < Struct.new(
  :name,
  :success_values,
  :failure_values)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the header to match against. The name must be an exact match, including case.

JSON example: "Name": [ "RequestResult" ]

Returns:

  • (String)


9001
9002
9003
9004
9005
9006
9007
# File 'lib/aws-sdk-wafv2/types.rb', line 9001

class ResponseInspectionHeader < Struct.new(
  :name,
  :success_values,
  :failure_values)
  SENSITIVE = []
  include Aws::Structure
end

#success_valuesArray<String>

Values in the response header with the specified name that indicate a successful login or account creation attempt. To be counted as a success, the value must be an exact match, including case. Each value must be unique among the success and failure values.

JSON examples: "SuccessValues": [ "LoginPassed", "Successful login" ] and "SuccessValues": [ "AccountCreated", "Successful account creation" ]

Returns:

  • (Array<String>)


9001
9002
9003
9004
9005
9006
9007
# File 'lib/aws-sdk-wafv2/types.rb', line 9001

class ResponseInspectionHeader < Struct.new(
  :name,
  :success_values,
  :failure_values)
  SENSITIVE = []
  include Aws::Structure
end