Class: Aws::WAFV2::Types::ResponseInspectionStatusCode
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ResponseInspectionStatusCode
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Configures inspection of the response status code. This is part of the
ResponseInspection configuration for AWSManagedRulesATPRuleSet and
AWSManagedRulesACFPRuleSet.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failure_codes ⇒ Array<Integer>
Status codes in the response that indicate a failed login or account creation attempt.
-
#success_codes ⇒ Array<Integer>
Status codes in the response that indicate a successful login or account creation attempt.
Instance Attribute Details
#failure_codes ⇒ Array<Integer>
Status codes in the response that indicate a failed login or account creation attempt. To be counted as a failure, the response status code must match one of these. Each code must be unique among the success and failure status codes.
JSON example: "FailureCodes": [ 400, 404 ]
9017 9018 9019 9020 9021 9022 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9017 class ResponseInspectionStatusCode < Struct.new( :success_codes, :failure_codes) SENSITIVE = [] include Aws::Structure end |
#success_codes ⇒ Array<Integer>
Status codes in the response that indicate a successful login or account creation attempt. To be counted as a success, the response status code must match one of these. Each code must be unique among the success and failure status codes.
JSON example: "SuccessCodes": [ 200, 201 ]
9017 9018 9019 9020 9021 9022 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9017 class ResponseInspectionStatusCode < Struct.new( :success_codes, :failure_codes) SENSITIVE = [] include Aws::Structure end |