Class: Aws::WAFV2::Types::RevenuePathStatistics
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::RevenuePathStatistics
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Revenue statistics for a single content path, including the path, revenue amount, and request count.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amount ⇒ String
The total revenue amount from this path in the specified currency.
-
#path ⇒ String
The URI path.
-
#percentage ⇒ Float
The percentage of total revenue from this path.
-
#request_count ⇒ Integer
The number of monetized requests to this path.
Instance Attribute Details
#amount ⇒ String
The total revenue amount from this path in the specified currency.
9162 9163 9164 9165 9166 9167 9168 9169 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9162 class RevenuePathStatistics < Struct.new( :path, :percentage, :amount, :request_count) SENSITIVE = [] include Aws::Structure end |
#path ⇒ String
The URI path.
9162 9163 9164 9165 9166 9167 9168 9169 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9162 class RevenuePathStatistics < Struct.new( :path, :percentage, :amount, :request_count) SENSITIVE = [] include Aws::Structure end |
#percentage ⇒ Float
The percentage of total revenue from this path.
9162 9163 9164 9165 9166 9167 9168 9169 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9162 class RevenuePathStatistics < Struct.new( :path, :percentage, :amount, :request_count) SENSITIVE = [] include Aws::Structure end |
#request_count ⇒ Integer
The number of monetized requests to this path.
9162 9163 9164 9165 9166 9167 9168 9169 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9162 class RevenuePathStatistics < Struct.new( :path, :percentage, :amount, :request_count) SENSITIVE = [] include Aws::Structure end |