Class: Aws::WAFV2::Types::RuleActionOverride
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::RuleActionOverride
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Action setting to use in the place of a rule action that is configured inside the rule group. You specify one override for each rule whose action you want to change.
You can use overrides for testing, for example you can override all of rule actions to ‘Count` and then monitor the resulting count metrics to understand how the rule group would handle your web traffic. You can also permanently override some or all actions, to modify how the rule group manages your web traffic.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_to_use ⇒ Types::RuleAction
The override action to use, in place of the configured action of the rule in the rule group.
-
#name ⇒ String
The name of the rule to override.
Instance Attribute Details
#action_to_use ⇒ Types::RuleAction
The override action to use, in place of the configured action of the rule in the rule group.
7417 7418 7419 7420 7421 7422 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7417 class RuleActionOverride < Struct.new( :name, :action_to_use) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule to override.
7417 7418 7419 7420 7421 7422 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7417 class RuleActionOverride < Struct.new( :name, :action_to_use) SENSITIVE = [] include Aws::Structure end |