Class: Aws::WAFV2::Types::RuleGroupReferenceStatement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

A rule statement used to run the rules that are defined in a RuleGroup. To use this, create a rule group with your rules, then provide the ARN of the rule group in this statement.

You cannot nest a ‘RuleGroupReferenceStatement`, for example for use inside a `NotStatement` or `OrStatement`. You can only use a rule group reference statement at the top level inside a web ACL.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the entity.

Returns:

  • (String)


6146
6147
6148
6149
6150
6151
6152
# File 'lib/aws-sdk-wafv2/types.rb', line 6146

class RuleGroupReferenceStatement < Struct.new(
  :arn,
  :excluded_rules,
  :rule_action_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#excluded_rulesArray<Types::ExcludedRule>

Rules in the referenced rule group whose actions are set to ‘Count`.

<note markdown=“1”> Instead of this option, use ‘RuleActionOverrides`. It accepts any valid action setting, including `Count`.

</note>

Returns:



6146
6147
6148
6149
6150
6151
6152
# File 'lib/aws-sdk-wafv2/types.rb', line 6146

class RuleGroupReferenceStatement < Struct.new(
  :arn,
  :excluded_rules,
  :rule_action_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#rule_action_overridesArray<Types::RuleActionOverride>

Action settings to use in the place of the rule actions that are configured inside the rule group. You specify one override for each rule whose action you want to change.

You can use overrides for testing, for example you can override all of rule actions to ‘Count` and then monitor the resulting count metrics to understand how the rule group would handle your web traffic. You can also permanently override some or all actions, to modify how the rule group manages your web traffic.

Returns:



6146
6147
6148
6149
6150
6151
6152
# File 'lib/aws-sdk-wafv2/types.rb', line 6146

class RuleGroupReferenceStatement < Struct.new(
  :arn,
  :excluded_rules,
  :rule_action_overrides)
  SENSITIVE = []
  include Aws::Structure
end