Class: Aws::WAFV2::Types::SampledHTTPRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Represents a single sampled web request. The response from GetSampledRequests includes a ‘SampledHTTPRequests` complex type that appears as `SampledRequests` in the response syntax. `SampledHTTPRequests` contains an array of `SampledHTTPRequest` objects.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action that WAF applied to the request.

Returns:

  • (String)


6203
6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
# File 'lib/aws-sdk-wafv2/types.rb', line 6203

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response,
  :challenge_response,
  :overridden_action)
  SENSITIVE = []
  include Aws::Structure
end

#captcha_responseTypes::CaptchaResponse

The ‘CAPTCHA` response for the request.



6203
6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
# File 'lib/aws-sdk-wafv2/types.rb', line 6203

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response,
  :challenge_response,
  :overridden_action)
  SENSITIVE = []
  include Aws::Structure
end

#challenge_responseTypes::ChallengeResponse

The ‘Challenge` response for the request.



6203
6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
# File 'lib/aws-sdk-wafv2/types.rb', line 6203

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response,
  :challenge_response,
  :overridden_action)
  SENSITIVE = []
  include Aws::Structure
end

#labelsArray<Types::Label>

Labels applied to the web request by matching rules. WAF applies fully qualified labels to matching web requests. A fully qualified label is the concatenation of a label namespace and a rule label. The rule’s rule group or web ACL defines the label namespace.

For example, ‘awswaf:111122223333:myRuleGroup:testRules:testNS1:testNS2:labelNameA` or `awswaf:managed:aws:managed-rule-set:header:encoding:utf8`.

Returns:



6203
6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
# File 'lib/aws-sdk-wafv2/types.rb', line 6203

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response,
  :challenge_response,
  :overridden_action)
  SENSITIVE = []
  include Aws::Structure
end

#overridden_actionString

Used only for rule group rules that have a rule action override in place in the web ACL. This is the action that the rule group rule is configured for, and not the action that was applied to the request. The action that WAF applied is the ‘Action` value.

Returns:

  • (String)


6203
6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
# File 'lib/aws-sdk-wafv2/types.rb', line 6203

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response,
  :challenge_response,
  :overridden_action)
  SENSITIVE = []
  include Aws::Structure
end

#requestTypes::HTTPRequest

A complex type that contains detailed information about the request.

Returns:



6203
6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
# File 'lib/aws-sdk-wafv2/types.rb', line 6203

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response,
  :challenge_response,
  :overridden_action)
  SENSITIVE = []
  include Aws::Structure
end

#request_headers_insertedArray<Types::HTTPHeader>

Custom request headers inserted by WAF into the request, according to the custom request configuration for the matching rule action.

Returns:



6203
6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
# File 'lib/aws-sdk-wafv2/types.rb', line 6203

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response,
  :challenge_response,
  :overridden_action)
  SENSITIVE = []
  include Aws::Structure
end

#response_code_sentInteger

The response code that was sent for the request.

Returns:

  • (Integer)


6203
6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
# File 'lib/aws-sdk-wafv2/types.rb', line 6203

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response,
  :challenge_response,
  :overridden_action)
  SENSITIVE = []
  include Aws::Structure
end

#rule_name_within_rule_groupString

The name of the ‘Rule` that the request matched. For managed rule groups, the format for this name is `<vendor name>#<managed rule group name>#<rule name>`. For your own rule groups, the format for this name is `<rule group name>#<rule name>`. If the rule is not in a rule group, this field is absent.

Returns:

  • (String)


6203
6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
# File 'lib/aws-sdk-wafv2/types.rb', line 6203

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response,
  :challenge_response,
  :overridden_action)
  SENSITIVE = []
  include Aws::Structure
end

#timestampTime

The time at which WAF received the request from your Amazon Web Services resource, in Unix time format (in seconds).

Returns:

  • (Time)


6203
6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
# File 'lib/aws-sdk-wafv2/types.rb', line 6203

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response,
  :challenge_response,
  :overridden_action)
  SENSITIVE = []
  include Aws::Structure
end

#weightInteger

A value that indicates how one result in the response relates proportionally to other results in the response. For example, a result that has a weight of ‘2` represents roughly twice as many web requests as a result that has a weight of `1`.

Returns:

  • (Integer)


6203
6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
6214
6215
6216
6217
# File 'lib/aws-sdk-wafv2/types.rb', line 6203

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response,
  :challenge_response,
  :overridden_action)
  SENSITIVE = []
  include Aws::Structure
end