Class: Aws::WAFV2::Types::SqliMatchStatement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

A rule statement that inspects for malicious SQL code. Attackers insert malicious SQL code into web requests to do things like modify your database or extract data from it.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#field_to_matchTypes::FieldToMatch

The part of the web request that you want WAF to inspect.

Returns:



10092
10093
10094
10095
10096
10097
10098
10099
# File 'lib/aws-sdk-wafv2/types.rb', line 10092

class SqliMatchStatement < Struct.new(
  :field_to_match,
  :text_transformations,
  :pre_parse_text_transformations,
  :sensitivity_level)
  SENSITIVE = []
  include Aws::Structure
end

#pre_parse_text_transformationsArray<Types::PreParseTextTransformation>

Pre-parse text transformations normalize the raw query string before WAF parses it into individual query arguments. They are applied before the standard text transformations. Pre-parse text transformations are only supported when FieldToMatch is SingleQueryArgument or AllQueryArguments. You can specify up to 3 pre-parse text transformations per rule statement.



10092
10093
10094
10095
10096
10097
10098
10099
# File 'lib/aws-sdk-wafv2/types.rb', line 10092

class SqliMatchStatement < Struct.new(
  :field_to_match,
  :text_transformations,
  :pre_parse_text_transformations,
  :sensitivity_level)
  SENSITIVE = []
  include Aws::Structure
end

#sensitivity_levelString

The sensitivity that you want WAF to use to inspect for SQL injection attacks.

HIGH detects more attacks, but might generate more false positives, especially if your web requests frequently contain unusual strings. For information about identifying and mitigating false positives, see Testing and tuning in the WAF Developer Guide.

LOW is generally a better choice for resources that already have other protections against SQL injection attacks or that have a low tolerance for false positives.

Default: LOW

Returns:

  • (String)


10092
10093
10094
10095
10096
10097
10098
10099
# File 'lib/aws-sdk-wafv2/types.rb', line 10092

class SqliMatchStatement < Struct.new(
  :field_to_match,
  :text_transformations,
  :pre_parse_text_transformations,
  :sensitivity_level)
  SENSITIVE = []
  include Aws::Structure
end

#text_transformationsArray<Types::TextTransformation>

Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. Text transformations are used in rule match statements, to transform the FieldToMatch request component before inspecting it, and they're used in rate-based rule statements, to transform request components before using them as custom aggregation keys. If you specify one or more transformations to apply, WAF performs all transformations on the specified content, starting from the lowest priority setting, and then uses the transformed component contents.

Returns:



10092
10093
10094
10095
10096
10097
10098
10099
# File 'lib/aws-sdk-wafv2/types.rb', line 10092

class SqliMatchStatement < Struct.new(
  :field_to_match,
  :text_transformations,
  :pre_parse_text_transformations,
  :sensitivity_level)
  SENSITIVE = []
  include Aws::Structure
end