Class: Aws::WAFV2::Types::TextTransformation
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::TextTransformation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#priority ⇒ Integer
Sets the relative processing order for multiple transformations.
-
#type ⇒ String
For detailed descriptions of each of the transformation types, see [Text transformations][1] in the WAF Developer Guide.
Instance Attribute Details
#priority ⇒ Integer
Sets the relative processing order for multiple transformations. WAF processes all transformations, from lowest priority to highest, before inspecting the transformed content. The priorities don't need to be consecutive, but they must all be different.
10535 10536 10537 10538 10539 10540 |
# File 'lib/aws-sdk-wafv2/types.rb', line 10535 class TextTransformation < Struct.new( :priority, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
For detailed descriptions of each of the transformation types, see Text transformations in the WAF Developer Guide.
10535 10536 10537 10538 10539 10540 |
# File 'lib/aws-sdk-wafv2/types.rb', line 10535 class TextTransformation < Struct.new( :priority, :type) SENSITIVE = [] include Aws::Structure end |