Method: Aws::WAFV2::Types::UpdateManagedRuleSetVersionExpiryDateRequest#lock_token

Defined in:
lib/aws-sdk-wafv2/types.rb

#lock_tokenString

A token used for optimistic locking. WAF returns a token to your get and list requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like update and delete. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a WAFOptimisticLockException. If this happens, perform another get, and use the new token returned by that operation.

Returns:

  • (String)


9830
9831
9832
9833
9834
9835
9836
9837
9838
9839
# File 'lib/aws-sdk-wafv2/types.rb', line 9830

class UpdateManagedRuleSetVersionExpiryDateRequest < Struct.new(
  :name,
  :scope,
  :id,
  :lock_token,
  :version_to_expire,
  :expiry_timestamp)
  SENSITIVE = []
  include Aws::Structure
end