Class: Aws::WAFV2::Types::VersionToPublish
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::VersionToPublish
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
A version of the named managed rule group, that the rule group's vendor publishes for use by customers.
Vendors, you can use the managed rule set APIs to provide controlled
rollout of your versioned managed rule group offerings for your
customers. The APIs are ListManagedRuleSets, GetManagedRuleSet,
PutManagedRuleSetVersions, and
UpdateManagedRuleSetVersionExpiryDate.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_rule_group_arn ⇒ String
The Amazon Resource Name (ARN) of the vendor's rule group that's used in the published managed rule group version.
-
#forecasted_lifetime ⇒ Integer
The amount of time the vendor expects this version of the managed rule group to last, in days.
Instance Attribute Details
#associated_rule_group_arn ⇒ String
The Amazon Resource Name (ARN) of the vendor's rule group that's used in the published managed rule group version.
11337 11338 11339 11340 11341 11342 |
# File 'lib/aws-sdk-wafv2/types.rb', line 11337 class VersionToPublish < Struct.new( :associated_rule_group_arn, :forecasted_lifetime) SENSITIVE = [] include Aws::Structure end |
#forecasted_lifetime ⇒ Integer
The amount of time the vendor expects this version of the managed rule group to last, in days.
11337 11338 11339 11340 11341 11342 |
# File 'lib/aws-sdk-wafv2/types.rb', line 11337 class VersionToPublish < Struct.new( :associated_rule_group_arn, :forecasted_lifetime) SENSITIVE = [] include Aws::Structure end |