Class: Aws::WAFV2::Types::WAFConfigurationWarningException
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::WAFConfigurationWarningException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
The operation failed because you are inspecting the web request body,
headers, or cookies without specifying how to handle oversize
components. Rules that inspect the body must either provide an
OversizeHandling configuration or they must be preceded by a
SizeConstraintStatement that blocks the body content from being too
large. Rules that inspect the headers or cookies must provide an
OversizeHandling configuration.
Provide the handling configuration and retry your operation.
Alternately, you can suppress this warning by adding the following tag
to the resource that you provide to this operation: Tag
(key:WAF:OversizeFieldsHandlingConstraintOptOut, value:true).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
11432 11433 11434 11435 11436 |
# File 'lib/aws-sdk-wafv2/types.rb', line 11432 class WAFConfigurationWarningException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |