Class: Aws::WAFV2::Types::WAFDuplicateItemException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

WAF couldn’t perform the operation because the resource that you tried to save is a duplicate of an existing one.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


18920
18921
18922
18923
18924
# File 'lib/aws-sdk-wafv2/types.rb', line 18920

class WAFDuplicateItemException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end