Class: Aws::WAFV2::Types::WAFUnavailableEntityException
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::WAFUnavailableEntityException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
WAF couldn’t retrieve a resource that you specified for this operation. If you’ve just created a resource that you’re using in this operation, you might just need to wait a few minutes. It can take from a few seconds to a number of minutes for changes to propagate. Verify the resources that you are specifying in your request parameters and then retry the operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
8775 8776 8777 8778 8779 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8775 class WAFUnavailableEntityException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |