Class: Aws::WAFV2::Types::WebACLSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::WebACLSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
High-level information about a WebACL, returned by operations like
create and list. This provides information like the ID, that you can
use to retrieve and manage a WebACL, and the ARN, that you provide
to operations like AssociateWebACL.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the entity.
-
#description ⇒ String
A description of the web ACL that helps with identification.
-
#id ⇒ String
The unique identifier for the web ACL.
-
#lock_token ⇒ String
A token used for optimistic locking.
-
#name ⇒ String
The name of the web ACL.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the entity.
12071 12072 12073 12074 12075 12076 12077 12078 12079 |
# File 'lib/aws-sdk-wafv2/types.rb', line 12071 class WebACLSummary < Struct.new( :name, :id, :description, :lock_token, :arn) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the web ACL that helps with identification.
12071 12072 12073 12074 12075 12076 12077 12078 12079 |
# File 'lib/aws-sdk-wafv2/types.rb', line 12071 class WebACLSummary < Struct.new( :name, :id, :description, :lock_token, :arn) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier for the web ACL. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
12071 12072 12073 12074 12075 12076 12077 12078 12079 |
# File 'lib/aws-sdk-wafv2/types.rb', line 12071 class WebACLSummary < Struct.new( :name, :id, :description, :lock_token, :arn) SENSITIVE = [] include Aws::Structure end |
#lock_token ⇒ String
A token used for optimistic locking. WAF returns a token to your
get and list requests, to mark the state of the entity at the
time of the request. To make changes to the entity associated with
the token, you provide the token to operations like update and
delete. WAF uses the token to ensure that no changes have been
made to the entity since you last retrieved it. If a change has been
made, the update fails with a WAFOptimisticLockException. If this
happens, perform another get, and use the new token returned by
that operation.
12071 12072 12073 12074 12075 12076 12077 12078 12079 |
# File 'lib/aws-sdk-wafv2/types.rb', line 12071 class WebACLSummary < Struct.new( :name, :id, :description, :lock_token, :arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the web ACL. You cannot change the name of a web ACL after you create it.
12071 12072 12073 12074 12075 12076 12077 12078 12079 |
# File 'lib/aws-sdk-wafv2/types.rb', line 12071 class WebACLSummary < Struct.new( :name, :id, :description, :lock_token, :arn) SENSITIVE = [] include Aws::Structure end |