Class: Aws::WAFV2::Types::XssMatchStatement
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::XssMatchStatement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
A rule statement that inspects for cross-site scripting (XSS) attacks. In XSS attacks, the attacker uses vulnerabilities in a benign website as a vehicle to inject malicious client-site scripts into other legitimate web browsers.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_to_match ⇒ Types::FieldToMatch
The part of the web request that you want WAF to inspect.
-
#pre_parse_text_transformations ⇒ Array<Types::PreParseTextTransformation>
Pre-parse text transformations normalize the raw query string before WAF parses it into individual query arguments.
-
#text_transformations ⇒ Array<Types::TextTransformation>
Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection.
Instance Attribute Details
#field_to_match ⇒ Types::FieldToMatch
The part of the web request that you want WAF to inspect.
12113 12114 12115 12116 12117 12118 12119 |
# File 'lib/aws-sdk-wafv2/types.rb', line 12113 class XssMatchStatement < Struct.new( :field_to_match, :text_transformations, :pre_parse_text_transformations) SENSITIVE = [] include Aws::Structure end |
#pre_parse_text_transformations ⇒ Array<Types::PreParseTextTransformation>
Pre-parse text transformations normalize the raw query string before
WAF parses it into individual query arguments. They are applied
before the standard text transformations. Pre-parse text
transformations are only supported when FieldToMatch is
SingleQueryArgument or AllQueryArguments. You can specify up to
3 pre-parse text transformations per rule statement.
12113 12114 12115 12116 12117 12118 12119 |
# File 'lib/aws-sdk-wafv2/types.rb', line 12113 class XssMatchStatement < Struct.new( :field_to_match, :text_transformations, :pre_parse_text_transformations) SENSITIVE = [] include Aws::Structure end |
#text_transformations ⇒ Array<Types::TextTransformation>
Text transformations eliminate some of the unusual formatting that
attackers use in web requests in an effort to bypass detection. Text
transformations are used in rule match statements, to transform the
FieldToMatch request component before inspecting it, and they're
used in rate-based rule statements, to transform request components
before using them as custom aggregation keys. If you specify one or
more transformations to apply, WAF performs all transformations on
the specified content, starting from the lowest priority setting,
and then uses the transformed component contents.
12113 12114 12115 12116 12117 12118 12119 |
# File 'lib/aws-sdk-wafv2/types.rb', line 12113 class XssMatchStatement < Struct.new( :field_to_match, :text_transformations, :pre_parse_text_transformations) SENSITIVE = [] include Aws::Structure end |