Class: Aws::WAFV2::Types::APIKeySummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::APIKeySummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Information for a single API key.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#api_key ⇒ String
The generated, encrypted API key.
-
#creation_timestamp ⇒ Time
The date and time that the key was created.
-
#token_domains ⇒ Array<String>
The token domains that are defined in this API key.
-
#version ⇒ Integer
Internal value used by WAF to manage the key.
Instance Attribute Details
#api_key ⇒ String
The generated, encrypted API key. You can copy this for use in your JavaScript CAPTCHA integration.
For information about how to use this in your CAPTCHA JavaScript integration, see [WAF client application integration] in the *WAF Developer Guide*.
[1]: docs.aws.amazon.com/waf/latest/developerguide/waf-application-integration.html
42 43 44 45 46 47 48 49 |
# File 'lib/aws-sdk-wafv2/types.rb', line 42 class APIKeySummary < Struct.new( :token_domains, :api_key, :creation_timestamp, :version) SENSITIVE = [] include Aws::Structure end |
#creation_timestamp ⇒ Time
The date and time that the key was created.
42 43 44 45 46 47 48 49 |
# File 'lib/aws-sdk-wafv2/types.rb', line 42 class APIKeySummary < Struct.new( :token_domains, :api_key, :creation_timestamp, :version) SENSITIVE = [] include Aws::Structure end |
#token_domains ⇒ Array<String>
The token domains that are defined in this API key.
42 43 44 45 46 47 48 49 |
# File 'lib/aws-sdk-wafv2/types.rb', line 42 class APIKeySummary < Struct.new( :token_domains, :api_key, :creation_timestamp, :version) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
Internal value used by WAF to manage the key.
42 43 44 45 46 47 48 49 |
# File 'lib/aws-sdk-wafv2/types.rb', line 42 class APIKeySummary < Struct.new( :token_domains, :api_key, :creation_timestamp, :version) SENSITIVE = [] include Aws::Structure end |