Class: Aws::WAFV2::Types::AWSManagedRulesACFPRuleSet
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::AWSManagedRulesACFPRuleSet
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Details for your use of the account creation fraud prevention managed rule group, ‘AWSManagedRulesACFPRuleSet`. This configuration is used in `ManagedRuleGroupConfig`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_path ⇒ String
The path of the account creation endpoint for your application.
-
#enable_regex_in_path ⇒ Boolean
Allow the use of regular expressions in the registration page path and the account creation path.
-
#registration_page_path ⇒ String
The path of the account registration endpoint for your application.
-
#request_inspection ⇒ Types::RequestInspectionACFP
The criteria for inspecting account creation requests, used by the ACFP rule group to validate and track account creation attempts.
-
#response_inspection ⇒ Types::ResponseInspection
The criteria for inspecting responses to account creation requests, used by the ACFP rule group to track account creation success rates.
Instance Attribute Details
#creation_path ⇒ String
The path of the account creation endpoint for your application. This is the page on your website that accepts the completed registration form for a new user. This page must accept ‘POST` requests.
For example, for the URL ‘example.com/web/signup`, you would provide the path `/web/signup`.
110 111 112 113 114 115 116 117 118 |
# File 'lib/aws-sdk-wafv2/types.rb', line 110 class AWSManagedRulesACFPRuleSet < Struct.new( :creation_path, :registration_page_path, :request_inspection, :response_inspection, :enable_regex_in_path) SENSITIVE = [] include Aws::Structure end |
#enable_regex_in_path ⇒ Boolean
Allow the use of regular expressions in the registration page path and the account creation path.
110 111 112 113 114 115 116 117 118 |
# File 'lib/aws-sdk-wafv2/types.rb', line 110 class AWSManagedRulesACFPRuleSet < Struct.new( :creation_path, :registration_page_path, :request_inspection, :response_inspection, :enable_regex_in_path) SENSITIVE = [] include Aws::Structure end |
#registration_page_path ⇒ String
The path of the account registration endpoint for your application. This is the page on your website that presents the registration form to new users.
<note markdown=“1”> This page must accept ‘GET` text/html requests.
</note>
For example, for the URL ‘example.com/web/register`, you would provide the path `/web/register`.
110 111 112 113 114 115 116 117 118 |
# File 'lib/aws-sdk-wafv2/types.rb', line 110 class AWSManagedRulesACFPRuleSet < Struct.new( :creation_path, :registration_page_path, :request_inspection, :response_inspection, :enable_regex_in_path) SENSITIVE = [] include Aws::Structure end |
#request_inspection ⇒ Types::RequestInspectionACFP
The criteria for inspecting account creation requests, used by the ACFP rule group to validate and track account creation attempts.
110 111 112 113 114 115 116 117 118 |
# File 'lib/aws-sdk-wafv2/types.rb', line 110 class AWSManagedRulesACFPRuleSet < Struct.new( :creation_path, :registration_page_path, :request_inspection, :response_inspection, :enable_regex_in_path) SENSITIVE = [] include Aws::Structure end |
#response_inspection ⇒ Types::ResponseInspection
The criteria for inspecting responses to account creation requests, used by the ACFP rule group to track account creation success rates.
<note markdown=“1”> Response inspection is available only in web ACLs that protect Amazon CloudFront distributions.
</note>
The ACFP rule group evaluates the responses that your protected resources send back to client account creation attempts, keeping count of successful and failed attempts from each IP address and client session. Using this information, the rule group labels and mitigates requests from client sessions and IP addresses that have had too many successful account creation attempts in a short amount of time.
110 111 112 113 114 115 116 117 118 |
# File 'lib/aws-sdk-wafv2/types.rb', line 110 class AWSManagedRulesACFPRuleSet < Struct.new( :creation_path, :registration_page_path, :request_inspection, :response_inspection, :enable_regex_in_path) SENSITIVE = [] include Aws::Structure end |