Class: Aws::WAFV2::Types::AWSManagedRulesATPRuleSet
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::AWSManagedRulesATPRuleSet
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Details for your use of the account takeover prevention managed rule group, ‘AWSManagedRulesATPRuleSet`. This configuration is used in `ManagedRuleGroupConfig`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#login_path ⇒ String
The path of the login endpoint for your application.
-
#request_inspection ⇒ Types::RequestInspection
The criteria for inspecting login requests, used by the ATP rule group to validate credentials usage.
-
#response_inspection ⇒ Types::ResponseInspection
The criteria for inspecting responses to login requests, used by the ATP rule group to track login failure rates.
Instance Attribute Details
#login_path ⇒ String
The path of the login endpoint for your application. For example, for the URL ‘example.com/web/login`, you would provide the path `/web/login`.
The rule group inspects only HTTP ‘POST` requests to your specified login endpoint.
50 51 52 53 54 55 56 |
# File 'lib/aws-sdk-wafv2/types.rb', line 50 class AWSManagedRulesATPRuleSet < Struct.new( :login_path, :request_inspection, :response_inspection) SENSITIVE = [] include Aws::Structure end |
#request_inspection ⇒ Types::RequestInspection
The criteria for inspecting login requests, used by the ATP rule group to validate credentials usage.
50 51 52 53 54 55 56 |
# File 'lib/aws-sdk-wafv2/types.rb', line 50 class AWSManagedRulesATPRuleSet < Struct.new( :login_path, :request_inspection, :response_inspection) SENSITIVE = [] include Aws::Structure end |
#response_inspection ⇒ Types::ResponseInspection
The criteria for inspecting responses to login requests, used by the ATP rule group to track login failure rates.
The ATP rule group evaluates the responses that your protected resources send back to client login attempts, keeping count of successful and failed attempts from each IP address and client session. Using this information, the rule group labels and mitigates requests from client sessions and IP addresses that submit too many failed login attempts in a short amount of time.
<note markdown=“1”> Response inspection is available only in web ACLs that protect Amazon CloudFront distributions.
</note>
50 51 52 53 54 55 56 |
# File 'lib/aws-sdk-wafv2/types.rb', line 50 class AWSManagedRulesATPRuleSet < Struct.new( :login_path, :request_inspection, :response_inspection) SENSITIVE = [] include Aws::Structure end |