Class: Aws::WAFV2::Types::AWSManagedRulesBotControlRuleSet
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::AWSManagedRulesBotControlRuleSet
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Details for your use of the Bot Control managed rule group, ‘AWSManagedRulesBotControlRuleSet`. This configuration is used in `ManagedRuleGroupConfig`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inspection_level ⇒ String
The inspection level to use for the Bot Control rule group.
Instance Attribute Details
#inspection_level ⇒ String
The inspection level to use for the Bot Control rule group. The common level is the least expensive. The targeted level includes all common level rules and adds rules with more advanced inspection criteria. For details, see [WAF Bot Control rule group].
[1]: docs.aws.amazon.com/waf/latest/developerguide/aws-managed-rule-groups-bot.html
83 84 85 86 87 |
# File 'lib/aws-sdk-wafv2/types.rb', line 83 class AWSManagedRulesBotControlRuleSet < Struct.new( :inspection_level) SENSITIVE = [] include Aws::Structure end |