Class: Aws::WAFV2::Types::ActionCondition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass ActionCondition data as a hash:

{
  action: "ALLOW", # required, accepts ALLOW, BLOCK, COUNT, CAPTCHA, CHALLENGE, EXCLUDED_AS_COUNT
}

A single action condition for a Condition in a logging filter.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action setting that a log record must contain in order to meet the condition. This is the action that WAF applied to the web request.

For rule groups, this is either the configured rule action setting, or if you've applied a rule action override to the rule, it's the override action. The value `EXCLUDED_AS_COUNT` matches on excluded rules and also on rules that have a rule action override of Count.

Returns:

  • (String)


64
65
66
67
68
# File 'lib/aws-sdk-wafv2/types.rb', line 64

class ActionCondition < Struct.new(
  :action)
  SENSITIVE = []
  include Aws::Structure
end