Class: Aws::WAFV2::Types::AssociateWebACLRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The Amazon Resource Name (ARN) of the resource to associate with the web ACL.

The ARN must be in one of the following formats:

  • For an Application Load Balancer: `arn:aws:elasticloadbalancing:region:account-id:loadbalancer/app/load-balancer-name/load-balancer-id `

  • For an Amazon API Gateway REST API: `arn:aws:apigateway:region::/restapis/api-id/stages/stage-name `

  • For an AppSync GraphQL API: `arn:aws:appsync:region:account-id:apis/GraphQLApiId `

  • For an Amazon Cognito user pool: `arn:aws:cognito-idp:region:account-id:userpool/user-pool-id `

Returns:

  • (String)


155
156
157
158
159
160
# File 'lib/aws-sdk-wafv2/types.rb', line 155

class AssociateWebACLRequest < Struct.new(
  :web_acl_arn,
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end

#web_acl_arnString

The Amazon Resource Name (ARN) of the web ACL that you want to associate with the resource.

Returns:

  • (String)


155
156
157
158
159
160
# File 'lib/aws-sdk-wafv2/types.rb', line 155

class AssociateWebACLRequest < Struct.new(
  :web_acl_arn,
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end