Class: Aws::WAFV2::Types::CaptchaConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::CaptchaConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Note:
When making an API call, you may pass CaptchaConfig data as a hash:
{
immunity_time_property: {
immunity_time: 1, # required
},
}
Specifies how WAF should handle `CAPTCHA` evaluations. This is available at the web ACL level and in each rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#immunity_time_property ⇒ Types::ImmunityTimeProperty
Determines how long a `CAPTCHA` token remains valid after the client successfully solves a `CAPTCHA` puzzle.
Instance Attribute Details
#immunity_time_property ⇒ Types::ImmunityTimeProperty
Determines how long a `CAPTCHA` token remains valid after the client successfully solves a `CAPTCHA` puzzle.
945 946 947 948 949 |
# File 'lib/aws-sdk-wafv2/types.rb', line 945 class CaptchaConfig < Struct.new( :immunity_time_property) SENSITIVE = [] include Aws::Structure end |