Class: Aws::WAFV2::Types::CheckCapacityRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#rulesArray<Types::Rule>

An array of Rule that you’re configuring to use in a rule group or web ACL.

Returns:



712
713
714
715
716
717
# File 'lib/aws-sdk-wafv2/types.rb', line 712

class CheckCapacityRequest < Struct.new(
  :scope,
  :rules)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, an Amazon Cognito user pool, an App Runner service, or an Amazon Web Services Verified Access instance.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: ‘–scope=CLOUDFRONT –region=us-east-1`.

  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Returns:

  • (String)


712
713
714
715
716
717
# File 'lib/aws-sdk-wafv2/types.rb', line 712

class CheckCapacityRequest < Struct.new(
  :scope,
  :rules)
  SENSITIVE = []
  include Aws::Structure
end