Class: Aws::WAFV2::Types::CheckCapacityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::CheckCapacityRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#rules ⇒ Array<Types::Rule>
An array of Rule that you’re configuring to use in a rule group or web ACL.
-
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application.
Instance Attribute Details
#rules ⇒ Array<Types::Rule>
An array of Rule that you’re configuring to use in a rule group or web ACL.
613 614 615 616 617 618 |
# File 'lib/aws-sdk-wafv2/types.rb', line 613 class CheckCapacityRequest < Struct.new( :scope, :rules) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, or an Amazon Cognito user pool.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope: ‘–scope=CLOUDFRONT –region=us-east-1`.
-
API and SDKs - For all calls, use the Region endpoint us-east-1.
613 614 615 616 617 618 |
# File 'lib/aws-sdk-wafv2/types.rb', line 613 class CheckCapacityRequest < Struct.new( :scope, :rules) SENSITIVE = [] include Aws::Structure end |