Class: Aws::WAFV2::Types::CookieMatchPattern

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass CookieMatchPattern data as a hash:

{
  all: {
  },
  included_cookies: ["SingleCookieName"],
  excluded_cookies: ["SingleCookieName"],
}

The filter to use to identify the subset of cookies to inspect in a web request.

You must specify exactly one setting: either `All`, `IncludedCookies`, or `ExcludedCookies`.

Example JSON: `“CookieMatchPattern”: { “IncludedCookies”: “KeyToInclude2”, “KeyToInclude3” }`

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allTypes::All

Inspect all cookies.

Returns:



1605
1606
1607
1608
1609
1610
1611
# File 'lib/aws-sdk-wafv2/types.rb', line 1605

class CookieMatchPattern < Struct.new(
  :all,
  :included_cookies,
  :excluded_cookies)
  SENSITIVE = []
  include Aws::Structure
end

#excluded_cookiesArray<String>

Inspect only the cookies whose keys don't match any of the strings specified here.

Returns:

  • (Array<String>)


1605
1606
1607
1608
1609
1610
1611
# File 'lib/aws-sdk-wafv2/types.rb', line 1605

class CookieMatchPattern < Struct.new(
  :all,
  :included_cookies,
  :excluded_cookies)
  SENSITIVE = []
  include Aws::Structure
end

#included_cookiesArray<String>

Inspect only the cookies that have a key that matches one of the strings specified here.

Returns:

  • (Array<String>)


1605
1606
1607
1608
1609
1610
1611
# File 'lib/aws-sdk-wafv2/types.rb', line 1605

class CookieMatchPattern < Struct.new(
  :all,
  :included_cookies,
  :excluded_cookies)
  SENSITIVE = []
  include Aws::Structure
end