Class: Aws::WAFV2::Types::Cookies
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::Cookies
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
When making an API call, you may pass Cookies data as a hash:
{
match_pattern: { # required
all: {
},
included_cookies: ["SingleCookieName"],
excluded_cookies: ["SingleCookieName"],
},
match_scope: "ALL", # required, accepts ALL, KEY, VALUE
oversize_handling: "CONTINUE", # required, accepts CONTINUE, MATCH, NO_MATCH
}
Inspect the cookies in the web request. You can specify the parts of the cookies to inspect and you can narrow the set of cookies to inspect by including or excluding specific keys.
This is used to indicate the web request component to inspect, in the FieldToMatch specification.
Example JSON: `“Cookies”: { “MatchPattern”: { “All”: {} }, “MatchScope”: “KEY”, “OversizeHandling”: “MATCH” }`
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#match_pattern ⇒ Types::CookieMatchPattern
The filter to use to identify the subset of cookies to inspect in a web request.
-
#match_scope ⇒ String
The parts of the cookies to inspect with the rule inspection criteria.
-
#oversize_handling ⇒ String
What WAF should do if the cookies of the request are larger than WAF can inspect.
Instance Attribute Details
#match_pattern ⇒ Types::CookieMatchPattern
The filter to use to identify the subset of cookies to inspect in a web request.
You must specify exactly one setting: either `All`, `IncludedCookies`, or `ExcludedCookies`.
Example JSON: `“MatchPattern”: { “IncludedCookies”: “KeyToInclude2”, “KeyToInclude3” }`
1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1680 class Cookies < Struct.new( :match_pattern, :match_scope, :oversize_handling) SENSITIVE = [] include Aws::Structure end |
#match_scope ⇒ String
The parts of the cookies to inspect with the rule inspection criteria. If you specify `All`, WAF inspects both keys and values.
1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1680 class Cookies < Struct.new( :match_pattern, :match_scope, :oversize_handling) SENSITIVE = [] include Aws::Structure end |
#oversize_handling ⇒ String
What WAF should do if the cookies of the request are larger than WAF can inspect. WAF does not support inspecting the entire contents of request cookies when they exceed 8 KB (8192 bytes) or 200 total cookies. The underlying host service forwards a maximum of 200 cookies and at most 8 KB of cookie contents to WAF.
The options for oversize handling are the following:
-
`CONTINUE` - Inspect the cookies normally, according to the rule inspection criteria.
-
`MATCH` - Treat the web request as matching the rule statement. WAF applies the rule action to the request.
-
`NO_MATCH` - Treat the web request as not matching the rule statement.
1680 1681 1682 1683 1684 1685 1686 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1680 class Cookies < Struct.new( :match_pattern, :match_scope, :oversize_handling) SENSITIVE = [] include Aws::Structure end |