Class: Aws::WAFV2::Types::CountAction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Specifies that WAF should count the request. Optionally defines additional custom handling for the request.

This is used in the context of other settings, for example to specify values for RuleAction and web ACL DefaultAction.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_request_handlingTypes::CustomRequestHandling

Defines custom handling for the web request.

For information about customizing web requests and responses, see Customizing web requests and responses in WAF in the WAF Developer Guide.



1386
1387
1388
1389
1390
# File 'lib/aws-sdk-wafv2/types.rb', line 1386

class CountAction < Struct.new(
  :custom_request_handling)
  SENSITIVE = []
  include Aws::Structure
end