Class: Aws::WAFV2::Types::CountAction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass CountAction data as a hash:

{
  custom_request_handling: {
    insert_headers: [ # required
      {
        name: "CustomHTTPHeaderName", # required
        value: "CustomHTTPHeaderValue", # required
      },
    ],
  },
}

Specifies that WAF should count the request. Optionally defines additional custom handling for the request.

This is used in the context of other settings, for example to specify values for RuleAction and web ACL DefaultAction.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_request_handlingTypes::CustomRequestHandling

Defines custom handling for the web request.

For information about customizing web requests and responses, see

Customizing web requests and responses in WAF][1

in the [WAF

Developer Guide].

[1]: docs.aws.amazon.com/waf/latest/developerguide/waf-custom-request-response.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html



2150
2151
2152
2153
2154
# File 'lib/aws-sdk-wafv2/types.rb', line 2150

class CountAction < Struct.new(
  :custom_request_handling)
  SENSITIVE = []
  include Aws::Structure
end