Class: Aws::WAFV2::Types::CreateAPIKeyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::CreateAPIKeyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application.
-
#token_domains ⇒ Array<String>
The client application domains that you want to use this API key for.
Instance Attribute Details
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, an Amazon Cognito user pool, an App Runner service, or an Amazon Web Services Verified Access instance.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope: ‘–scope=CLOUDFRONT –region=us-east-1`.
-
API and SDKs - For all calls, use the Region endpoint us-east-1.
1037 1038 1039 1040 1041 1042 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1037 class CreateAPIKeyRequest < Struct.new( :scope, :token_domains) SENSITIVE = [] include Aws::Structure end |
#token_domains ⇒ Array<String>
The client application domains that you want to use this API key for.
Example JSON: ‘“TokenDomains”: [“abc.com”, “store.abc.com”]`
Public suffixes aren’t allowed. For example, you can’t use ‘usa.gov` or `co.uk` as token domains.
1037 1038 1039 1040 1041 1042 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1037 class CreateAPIKeyRequest < Struct.new( :scope, :token_domains) SENSITIVE = [] include Aws::Structure end |