Class: Aws::WAFV2::Types::CreateIPSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass CreateIPSetRequest data as a hash:

{
  name: "EntityName", # required
  scope: "CLOUDFRONT", # required, accepts CLOUDFRONT, REGIONAL
  description: "EntityDescription",
  ip_address_version: "IPV4", # required, accepts IPV4, IPV6
  addresses: ["IPAddress"], # required
  tags: [
    {
      key: "TagKey", # required
      value: "TagValue", # required
    },
  ],
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#addressesArray<String>

Contains an array of strings that specifies zero or more IP addresses or blocks of IP addresses. All addresses must be specified using Classless Inter-Domain Routing (CIDR) notation. WAF supports all IPv4 and IPv6 CIDR ranges except for `/0`.

Example address strings:

  • To configure WAF to allow, block, or count requests that originated from the IP address 192.0.2.44, specify `192.0.2.44/32`.

  • To configure WAF to allow, block, or count requests that originated from IP addresses from 192.0.2.0 to 192.0.2.255, specify `192.0.2.0/24`.

  • To configure WAF to allow, block, or count requests that originated from the IP address 1111:0000:0000:0000:0000:0000:0000:0111, specify `1111:0000:0000:0000:0000:0000:0000:0111/128`.

  • To configure WAF to allow, block, or count requests that originated from IP addresses 1111:0000:0000:0000:0000:0000:0000:0000 to 1111:0000:0000:0000:ffff:ffff:ffff:ffff, specify `1111:0000:0000:0000:0000:0000:0000:0000/64`.

For more information about CIDR notation, see the Wikipedia entry [Classless Inter-Domain Routing].

Example JSON `Addresses` specifications:

  • Empty array: `“Addresses”: []`

  • Array with one address: `“Addresses”: [“192.0.2.44/32”]`

  • Array with three addresses: `“Addresses”: [“192.0.2.44/32”, “192.0.2.0/24”, “192.0.0.0/16”]`

  • INVALID specification: `“Addresses”: [“”]` INVALID

[1]: en.wikipedia.org/wiki/Classless_Inter-Domain_Routing

Returns:

  • (Array<String>)


1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
# File 'lib/aws-sdk-wafv2/types.rb', line 1826

class CreateIPSetRequest < Struct.new(
  :name,
  :scope,
  :description,
  :ip_address_version,
  :addresses,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the IP set that helps with identification.

Returns:

  • (String)


1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
# File 'lib/aws-sdk-wafv2/types.rb', line 1826

class CreateIPSetRequest < Struct.new(
  :name,
  :scope,
  :description,
  :ip_address_version,
  :addresses,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ip_address_versionString

The version of the IP addresses, either `IPV4` or `IPV6`.

Returns:

  • (String)


1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
# File 'lib/aws-sdk-wafv2/types.rb', line 1826

class CreateIPSetRequest < Struct.new(
  :name,
  :scope,
  :description,
  :ip_address_version,
  :addresses,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the IP set. You cannot change the name of an `IPSet` after you create it.

Returns:

  • (String)


1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
# File 'lib/aws-sdk-wafv2/types.rb', line 1826

class CreateIPSetRequest < Struct.new(
  :name,
  :scope,
  :description,
  :ip_address_version,
  :addresses,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, or an Amazon Cognito user pool.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: `–scope=CLOUDFRONT –region=us-east-1`.

  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Returns:

  • (String)


1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
# File 'lib/aws-sdk-wafv2/types.rb', line 1826

class CreateIPSetRequest < Struct.new(
  :name,
  :scope,
  :description,
  :ip_address_version,
  :addresses,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of key:value pairs to associate with the resource.

Returns:



1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
# File 'lib/aws-sdk-wafv2/types.rb', line 1826

class CreateIPSetRequest < Struct.new(
  :name,
  :scope,
  :description,
  :ip_address_version,
  :addresses,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end