Class: Aws::WAFV2::Types::CreateRegexPatternSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::CreateRegexPatternSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the set that helps with identification.
-
#name ⇒ String
The name of the set.
-
#regular_expression_list ⇒ Array<Types::Regex>
Array of regular expression strings.
-
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application.
-
#tags ⇒ Array<Types::Tag>
An array of key:value pairs to associate with the resource.
Instance Attribute Details
#description ⇒ String
A description of the set that helps with identification.
918 919 920 921 922 923 924 925 926 |
# File 'lib/aws-sdk-wafv2/types.rb', line 918 class CreateRegexPatternSetRequest < Struct.new( :name, :scope, :description, :regular_expression_list, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the set. You cannot change the name after you create the set.
918 919 920 921 922 923 924 925 926 |
# File 'lib/aws-sdk-wafv2/types.rb', line 918 class CreateRegexPatternSetRequest < Struct.new( :name, :scope, :description, :regular_expression_list, :tags) SENSITIVE = [] include Aws::Structure end |
#regular_expression_list ⇒ Array<Types::Regex>
Array of regular expression strings.
918 919 920 921 922 923 924 925 926 |
# File 'lib/aws-sdk-wafv2/types.rb', line 918 class CreateRegexPatternSetRequest < Struct.new( :name, :scope, :description, :regular_expression_list, :tags) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, a Amazon Cognito user pool, or an App Runner service.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope: ‘–scope=CLOUDFRONT –region=us-east-1`.
-
API and SDKs - For all calls, use the Region endpoint us-east-1.
918 919 920 921 922 923 924 925 926 |
# File 'lib/aws-sdk-wafv2/types.rb', line 918 class CreateRegexPatternSetRequest < Struct.new( :name, :scope, :description, :regular_expression_list, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of key:value pairs to associate with the resource.
918 919 920 921 922 923 924 925 926 |
# File 'lib/aws-sdk-wafv2/types.rb', line 918 class CreateRegexPatternSetRequest < Struct.new( :name, :scope, :description, :regular_expression_list, :tags) SENSITIVE = [] include Aws::Structure end |