Class: Aws::WAFV2::Types::CreateRegexPatternSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the set that helps with identification.

Returns:

  • (String)


919
920
921
922
923
924
925
926
927
# File 'lib/aws-sdk-wafv2/types.rb', line 919

class CreateRegexPatternSetRequest < Struct.new(
  :name,
  :scope,
  :description,
  :regular_expression_list,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the set. You cannot change the name after you create the set.

Returns:

  • (String)


919
920
921
922
923
924
925
926
927
# File 'lib/aws-sdk-wafv2/types.rb', line 919

class CreateRegexPatternSetRequest < Struct.new(
  :name,
  :scope,
  :description,
  :regular_expression_list,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#regular_expression_listArray<Types::Regex>

Array of regular expression strings.

Returns:



919
920
921
922
923
924
925
926
927
# File 'lib/aws-sdk-wafv2/types.rb', line 919

class CreateRegexPatternSetRequest < Struct.new(
  :name,
  :scope,
  :description,
  :regular_expression_list,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, or an Amazon Cognito user pool.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: ‘–scope=CLOUDFRONT –region=us-east-1`.

  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Returns:

  • (String)


919
920
921
922
923
924
925
926
927
# File 'lib/aws-sdk-wafv2/types.rb', line 919

class CreateRegexPatternSetRequest < Struct.new(
  :name,
  :scope,
  :description,
  :regular_expression_list,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of key:value pairs to associate with the resource.

Returns:



919
920
921
922
923
924
925
926
927
# File 'lib/aws-sdk-wafv2/types.rb', line 919

class CreateRegexPatternSetRequest < Struct.new(
  :name,
  :scope,
  :description,
  :regular_expression_list,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end