Class: Aws::WAFV2::Types::CreateRegexPatternSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::CreateRegexPatternSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
When making an API call, you may pass CreateRegexPatternSetRequest data as a hash:
{
name: "EntityName", # required
scope: "CLOUDFRONT", # required, accepts CLOUDFRONT, REGIONAL
description: "EntityDescription",
regular_expression_list: [ # required
{
regex_string: "RegexPatternString",
},
],
tags: [
{
key: "TagKey", # required
value: "TagValue", # required
},
],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the set that helps with identification.
-
#name ⇒ String
The name of the set.
-
#regular_expression_list ⇒ Array<Types::Regex>
Array of regular expression strings.
-
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application.
-
#tags ⇒ Array<Types::Tag>
An array of key:value pairs to associate with the resource.
Instance Attribute Details
#description ⇒ String
A description of the set that helps with identification.
1906 1907 1908 1909 1910 1911 1912 1913 1914 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1906 class CreateRegexPatternSetRequest < Struct.new( :name, :scope, :description, :regular_expression_list, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the set. You cannot change the name after you create the set.
1906 1907 1908 1909 1910 1911 1912 1913 1914 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1906 class CreateRegexPatternSetRequest < Struct.new( :name, :scope, :description, :regular_expression_list, :tags) SENSITIVE = [] include Aws::Structure end |
#regular_expression_list ⇒ Array<Types::Regex>
Array of regular expression strings.
1906 1907 1908 1909 1910 1911 1912 1913 1914 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1906 class CreateRegexPatternSetRequest < Struct.new( :name, :scope, :description, :regular_expression_list, :tags) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, or an Amazon Cognito user pool.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope: `–scope=CLOUDFRONT –region=us-east-1`.
-
API and SDKs - For all calls, use the Region endpoint us-east-1.
1906 1907 1908 1909 1910 1911 1912 1913 1914 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1906 class CreateRegexPatternSetRequest < Struct.new( :name, :scope, :description, :regular_expression_list, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of key:value pairs to associate with the resource.
1906 1907 1908 1909 1910 1911 1912 1913 1914 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1906 class CreateRegexPatternSetRequest < Struct.new( :name, :scope, :description, :regular_expression_list, :tags) SENSITIVE = [] include Aws::Structure end |