Class: Aws::WAFV2::Types::CustomHTTPHeader
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::CustomHTTPHeader
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Note:
When making an API call, you may pass CustomHTTPHeader data as a hash:
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
}
A custom header for custom request and response handling. This is used in CustomResponse and CustomRequestHandling.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the custom header.
-
#value ⇒ String
The value of the custom header.
Instance Attribute Details
#name ⇒ String
The name of the custom header.
For custom request header insertion, when WAF inserts the header into the request, it prefixes this name `x-amzn-waf-`, to avoid confusion with the headers that are already in the request. For example, for the header name `sample`, WAF inserts the header `x-amzn-waf-sample`.
3275 3276 3277 3278 3279 3280 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3275 class CustomHTTPHeader < Struct.new( :name, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value of the custom header.
3275 3276 3277 3278 3279 3280 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3275 class CustomHTTPHeader < Struct.new( :name, :value) SENSITIVE = [] include Aws::Structure end |