Class: Aws::WAFV2::Types::CustomRequestHandling
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::CustomRequestHandling
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
When making an API call, you may pass CustomRequestHandling data as a hash:
{
insert_headers: [ # required
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
}
Custom request handling behavior that inserts custom headers into a web request. You can add custom request handling for the rule actions allow and count.
For information about customizing web requests and responses, see
- Customizing web requests and responses in WAF][1
-
in the [WAF
Developer Guide].
[1]: docs.aws.amazon.com/waf/latest/developerguide/waf-custom-request-response.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#insert_headers ⇒ Array<Types::CustomHTTPHeader>
The HTTP headers to insert into the request.
Instance Attribute Details
#insert_headers ⇒ Array<Types::CustomHTTPHeader>
The HTTP headers to insert into the request. Duplicate header names are not allowed.
For information about the limits on count and size for custom request and response settings, see [WAF quotas] in the [WAF Developer Guide].
[1]: docs.aws.amazon.com/waf/latest/developerguide/limits.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html
3326 3327 3328 3329 3330 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3326 class CustomRequestHandling < Struct.new( :insert_headers) SENSITIVE = [] include Aws::Structure end |