Class: Aws::WAFV2::Types::CustomResponseBody

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

The response body to use in a custom response to a web request. This is referenced by key from CustomResponse CustomResponseBodyKey.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contentString

The payload of the custom response.

You can use JSON escape strings in JSON content. To do this, you must specify JSON content in the ContentType setting.

For information about the limits on count and size for custom request and response settings, see WAF quotas in the WAF Developer Guide.

Returns:

  • (String)


2059
2060
2061
2062
2063
2064
# File 'lib/aws-sdk-wafv2/types.rb', line 2059

class CustomResponseBody < Struct.new(
  :content_type,
  :content)
  SENSITIVE = []
  include Aws::Structure
end

#content_typeString

The type of content in the payload that you are defining in the Content string.

Returns:

  • (String)


2059
2060
2061
2062
2063
2064
# File 'lib/aws-sdk-wafv2/types.rb', line 2059

class CustomResponseBody < Struct.new(
  :content_type,
  :content)
  SENSITIVE = []
  include Aws::Structure
end