Class: Aws::WAFV2::Types::DataPointEntry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

A single data point in a revenue time series, representing aggregated monetization metrics for a specific time interval.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#categoryString

The bot category for this data point, when grouped by category.

Returns:

  • (String)


2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
# File 'lib/aws-sdk-wafv2/types.rb', line 2098

class DataPointEntry < Struct.new(
  :date,
  :monetize_served_count,
  :settled_count,
  :total_amount,
  :category,
  :intent,
  :group_by_value)
  SENSITIVE = []
  include Aws::Structure
end

#dateTime

The timestamp for this data point.

Returns:

  • (Time)


2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
# File 'lib/aws-sdk-wafv2/types.rb', line 2098

class DataPointEntry < Struct.new(
  :date,
  :monetize_served_count,
  :settled_count,
  :total_amount,
  :category,
  :intent,
  :group_by_value)
  SENSITIVE = []
  include Aws::Structure
end

#group_by_valueString

The group-by dimension value for this data point.

Returns:

  • (String)


2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
# File 'lib/aws-sdk-wafv2/types.rb', line 2098

class DataPointEntry < Struct.new(
  :date,
  :monetize_served_count,
  :settled_count,
  :total_amount,
  :category,
  :intent,
  :group_by_value)
  SENSITIVE = []
  include Aws::Structure
end

#intentString

The intent classification for this data point, when grouped by intent.

Returns:

  • (String)


2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
# File 'lib/aws-sdk-wafv2/types.rb', line 2098

class DataPointEntry < Struct.new(
  :date,
  :monetize_served_count,
  :settled_count,
  :total_amount,
  :category,
  :intent,
  :group_by_value)
  SENSITIVE = []
  include Aws::Structure
end

#monetize_served_countInteger

The number of HTTP 402 Payment Required responses served during this interval.

Returns:

  • (Integer)


2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
# File 'lib/aws-sdk-wafv2/types.rb', line 2098

class DataPointEntry < Struct.new(
  :date,
  :monetize_served_count,
  :settled_count,
  :total_amount,
  :category,
  :intent,
  :group_by_value)
  SENSITIVE = []
  include Aws::Structure
end

#settled_countInteger

The number of successfully settled payments during this interval.

Returns:

  • (Integer)


2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
# File 'lib/aws-sdk-wafv2/types.rb', line 2098

class DataPointEntry < Struct.new(
  :date,
  :monetize_served_count,
  :settled_count,
  :total_amount,
  :category,
  :intent,
  :group_by_value)
  SENSITIVE = []
  include Aws::Structure
end

#total_amountString

The total revenue amount during this interval in the specified currency.

Returns:

  • (String)


2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
# File 'lib/aws-sdk-wafv2/types.rb', line 2098

class DataPointEntry < Struct.new(
  :date,
  :monetize_served_count,
  :settled_count,
  :total_amount,
  :category,
  :intent,
  :group_by_value)
  SENSITIVE = []
  include Aws::Structure
end