Class: Aws::WAFV2::Types::DataPointEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::DataPointEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
A single data point in a revenue time series, representing aggregated monetization metrics for a specific time interval.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#category ⇒ String
The bot category for this data point, when grouped by category.
-
#date ⇒ Time
The timestamp for this data point.
-
#group_by_value ⇒ String
The group-by dimension value for this data point.
-
#intent ⇒ String
The intent classification for this data point, when grouped by intent.
-
#monetize_served_count ⇒ Integer
The number of HTTP 402 Payment Required responses served during this interval.
-
#settled_count ⇒ Integer
The number of successfully settled payments during this interval.
-
#total_amount ⇒ String
The total revenue amount during this interval in the specified currency.
Instance Attribute Details
#category ⇒ String
The bot category for this data point, when grouped by category.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2098 class DataPointEntry < Struct.new( :date, :monetize_served_count, :settled_count, :total_amount, :category, :intent, :group_by_value) SENSITIVE = [] include Aws::Structure end |
#date ⇒ Time
The timestamp for this data point.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2098 class DataPointEntry < Struct.new( :date, :monetize_served_count, :settled_count, :total_amount, :category, :intent, :group_by_value) SENSITIVE = [] include Aws::Structure end |
#group_by_value ⇒ String
The group-by dimension value for this data point.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2098 class DataPointEntry < Struct.new( :date, :monetize_served_count, :settled_count, :total_amount, :category, :intent, :group_by_value) SENSITIVE = [] include Aws::Structure end |
#intent ⇒ String
The intent classification for this data point, when grouped by intent.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2098 class DataPointEntry < Struct.new( :date, :monetize_served_count, :settled_count, :total_amount, :category, :intent, :group_by_value) SENSITIVE = [] include Aws::Structure end |
#monetize_served_count ⇒ Integer
The number of HTTP 402 Payment Required responses served during this interval.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2098 class DataPointEntry < Struct.new( :date, :monetize_served_count, :settled_count, :total_amount, :category, :intent, :group_by_value) SENSITIVE = [] include Aws::Structure end |
#settled_count ⇒ Integer
The number of successfully settled payments during this interval.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2098 class DataPointEntry < Struct.new( :date, :monetize_served_count, :settled_count, :total_amount, :category, :intent, :group_by_value) SENSITIVE = [] include Aws::Structure end |
#total_amount ⇒ String
The total revenue amount during this interval in the specified currency.
2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2098 class DataPointEntry < Struct.new( :date, :monetize_served_count, :settled_count, :total_amount, :category, :intent, :group_by_value) SENSITIVE = [] include Aws::Structure end |