Class: Aws::WAFV2::Types::DeleteIPSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass DeleteIPSetRequest data as a hash:

{
  name: "EntityName", # required
  scope: "CLOUDFRONT", # required, accepts CLOUDFRONT, REGIONAL
  id: "EntityId", # required
  lock_token: "LockToken", # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.

Returns:

  • (String)


3600
3601
3602
3603
3604
3605
3606
3607
# File 'lib/aws-sdk-wafv2/types.rb', line 3600

class DeleteIPSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end

#lock_tokenString

A token used for optimistic locking. WAF returns a token to your `get` and `list` requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like `update` and `delete`. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a `WAFOptimisticLockException`. If this happens, perform another `get`, and use the new token returned by that operation.

Returns:

  • (String)


3600
3601
3602
3603
3604
3605
3606
3607
# File 'lib/aws-sdk-wafv2/types.rb', line 3600

class DeleteIPSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the IP set. You cannot change the name of an `IPSet` after you create it.

Returns:

  • (String)


3600
3601
3602
3603
3604
3605
3606
3607
# File 'lib/aws-sdk-wafv2/types.rb', line 3600

class DeleteIPSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, or an Amazon Cognito user pool.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: `–scope=CLOUDFRONT –region=us-east-1`.

  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Returns:

  • (String)


3600
3601
3602
3603
3604
3605
3606
3607
# File 'lib/aws-sdk-wafv2/types.rb', line 3600

class DeleteIPSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end