Class: Aws::WAFV2::Types::DeletePermissionPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::DeletePermissionPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the rule group from which you want to delete the policy.
Instance Attribute Details
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the rule group from which you want to delete the policy.
You must be the owner of the rule group to perform this operation.
1800 1801 1802 1803 1804 |
# File 'lib/aws-sdk-wafv2/types.rb', line 1800 class DeletePermissionPolicyRequest < Struct.new( :resource_arn) SENSITIVE = [] include Aws::Structure end |