Class: Aws::WAFV2::Types::DeletePermissionPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The Amazon Resource Name (ARN) of the rule group from which you want to delete the policy.

You must be the owner of the rule group to perform this operation.

Returns:

  • (String)


1484
1485
1486
1487
1488
# File 'lib/aws-sdk-wafv2/types.rb', line 1484

class DeletePermissionPolicyRequest < Struct.new(
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end