Class: Aws::WAFV2::Types::DeletePermissionPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass DeletePermissionPolicyRequest data as a hash:

{
  resource_arn: "ResourceArn", # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The Amazon Resource Name (ARN) of the rule group from which you want to delete the policy.

You must be the owner of the rule group to perform this operation.

Returns:

  • (String)


3653
3654
3655
3656
3657
# File 'lib/aws-sdk-wafv2/types.rb', line 3653

class DeletePermissionPolicyRequest < Struct.new(
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end