Class: Aws::WAFV2::Types::DeletePermissionPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::DeletePermissionPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Note:
When making an API call, you may pass DeletePermissionPolicyRequest data as a hash:
{
resource_arn: "ResourceArn", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the rule group from which you want to delete the policy.
Instance Attribute Details
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the rule group from which you want to delete the policy.
You must be the owner of the rule group to perform this operation.
2939 2940 2941 2942 2943 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2939 class DeletePermissionPolicyRequest < Struct.new( :resource_arn) SENSITIVE = [] include Aws::Structure end |