Class: Aws::WAFV2::Types::DescribeManagedRuleGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass DescribeManagedRuleGroupRequest data as a hash:

{
  vendor_name: "VendorName", # required
  name: "EntityName", # required
  scope: "CLOUDFRONT", # required, accepts CLOUDFRONT, REGIONAL
  version_name: "VersionKeyString",
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the managed rule group. You use this, along with the vendor name, to identify the rule group.

Returns:

  • (String)


3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-wafv2/types.rb', line 3193

class DescribeManagedRuleGroupRequest < Struct.new(
  :vendor_name,
  :name,
  :scope,
  :version_name)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: `–scope=CLOUDFRONT –region=us-east-1`.

  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Returns:

  • (String)


3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-wafv2/types.rb', line 3193

class DescribeManagedRuleGroupRequest < Struct.new(
  :vendor_name,
  :name,
  :scope,
  :version_name)
  SENSITIVE = []
  include Aws::Structure
end

#vendor_nameString

The name of the managed rule group vendor. You use this, along with the rule group name, to identify the rule group.

Returns:

  • (String)


3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-wafv2/types.rb', line 3193

class DescribeManagedRuleGroupRequest < Struct.new(
  :vendor_name,
  :name,
  :scope,
  :version_name)
  SENSITIVE = []
  include Aws::Structure
end

#version_nameString

The version of the rule group. You can only use a version that is not scheduled for expiration. If you don't provide this, WAF uses the vendor's default version.

Returns:

  • (String)


3193
3194
3195
3196
3197
3198
3199
3200
# File 'lib/aws-sdk-wafv2/types.rb', line 3193

class DescribeManagedRuleGroupRequest < Struct.new(
  :vendor_name,
  :name,
  :scope,
  :version_name)
  SENSITIVE = []
  include Aws::Structure
end