Class: Aws::WAFV2::Types::ExcludedRule

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Specifies a single rule in a rule group whose action you want to override to Count.

Instead of this option, use RuleActionOverrides. It accepts any valid action setting, including Count.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the rule whose action you want to override to Count.

Returns:

  • (String)


2893
2894
2895
2896
2897
# File 'lib/aws-sdk-wafv2/types.rb', line 2893

class ExcludedRule < Struct.new(
  :name)
  SENSITIVE = []
  include Aws::Structure
end