Class: Aws::WAFV2::Types::ExcludedRule
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ExcludedRule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Note:
When making an API call, you may pass ExcludedRule data as a hash:
{
name: "EntityName", # required
}
Specifies a single rule in a rule group whose action you want to override to `Count`.
<note markdown=“1”> Instead of this option, use `RuleActionOverrides`. It accepts any valid action setting, including `Count`.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the rule whose action you want to override to `Count`.
Instance Attribute Details
#name ⇒ String
The name of the rule whose action you want to override to `Count`.
4766 4767 4768 4769 4770 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4766 class ExcludedRule < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |