Class: Aws::WAFV2::Types::ExcludedRule
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ExcludedRule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Note:
When making an API call, you may pass ExcludedRule data as a hash:
{
name: "EntityName", # required
}
Specifies a single rule in a rule group whose action you want to override to `Count`. When you exclude a rule, WAF evaluates it exactly as it would if the rule action setting were `Count`. This is a useful option for testing the rules in a rule group without modifying how they handle your web traffic.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the rule whose action you want to override to `Count`.
Instance Attribute Details
#name ⇒ String
The name of the rule whose action you want to override to `Count`.
3331 3332 3333 3334 3335 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3331 class ExcludedRule < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |