Class: Aws::WAFV2::Types::FieldToMatch

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

The part of the web request that you want WAF to inspect. Include the single ‘FieldToMatch` type that you want to inspect, with additional specifications as needed, according to the type. You specify a single request component in `FieldToMatch` for each rule statement that requires it. To inspect more than one component of the web request, create a separate rule statement for each component.

Example JSON for a ‘QueryString` field to match:

‘ “FieldToMatch”: { “QueryString”: {} }`

Example JSON for a ‘Method` field to match specification:

‘ “FieldToMatch”: { “Method”: { “Name”: “DELETE” } }`

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#all_query_argumentsTypes::AllQueryArguments

Inspect all query arguments.



1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
# File 'lib/aws-sdk-wafv2/types.rb', line 1936

class FieldToMatch < Struct.new(
  :single_header,
  :single_query_argument,
  :all_query_arguments,
  :uri_path,
  :query_string,
  :body,
  :method,
  :json_body,
  :headers,
  :cookies)
  SENSITIVE = []
  include Aws::Structure
end

#bodyTypes::Body

Inspect the request body as plain text. The request body immediately follows the request headers. This is the part of a request that contains any additional data that you want to send to your web server as the HTTP request body, such as data from a form.

Only the first 8 KB (8192 bytes) of the request body are forwarded to WAF for inspection by the underlying host service. For information about how to handle oversized request bodies, see the ‘Body` object configuration.

Returns:



1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
# File 'lib/aws-sdk-wafv2/types.rb', line 1936

class FieldToMatch < Struct.new(
  :single_header,
  :single_query_argument,
  :all_query_arguments,
  :uri_path,
  :query_string,
  :body,
  :method,
  :json_body,
  :headers,
  :cookies)
  SENSITIVE = []
  include Aws::Structure
end

#cookiesTypes::Cookies

Inspect the request cookies. You must configure scope and pattern matching filters in the ‘Cookies` object, to define the set of cookies and the parts of the cookies that WAF inspects.

Only the first 8 KB (8192 bytes) of a request’s cookies and only the first 200 cookies are forwarded to WAF for inspection by the underlying host service. You must configure how to handle any oversize cookie content in the ‘Cookies` object. WAF applies the pattern matching filters to the cookies that it receives from the underlying host service.

Returns:



1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
# File 'lib/aws-sdk-wafv2/types.rb', line 1936

class FieldToMatch < Struct.new(
  :single_header,
  :single_query_argument,
  :all_query_arguments,
  :uri_path,
  :query_string,
  :body,
  :method,
  :json_body,
  :headers,
  :cookies)
  SENSITIVE = []
  include Aws::Structure
end

#headersTypes::Headers

Inspect the request headers. You must configure scope and pattern matching filters in the ‘Headers` object, to define the set of headers to and the parts of the headers that WAF inspects.

Only the first 8 KB (8192 bytes) of a request’s headers and only the first 200 headers are forwarded to WAF for inspection by the underlying host service. You must configure how to handle any oversize header content in the ‘Headers` object. WAF applies the pattern matching filters to the headers that it receives from the underlying host service.

Returns:



1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
# File 'lib/aws-sdk-wafv2/types.rb', line 1936

class FieldToMatch < Struct.new(
  :single_header,
  :single_query_argument,
  :all_query_arguments,
  :uri_path,
  :query_string,
  :body,
  :method,
  :json_body,
  :headers,
  :cookies)
  SENSITIVE = []
  include Aws::Structure
end

#json_bodyTypes::JsonBody

Inspect the request body as JSON. The request body immediately follows the request headers. This is the part of a request that contains any additional data that you want to send to your web server as the HTTP request body, such as data from a form.

Only the first 8 KB (8192 bytes) of the request body are forwarded to WAF for inspection by the underlying host service. For information about how to handle oversized request bodies, see the ‘JsonBody` object configuration.

Returns:



1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
# File 'lib/aws-sdk-wafv2/types.rb', line 1936

class FieldToMatch < Struct.new(
  :single_header,
  :single_query_argument,
  :all_query_arguments,
  :uri_path,
  :query_string,
  :body,
  :method,
  :json_body,
  :headers,
  :cookies)
  SENSITIVE = []
  include Aws::Structure
end

#methodTypes::Method

Inspect the HTTP method. The method indicates the type of operation that the request is asking the origin to perform.

Returns:



1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
# File 'lib/aws-sdk-wafv2/types.rb', line 1936

class FieldToMatch < Struct.new(
  :single_header,
  :single_query_argument,
  :all_query_arguments,
  :uri_path,
  :query_string,
  :body,
  :method,
  :json_body,
  :headers,
  :cookies)
  SENSITIVE = []
  include Aws::Structure
end

#query_stringTypes::QueryString

Inspect the query string. This is the part of a URL that appears after a ‘?` character, if any.

Returns:



1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
# File 'lib/aws-sdk-wafv2/types.rb', line 1936

class FieldToMatch < Struct.new(
  :single_header,
  :single_query_argument,
  :all_query_arguments,
  :uri_path,
  :query_string,
  :body,
  :method,
  :json_body,
  :headers,
  :cookies)
  SENSITIVE = []
  include Aws::Structure
end

#single_headerTypes::SingleHeader

Inspect a single header. Provide the name of the header to inspect, for example, ‘User-Agent` or `Referer`. This setting isn’t case sensitive.

Example JSON: ‘“SingleHeader”: { “Name”: “haystack” }`

Alternately, you can filter and inspect all headers with the ‘Headers` `FieldToMatch` setting.

Returns:



1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
# File 'lib/aws-sdk-wafv2/types.rb', line 1936

class FieldToMatch < Struct.new(
  :single_header,
  :single_query_argument,
  :all_query_arguments,
  :uri_path,
  :query_string,
  :body,
  :method,
  :json_body,
  :headers,
  :cookies)
  SENSITIVE = []
  include Aws::Structure
end

#single_query_argumentTypes::SingleQueryArgument

Inspect a single query argument. Provide the name of the query argument to inspect, such as UserName or SalesRegion. The name can be up to 30 characters long and isn’t case sensitive.

Example JSON: ‘“SingleQueryArgument”: { “Name”: “myArgument” }`



1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
# File 'lib/aws-sdk-wafv2/types.rb', line 1936

class FieldToMatch < Struct.new(
  :single_header,
  :single_query_argument,
  :all_query_arguments,
  :uri_path,
  :query_string,
  :body,
  :method,
  :json_body,
  :headers,
  :cookies)
  SENSITIVE = []
  include Aws::Structure
end

#uri_pathTypes::UriPath

Inspect the request URI path. This is the part of the web request that identifies a resource, for example, ‘/images/daily-ad.jpg`.

Returns:



1936
1937
1938
1939
1940
1941
1942
1943
1944
1945
1946
1947
1948
1949
# File 'lib/aws-sdk-wafv2/types.rb', line 1936

class FieldToMatch < Struct.new(
  :single_header,
  :single_query_argument,
  :all_query_arguments,
  :uri_path,
  :query_string,
  :body,
  :method,
  :json_body,
  :headers,
  :cookies)
  SENSITIVE = []
  include Aws::Structure
end