Class: Aws::WAFV2::Types::FirewallManagerRuleGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::FirewallManagerRuleGroup
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
A rule group that's defined for an Firewall Manager WAF policy.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#firewall_manager_statement ⇒ Types::FirewallManagerStatement
The processing guidance for an Firewall Manager rule.
-
#name ⇒ String
The name of the rule group.
-
#override_action ⇒ Types::OverrideAction
The action to use in the place of the action that results from the rule group evaluation.
-
#priority ⇒ Integer
If you define more than one rule group in the first or last Firewall Manager rule groups, WAF evaluates each request against the rule groups in order, starting from the lowest priority setting.
-
#visibility_config ⇒ Types::VisibilityConfig
Defines and enables Amazon CloudWatch metrics and web request sample collection.
Instance Attribute Details
#firewall_manager_statement ⇒ Types::FirewallManagerStatement
The processing guidance for an Firewall Manager rule. This is like a regular rule Statement, but it can only contain a rule group reference.
3281 3282 3283 3284 3285 3286 3287 3288 3289 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3281 class FirewallManagerRuleGroup < Struct.new( :name, :priority, :firewall_manager_statement, :override_action, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule group. You cannot change the name of a rule group after you create it.
3281 3282 3283 3284 3285 3286 3287 3288 3289 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3281 class FirewallManagerRuleGroup < Struct.new( :name, :priority, :firewall_manager_statement, :override_action, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#override_action ⇒ Types::OverrideAction
The action to use in the place of the action that results from the rule group evaluation. Set the override action to none to leave the result of the rule group alone. Set it to count to override the result to count only.
You can only use this for rule statements that reference a rule
group, like RuleGroupReferenceStatement and
ManagedRuleGroupStatement.
Count action, in your rule group
reference statement settings.
3281 3282 3283 3284 3285 3286 3287 3288 3289 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3281 class FirewallManagerRuleGroup < Struct.new( :name, :priority, :firewall_manager_statement, :override_action, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
If you define more than one rule group in the first or last Firewall Manager rule groups, WAF evaluates each request against the rule groups in order, starting from the lowest priority setting. The priorities don't need to be consecutive, but they must all be different.
3281 3282 3283 3284 3285 3286 3287 3288 3289 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3281 class FirewallManagerRuleGroup < Struct.new( :name, :priority, :firewall_manager_statement, :override_action, :visibility_config) SENSITIVE = [] include Aws::Structure end |
#visibility_config ⇒ Types::VisibilityConfig
Defines and enables Amazon CloudWatch metrics and web request sample collection.
3281 3282 3283 3284 3285 3286 3287 3288 3289 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3281 class FirewallManagerRuleGroup < Struct.new( :name, :priority, :firewall_manager_statement, :override_action, :visibility_config) SENSITIVE = [] include Aws::Structure end |