Class: Aws::WAFV2::Types::FirewallManagerStatement
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::FirewallManagerStatement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
The processing guidance for an Firewall Manager rule. This is like a regular rule Statement, but it can only contain a rule group reference.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#managed_rule_group_statement ⇒ Types::ManagedRuleGroupStatement
A rule statement used to run the rules that are defined in a managed rule group.
-
#rule_group_reference_statement ⇒ Types::RuleGroupReferenceStatement
A rule statement used to run the rules that are defined in a RuleGroup.
Instance Attribute Details
#managed_rule_group_statement ⇒ Types::ManagedRuleGroupStatement
A rule statement used to run the rules that are defined in a managed rule group. To use this, provide the vendor name and the name of the rule group in this statement. You can retrieve the required names by calling ListAvailableManagedRuleGroups.
You cannot nest a `ManagedRuleGroupStatement`, for example for use inside a `NotStatement` or `OrStatement`. It can only be referenced as a top-level statement within a rule.
4332 4333 4334 4335 4336 4337 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4332 class FirewallManagerStatement < Struct.new( :managed_rule_group_statement, :rule_group_reference_statement) SENSITIVE = [] include Aws::Structure end |
#rule_group_reference_statement ⇒ Types::RuleGroupReferenceStatement
A rule statement used to run the rules that are defined in a RuleGroup. To use this, create a rule group with your rules, then provide the ARN of the rule group in this statement.
You cannot nest a `RuleGroupReferenceStatement`, for example for use inside a `NotStatement` or `OrStatement`. You can only use a rule group reference statement at the top level inside a web ACL.
4332 4333 4334 4335 4336 4337 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4332 class FirewallManagerStatement < Struct.new( :managed_rule_group_statement, :rule_group_reference_statement) SENSITIVE = [] include Aws::Structure end |