Class: Aws::WAFV2::Types::ForwardedIPConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ForwardedIPConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
When making an API call, you may pass ForwardedIPConfig data as a hash:
{
header_name: "ForwardedIPHeaderName", # required
fallback_behavior: "MATCH", # required, accepts MATCH, NO_MATCH
}
The configuration for inspecting IP addresses in an HTTP header that you specify, instead of using the IP address that's reported by the web request origin. Commonly, this is the X-Forwarded-For (XFF) header, but you can specify any header name.
<note markdown=“1”> If the specified header isn't present in the request, WAF doesn't apply the rule to the web request at all.
</note>
This configuration is used for GeoMatchStatement and RateBasedStatement. For IPSetReferenceStatement, use IPSetForwardedIPConfig instead.
WAF only evaluates the first IP address found in the specified HTTP header.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fallback_behavior ⇒ String
The match status to assign to the web request if the request doesn't have a valid IP address in the specified position.
-
#header_name ⇒ String
The name of the HTTP header to use for the IP address.
Instance Attribute Details
#fallback_behavior ⇒ String
The match status to assign to the web request if the request doesn't have a valid IP address in the specified position.
<note markdown=“1”> If the specified header isn't present in the request, WAF doesn't apply the rule to the web request at all.
</note>
You can specify the following fallback behaviors:
-
`MATCH` - Treat the web request as matching the rule statement. WAF applies the rule action to the request.
-
`NO_MATCH` - Treat the web request as not matching the rule statement.
4418 4419 4420 4421 4422 4423 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4418 class ForwardedIPConfig < Struct.new( :header_name, :fallback_behavior) SENSITIVE = [] include Aws::Structure end |
#header_name ⇒ String
The name of the HTTP header to use for the IP address. For example, to use the X-Forwarded-For (XFF) header, set this to `X-Forwarded-For`.
<note markdown=“1”> If the specified header isn't present in the request, WAF doesn't apply the rule to the web request at all.
</note>
4418 4419 4420 4421 4422 4423 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4418 class ForwardedIPConfig < Struct.new( :header_name, :fallback_behavior) SENSITIVE = [] include Aws::Structure end |