Class: Aws::WAFV2::Types::GetDecryptedAPIKeyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#api_keyString

The encrypted API key.

Returns:

  • (String)


2688
2689
2690
2691
2692
2693
# File 'lib/aws-sdk-wafv2/types.rb', line 2688

class GetDecryptedAPIKeyRequest < Struct.new(
  :scope,
  :api_key)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, an Amazon Cognito user pool, an App Runner service, or an Amazon Web Services Verified Access instance.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: ‘–scope=CLOUDFRONT –region=us-east-1`.

  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Returns:

  • (String)


2688
2689
2690
2691
2692
2693
# File 'lib/aws-sdk-wafv2/types.rb', line 2688

class GetDecryptedAPIKeyRequest < Struct.new(
  :scope,
  :api_key)
  SENSITIVE = []
  include Aws::Structure
end