Class: Aws::WAFV2::Types::GetManagedRuleSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetManagedRuleSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
A unique identifier for the managed rule set.
-
#name ⇒ String
The name of the managed rule set.
-
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application.
Instance Attribute Details
#id ⇒ String
A unique identifier for the managed rule set. The ID is returned in the responses to commands like ‘list`. You provide it to operations like `get` and `update`.
2416 2417 2418 2419 2420 2421 2422 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2416 class GetManagedRuleSetRequest < Struct.new( :name, :scope, :id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the managed rule set. You use this, along with the rule set ID, to identify the rule set.
This name is assigned to the corresponding managed rule group, which your customers can access and use.
2416 2417 2418 2419 2420 2421 2422 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2416 class GetManagedRuleSetRequest < Struct.new( :name, :scope, :id) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, an Amazon Cognito user pool, or an App Runner service.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope: ‘–scope=CLOUDFRONT –region=us-east-1`.
-
API and SDKs - For all calls, use the Region endpoint us-east-1.
2416 2417 2418 2419 2420 2421 2422 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2416 class GetManagedRuleSetRequest < Struct.new( :name, :scope, :id) SENSITIVE = [] include Aws::Structure end |