Class: Aws::WAFV2::Types::GetManagedRuleSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass GetManagedRuleSetRequest data as a hash:

{
  name: "EntityName", # required
  scope: "CLOUDFRONT", # required, accepts CLOUDFRONT, REGIONAL
  id: "EntityId", # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

A unique identifier for the managed rule set. The ID is returned in the responses to commands like `list`. You provide it to operations like `get` and `update`.

Returns:

  • (String)


3876
3877
3878
3879
3880
3881
3882
# File 'lib/aws-sdk-wafv2/types.rb', line 3876

class GetManagedRuleSetRequest < Struct.new(
  :name,
  :scope,
  :id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the managed rule set. You use this, along with the rule set ID, to identify the rule set.

This name is assigned to the corresponding managed rule group, which your customers can access and use.

Returns:

  • (String)


3876
3877
3878
3879
3880
3881
3882
# File 'lib/aws-sdk-wafv2/types.rb', line 3876

class GetManagedRuleSetRequest < Struct.new(
  :name,
  :scope,
  :id)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: `–scope=CLOUDFRONT –region=us-east-1`.

  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Returns:

  • (String)


3876
3877
3878
3879
3880
3881
3882
# File 'lib/aws-sdk-wafv2/types.rb', line 3876

class GetManagedRuleSetRequest < Struct.new(
  :name,
  :scope,
  :id)
  SENSITIVE = []
  include Aws::Structure
end