Class: Aws::WAFV2::Types::GetRateBasedStatementManagedKeysRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetRateBasedStatementManagedKeysRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#rule_group_rule_name ⇒ String
The name of the rule group reference statement in your web ACL.
-
#rule_name ⇒ String
The name of the rate-based rule to get the keys for.
-
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application.
-
#web_acl_id ⇒ String
The unique identifier for the web ACL.
-
#web_acl_name ⇒ String
The name of the web ACL.
Instance Attribute Details
#rule_group_rule_name ⇒ String
The name of the rule group reference statement in your web ACL. This is required only when you have the rate-based rule nested inside a rule group.
2486 2487 2488 2489 2490 2491 2492 2493 2494 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2486 class GetRateBasedStatementManagedKeysRequest < Struct.new( :scope, :web_acl_name, :web_acl_id, :rule_group_rule_name, :rule_name) SENSITIVE = [] include Aws::Structure end |
#rule_name ⇒ String
The name of the rate-based rule to get the keys for. If you have the rule defined inside a rule group that you’re using in your web ACL, also provide the name of the rule group reference statement in the request parameter ‘RuleGroupRuleName`.
2486 2487 2488 2489 2490 2491 2492 2493 2494 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2486 class GetRateBasedStatementManagedKeysRequest < Struct.new( :scope, :web_acl_name, :web_acl_id, :rule_group_rule_name, :rule_name) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, a Amazon Cognito user pool, or an App Runner service.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope: ‘–scope=CLOUDFRONT –region=us-east-1`.
-
API and SDKs - For all calls, use the Region endpoint us-east-1.
2486 2487 2488 2489 2490 2491 2492 2493 2494 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2486 class GetRateBasedStatementManagedKeysRequest < Struct.new( :scope, :web_acl_name, :web_acl_id, :rule_group_rule_name, :rule_name) SENSITIVE = [] include Aws::Structure end |
#web_acl_id ⇒ String
The unique identifier for the web ACL. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
2486 2487 2488 2489 2490 2491 2492 2493 2494 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2486 class GetRateBasedStatementManagedKeysRequest < Struct.new( :scope, :web_acl_name, :web_acl_id, :rule_group_rule_name, :rule_name) SENSITIVE = [] include Aws::Structure end |
#web_acl_name ⇒ String
The name of the web ACL. You cannot change the name of a web ACL after you create it.
2486 2487 2488 2489 2490 2491 2492 2493 2494 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2486 class GetRateBasedStatementManagedKeysRequest < Struct.new( :scope, :web_acl_name, :web_acl_id, :rule_group_rule_name, :rule_name) SENSITIVE = [] include Aws::Structure end |