Class: Aws::WAFV2::Types::GetRegexPatternSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetRegexPatternSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
When making an API call, you may pass GetRegexPatternSetRequest data as a hash:
{
name: "EntityName", # required
scope: "CLOUDFRONT", # required, accepts CLOUDFRONT, REGIONAL
id: "EntityId", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
A unique identifier for the set.
-
#name ⇒ String
The name of the set.
-
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application.
Instance Attribute Details
#id ⇒ String
A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
4847 4848 4849 4850 4851 4852 4853 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4847 class GetRegexPatternSetRequest < Struct.new( :name, :scope, :id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the set. You cannot change the name after you create the set.
4847 4848 4849 4850 4851 4852 4853 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4847 class GetRegexPatternSetRequest < Struct.new( :name, :scope, :id) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope: `–scope=CLOUDFRONT –region=us-east-1`.
-
API and SDKs - For all calls, use the Region endpoint us-east-1.
4847 4848 4849 4850 4851 4852 4853 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4847 class GetRegexPatternSetRequest < Struct.new( :name, :scope, :id) SENSITIVE = [] include Aws::Structure end |