Class: Aws::WAFV2::Types::GetRegexPatternSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass GetRegexPatternSetRequest data as a hash:

{
  name: "EntityName", # required
  scope: "CLOUDFRONT", # required, accepts CLOUDFRONT, REGIONAL
  id: "EntityId", # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.

Returns:

  • (String)


4096
4097
4098
4099
4100
4101
4102
# File 'lib/aws-sdk-wafv2/types.rb', line 4096

class GetRegexPatternSetRequest < Struct.new(
  :name,
  :scope,
  :id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the set. You cannot change the name after you create the set.

Returns:

  • (String)


4096
4097
4098
4099
4100
4101
4102
# File 'lib/aws-sdk-wafv2/types.rb', line 4096

class GetRegexPatternSetRequest < Struct.new(
  :name,
  :scope,
  :id)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: `–scope=CLOUDFRONT –region=us-east-1`.

  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Returns:

  • (String)


4096
4097
4098
4099
4100
4101
4102
# File 'lib/aws-sdk-wafv2/types.rb', line 4096

class GetRegexPatternSetRequest < Struct.new(
  :name,
  :scope,
  :id)
  SENSITIVE = []
  include Aws::Structure
end