Class: Aws::WAFV2::Types::GetRegexPatternSetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetRegexPatternSetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lock_token ⇒ String
A token used for optimistic locking.
- #regex_pattern_set ⇒ Types::RegexPatternSet
Instance Attribute Details
#lock_token ⇒ String
A token used for optimistic locking. WAF returns a token to your
get and list requests, to mark the state of the entity at the
time of the request. To make changes to the entity associated with
the token, you provide the token to operations like update and
delete. WAF uses the token to ensure that no changes have been
made to the entity since you last retrieved it. If a change has been
made, the update fails with a WAFOptimisticLockException. If this
happens, perform another get, and use the new token returned by
that operation.
3872 3873 3874 3875 3876 3877 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3872 class GetRegexPatternSetResponse < Struct.new( :regex_pattern_set, :lock_token) SENSITIVE = [] include Aws::Structure end |
#regex_pattern_set ⇒ Types::RegexPatternSet
3872 3873 3874 3875 3876 3877 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3872 class GetRegexPatternSetResponse < Struct.new( :regex_pattern_set, :lock_token) SENSITIVE = [] include Aws::Structure end |