Class: Aws::WAFV2::Types::GetRevenueStatisticsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetRevenueStatisticsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency ⇒ String
The currency for the revenue amounts in the response.
-
#filters ⇒ Array<Types::MonetizationFilter>
Optional filters to narrow the results.
-
#group_by ⇒ String
The dimension to group results by: ‘NAME`, `CATEGORY`, `INTENT`, `ORGANIZATION`, or `WEBACL`.
-
#limit ⇒ Integer
The maximum number of results to return.
-
#next_marker ⇒ String
When you get a paginated response, this marker indicates that additional results are available.
-
#scope ⇒ String
Specifies whether this is for a Amazon CloudFront distribution (‘CLOUDFRONT`) or for a regional application (`REGIONAL`).
-
#sort_by ⇒ String
The field to sort results by: ‘REVENUE`, `PERCENTAGE`, or `NAME`.
-
#sort_order ⇒ String
The sort order: ‘ASC` for ascending or `DESC` for descending.
-
#statistic_type ⇒ String
‘TOP_SOURCES_BY_REVENUE` ranks revenue from AI bot traffic, grouped by the dimension you specify in the `GroupBy` parameter (`NAME`, `CATEGORY`, `INTENT`, `ORGANIZATION`, or `WEBACL`); `GroupBy` is required for this statistic type.
-
#time_window ⇒ Types::TimeWindow
The time range for the query.
Instance Attribute Details
#currency ⇒ String
The currency for the revenue amounts in the response.
3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 3937 3938 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3925 class GetRevenueStatisticsRequest < Struct.new( :statistic_type, :time_window, :scope, :currency, :group_by, :filters, :next_marker, :limit, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::MonetizationFilter>
Optional filters to narrow the results.
3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 3937 3938 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3925 class GetRevenueStatisticsRequest < Struct.new( :statistic_type, :time_window, :scope, :currency, :group_by, :filters, :next_marker, :limit, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#group_by ⇒ String
The dimension to group results by: ‘NAME`, `CATEGORY`, `INTENT`, `ORGANIZATION`, or `WEBACL`. Required when `StatisticType` is `TOP_SOURCES_BY_REVENUE`. Not required for `TOP_PATHS_BY_REVENUE`, where results are grouped by content path. If `StatisticType` is `TOP_SOURCES_BY_REVENUE` and `GroupBy` is omitted, the request is rejected with a `WAFInvalidParameterException`.
3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 3937 3938 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3925 class GetRevenueStatisticsRequest < Struct.new( :statistic_type, :time_window, :scope, :currency, :group_by, :filters, :next_marker, :limit, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of results to return.
3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 3937 3938 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3925 class GetRevenueStatisticsRequest < Struct.new( :statistic_type, :time_window, :scope, :currency, :group_by, :filters, :next_marker, :limit, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
When you get a paginated response, this marker indicates that additional results are available. Use it in a subsequent request to retrieve the next page of results.
3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 3937 3938 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3925 class GetRevenueStatisticsRequest < Struct.new( :statistic_type, :time_window, :scope, :currency, :group_by, :filters, :next_marker, :limit, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for a Amazon CloudFront distribution (‘CLOUDFRONT`) or for a regional application (`REGIONAL`).
3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 3937 3938 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3925 class GetRevenueStatisticsRequest < Struct.new( :statistic_type, :time_window, :scope, :currency, :group_by, :filters, :next_marker, :limit, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The field to sort results by: ‘REVENUE`, `PERCENTAGE`, or `NAME`.
3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 3937 3938 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3925 class GetRevenueStatisticsRequest < Struct.new( :statistic_type, :time_window, :scope, :currency, :group_by, :filters, :next_marker, :limit, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order: ‘ASC` for ascending or `DESC` for descending.
3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 3937 3938 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3925 class GetRevenueStatisticsRequest < Struct.new( :statistic_type, :time_window, :scope, :currency, :group_by, :filters, :next_marker, :limit, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#statistic_type ⇒ String
‘TOP_SOURCES_BY_REVENUE` ranks revenue from AI bot traffic, grouped by the dimension you specify in the `GroupBy` parameter (`NAME`, `CATEGORY`, `INTENT`, `ORGANIZATION`, or `WEBACL`); `GroupBy` is required for this statistic type. `TOP_PATHS_BY_REVENUE` ranks revenue by path.
3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 3937 3938 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3925 class GetRevenueStatisticsRequest < Struct.new( :statistic_type, :time_window, :scope, :currency, :group_by, :filters, :next_marker, :limit, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#time_window ⇒ Types::TimeWindow
The time range for the query. Specify start and end timestamps.
3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 3937 3938 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3925 class GetRevenueStatisticsRequest < Struct.new( :statistic_type, :time_window, :scope, :currency, :group_by, :filters, :next_marker, :limit, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |