Class: Aws::WAFV2::Types::GetRevenueStatisticsSummaryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetRevenueStatisticsSummaryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency ⇒ String
The currency for the revenue amounts in the response.
-
#filters ⇒ Array<Types::MonetizationFilter>
Optional filters to narrow the results.
-
#scope ⇒ String
Specifies whether this is for a Amazon CloudFront distribution (
CLOUDFRONT) or for a regional application (REGIONAL). -
#time_window ⇒ Types::TimeWindow
The time range for the revenue summary query.
Instance Attribute Details
#currency ⇒ String
The currency for the revenue amounts in the response. Currently only
USDC is supported.
3997 3998 3999 4000 4001 4002 4003 4004 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3997 class GetRevenueStatisticsSummaryRequest < Struct.new( :time_window, :scope, :currency, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::MonetizationFilter>
Optional filters to narrow the results. You can filter by source name, category, organization, intent, verified status, content path, web ACL ARN, or currency mode.
3997 3998 3999 4000 4001 4002 4003 4004 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3997 class GetRevenueStatisticsSummaryRequest < Struct.new( :time_window, :scope, :currency, :filters) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for a Amazon CloudFront distribution
(CLOUDFRONT) or for a regional application (REGIONAL). AI bot
monetization is only available for CLOUDFRONT scope.
3997 3998 3999 4000 4001 4002 4003 4004 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3997 class GetRevenueStatisticsSummaryRequest < Struct.new( :time_window, :scope, :currency, :filters) SENSITIVE = [] include Aws::Structure end |
#time_window ⇒ Types::TimeWindow
The time range for the revenue summary query. Specify start and end timestamps.
3997 3998 3999 4000 4001 4002 4003 4004 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3997 class GetRevenueStatisticsSummaryRequest < Struct.new( :time_window, :scope, :currency, :filters) SENSITIVE = [] include Aws::Structure end |