Class: Aws::WAFV2::Types::GetRevenueStatisticsSummaryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#currencyString

The currency for the revenue amounts in the response. Currently only ‘USDC` is supported.

Returns:

  • (String)


3989
3990
3991
3992
3993
3994
3995
3996
# File 'lib/aws-sdk-wafv2/types.rb', line 3989

class GetRevenueStatisticsSummaryRequest < Struct.new(
  :time_window,
  :scope,
  :currency,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::MonetizationFilter>

Optional filters to narrow the results. You can filter by source name, category, organization, intent, verified status, content path, web ACL ARN, or currency mode.

Returns:



3989
3990
3991
3992
3993
3994
3995
3996
# File 'lib/aws-sdk-wafv2/types.rb', line 3989

class GetRevenueStatisticsSummaryRequest < Struct.new(
  :time_window,
  :scope,
  :currency,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether this is for a Amazon CloudFront distribution (‘CLOUDFRONT`) or for a regional application (`REGIONAL`). AI bot monetization is only available for `CLOUDFRONT` scope.

Returns:

  • (String)


3989
3990
3991
3992
3993
3994
3995
3996
# File 'lib/aws-sdk-wafv2/types.rb', line 3989

class GetRevenueStatisticsSummaryRequest < Struct.new(
  :time_window,
  :scope,
  :currency,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end

#time_windowTypes::TimeWindow

The time range for the revenue summary query. Specify start and end timestamps.

Returns:



3989
3990
3991
3992
3993
3994
3995
3996
# File 'lib/aws-sdk-wafv2/types.rb', line 3989

class GetRevenueStatisticsSummaryRequest < Struct.new(
  :time_window,
  :scope,
  :currency,
  :filters)
  SENSITIVE = []
  include Aws::Structure
end