Class: Aws::WAFV2::Types::GetRevenueStatisticsSummaryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetRevenueStatisticsSummaryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency ⇒ String
The currency for the revenue amounts in the response.
-
#filters ⇒ Array<Types::MonetizationFilter>
Optional filters to narrow the results.
-
#scope ⇒ String
Specifies whether this is for a Amazon CloudFront distribution (‘CLOUDFRONT`) or for a regional application (`REGIONAL`).
-
#time_window ⇒ Types::TimeWindow
The time range for the revenue summary query.
Instance Attribute Details
#currency ⇒ String
The currency for the revenue amounts in the response. Currently only ‘USDC` is supported.
3989 3990 3991 3992 3993 3994 3995 3996 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3989 class GetRevenueStatisticsSummaryRequest < Struct.new( :time_window, :scope, :currency, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::MonetizationFilter>
Optional filters to narrow the results. You can filter by source name, category, organization, intent, verified status, content path, web ACL ARN, or currency mode.
3989 3990 3991 3992 3993 3994 3995 3996 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3989 class GetRevenueStatisticsSummaryRequest < Struct.new( :time_window, :scope, :currency, :filters) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for a Amazon CloudFront distribution (‘CLOUDFRONT`) or for a regional application (`REGIONAL`). AI bot monetization is only available for `CLOUDFRONT` scope.
3989 3990 3991 3992 3993 3994 3995 3996 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3989 class GetRevenueStatisticsSummaryRequest < Struct.new( :time_window, :scope, :currency, :filters) SENSITIVE = [] include Aws::Structure end |
#time_window ⇒ Types::TimeWindow
The time range for the revenue summary query. Specify start and end timestamps.
3989 3990 3991 3992 3993 3994 3995 3996 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3989 class GetRevenueStatisticsSummaryRequest < Struct.new( :time_window, :scope, :currency, :filters) SENSITIVE = [] include Aws::Structure end |