Class: Aws::WAFV2::Types::GetRuleGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the entity.

Returns:

  • (String)


2538
2539
2540
2541
2542
2543
2544
2545
# File 'lib/aws-sdk-wafv2/types.rb', line 2538

class GetRuleGroupRequest < Struct.new(
  :name,
  :scope,
  :id,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#idString

A unique identifier for the rule group. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.

Returns:

  • (String)


2538
2539
2540
2541
2542
2543
2544
2545
# File 'lib/aws-sdk-wafv2/types.rb', line 2538

class GetRuleGroupRequest < Struct.new(
  :name,
  :scope,
  :id,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the rule group. You cannot change the name of a rule group after you create it.

Returns:

  • (String)


2538
2539
2540
2541
2542
2543
2544
2545
# File 'lib/aws-sdk-wafv2/types.rb', line 2538

class GetRuleGroupRequest < Struct.new(
  :name,
  :scope,
  :id,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, or an Amazon Cognito user pool.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: `–scope=CLOUDFRONT –region=us-east-1`.

  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Returns:

  • (String)


2538
2539
2540
2541
2542
2543
2544
2545
# File 'lib/aws-sdk-wafv2/types.rb', line 2538

class GetRuleGroupRequest < Struct.new(
  :name,
  :scope,
  :id,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end