Class: Aws::WAFV2::Types::GetRuleGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetRuleGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the entity.
-
#id ⇒ String
A unique identifier for the rule group.
-
#name ⇒ String
The name of the rule group.
-
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the entity.
2538 2539 2540 2541 2542 2543 2544 2545 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2538 class GetRuleGroupRequest < Struct.new( :name, :scope, :id, :arn) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A unique identifier for the rule group. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
2538 2539 2540 2541 2542 2543 2544 2545 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2538 class GetRuleGroupRequest < Struct.new( :name, :scope, :id, :arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule group. You cannot change the name of a rule group after you create it.
2538 2539 2540 2541 2542 2543 2544 2545 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2538 class GetRuleGroupRequest < Struct.new( :name, :scope, :id, :arn) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, or an Amazon Cognito user pool.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope: `–scope=CLOUDFRONT –region=us-east-1`.
-
API and SDKs - For all calls, use the Region endpoint us-east-1.
2538 2539 2540 2541 2542 2543 2544 2545 |
# File 'lib/aws-sdk-wafv2/types.rb', line 2538 class GetRuleGroupRequest < Struct.new( :name, :scope, :id, :arn) SENSITIVE = [] include Aws::Structure end |