Class: Aws::WAFV2::Types::GetSampledRequestsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#population_sizeInteger

The total number of requests from which GetSampledRequests got a sample of MaxItems requests. If PopulationSize is less than MaxItems, the sample includes every request that your Amazon Web Services resource received during the specified time range.

Returns:

  • (Integer)


4254
4255
4256
4257
4258
4259
4260
# File 'lib/aws-sdk-wafv2/types.rb', line 4254

class GetSampledRequestsResponse < Struct.new(
  :sampled_requests,
  :population_size,
  :time_window)
  SENSITIVE = []
  include Aws::Structure
end

#sampled_requestsArray<Types::SampledHTTPRequest>

A complex type that contains detailed information about each of the requests in the sample.

Returns:



4254
4255
4256
4257
4258
4259
4260
# File 'lib/aws-sdk-wafv2/types.rb', line 4254

class GetSampledRequestsResponse < Struct.new(
  :sampled_requests,
  :population_size,
  :time_window)
  SENSITIVE = []
  include Aws::Structure
end

#time_windowTypes::TimeWindow

Usually, TimeWindow is the time range that you specified in the GetSampledRequests request. However, if your Amazon Web Services resource received more than 5,000 requests during the time range that you specified in the request, GetSampledRequests returns the time range for the first 5,000 requests. Times are in Coordinated Universal Time (UTC) format.

Returns:



4254
4255
4256
4257
4258
4259
4260
# File 'lib/aws-sdk-wafv2/types.rb', line 4254

class GetSampledRequestsResponse < Struct.new(
  :sampled_requests,
  :population_size,
  :time_window)
  SENSITIVE = []
  include Aws::Structure
end