Class: Aws::WAFV2::Types::GetSampledRequestsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetSampledRequestsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#population_size ⇒ Integer
The total number of requests from which
GetSampledRequestsgot a sample ofMaxItemsrequests. -
#sampled_requests ⇒ Array<Types::SampledHTTPRequest>
A complex type that contains detailed information about each of the requests in the sample.
-
#time_window ⇒ Types::TimeWindow
Usually,
TimeWindowis the time range that you specified in theGetSampledRequestsrequest.
Instance Attribute Details
#population_size ⇒ Integer
The total number of requests from which GetSampledRequests got a
sample of MaxItems requests. If PopulationSize is less than
MaxItems, the sample includes every request that your Amazon Web
Services resource received during the specified time range.
4236 4237 4238 4239 4240 4241 4242 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4236 class GetSampledRequestsResponse < Struct.new( :sampled_requests, :population_size, :time_window) SENSITIVE = [] include Aws::Structure end |
#sampled_requests ⇒ Array<Types::SampledHTTPRequest>
A complex type that contains detailed information about each of the requests in the sample.
4236 4237 4238 4239 4240 4241 4242 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4236 class GetSampledRequestsResponse < Struct.new( :sampled_requests, :population_size, :time_window) SENSITIVE = [] include Aws::Structure end |
#time_window ⇒ Types::TimeWindow
Usually, TimeWindow is the time range that you specified in the
GetSampledRequests request. However, if your Amazon Web Services
resource received more than 5,000 requests during the time range
that you specified in the request, GetSampledRequests returns the
time range for the first 5,000 requests. Times are in Coordinated
Universal Time (UTC) format.
4236 4237 4238 4239 4240 4241 4242 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4236 class GetSampledRequestsResponse < Struct.new( :sampled_requests, :population_size, :time_window) SENSITIVE = [] include Aws::Structure end |