Class: Aws::WAFV2::Types::GetTopPathStatisticsByTrafficRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetTopPathStatisticsByTrafficRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bot_category ⇒ String
Filters the results to include only traffic from bots in the specified category.
-
#bot_name ⇒ String
Filters the results to include only traffic from the specified bot.
-
#bot_organization ⇒ String
Filters the results to include only traffic from bots belonging to the specified organization.
-
#limit ⇒ Integer
The maximum number of path statistics to return.
-
#next_marker ⇒ String
When you request a list of objects with a
Limitsetting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns aNextMarkervalue in the response. -
#number_of_top_traffic_bots_per_path ⇒ Integer
The maximum number of top bots to include in the statistics for each path.
-
#scope ⇒ String
Specifies whether the web ACL is for an Amazon Web Services CloudFront distribution or for a regional application.
-
#time_window ⇒ Types::TimeWindow
The time window for which you want to retrieve path statistics.
-
#uri_path_prefix ⇒ String
A URI path prefix to filter the results.
-
#web_acl_arn ⇒ String
The Amazon Resource Name (ARN) of the web ACL for which you want to retrieve path statistics.
Instance Attribute Details
#bot_category ⇒ String
Filters the results to include only traffic from bots in the specified category. For example, you can filter by ai to see only AI crawler traffic, or search_engine to see only search engine bot traffic. When you apply this filter, the Source field is populated in the response.
4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4010 class GetTopPathStatisticsByTrafficRequest < Struct.new( :web_acl_arn, :scope, :uri_path_prefix, :time_window, :bot_category, :bot_organization, :bot_name, :limit, :number_of_top_traffic_bots_per_path, :next_marker) SENSITIVE = [] include Aws::Structure end |
#bot_name ⇒ String
Filters the results to include only traffic from the specified bot. For example, you can filter by gptbot or googlebot. When you apply this filter, the Source field is populated in the response.
4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4010 class GetTopPathStatisticsByTrafficRequest < Struct.new( :web_acl_arn, :scope, :uri_path_prefix, :time_window, :bot_category, :bot_organization, :bot_name, :limit, :number_of_top_traffic_bots_per_path, :next_marker) SENSITIVE = [] include Aws::Structure end |
#bot_organization ⇒ String
Filters the results to include only traffic from bots belonging to the specified organization. For example, you can filter by openai or google. When you apply this filter, the Source field is populated in the response.
4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4010 class GetTopPathStatisticsByTrafficRequest < Struct.new( :web_acl_arn, :scope, :uri_path_prefix, :time_window, :bot_category, :bot_organization, :bot_name, :limit, :number_of_top_traffic_bots_per_path, :next_marker) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of path statistics to return. Valid values are 1 to 100.
4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4010 class GetTopPathStatisticsByTrafficRequest < Struct.new( :web_acl_arn, :scope, :uri_path_prefix, :time_window, :bot_category, :bot_organization, :bot_name, :limit, :number_of_top_traffic_bots_per_path, :next_marker) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
When you request a list of objects with a Limit setting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns a NextMarker value in the response. To retrieve the next batch of objects, provide the marker from the prior call in your next request.
4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4010 class GetTopPathStatisticsByTrafficRequest < Struct.new( :web_acl_arn, :scope, :uri_path_prefix, :time_window, :bot_category, :bot_organization, :bot_name, :limit, :number_of_top_traffic_bots_per_path, :next_marker) SENSITIVE = [] include Aws::Structure end |
#number_of_top_traffic_bots_per_path ⇒ Integer
The maximum number of top bots to include in the statistics for each path. Valid values are 1 to 10.
4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4010 class GetTopPathStatisticsByTrafficRequest < Struct.new( :web_acl_arn, :scope, :uri_path_prefix, :time_window, :bot_category, :bot_organization, :bot_name, :limit, :number_of_top_traffic_bots_per_path, :next_marker) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether the web ACL is for an Amazon Web Services CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer, an AppSync GraphQL API, an Amazon Cognito user pool, an Amazon Web Services App Runner service, or an Amazon Web Services Verified Access instance.
4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4010 class GetTopPathStatisticsByTrafficRequest < Struct.new( :web_acl_arn, :scope, :uri_path_prefix, :time_window, :bot_category, :bot_organization, :bot_name, :limit, :number_of_top_traffic_bots_per_path, :next_marker) SENSITIVE = [] include Aws::Structure end |
#time_window ⇒ Types::TimeWindow
The time window for which you want to retrieve path statistics. The time window must be within the data retention period for your web ACL.
4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4010 class GetTopPathStatisticsByTrafficRequest < Struct.new( :web_acl_arn, :scope, :uri_path_prefix, :time_window, :bot_category, :bot_organization, :bot_name, :limit, :number_of_top_traffic_bots_per_path, :next_marker) SENSITIVE = [] include Aws::Structure end |
#uri_path_prefix ⇒ String
A URI path prefix to filter the results. When you specify this parameter, the operation returns statistics for individual URIs within the specified path prefix. For example, if you specify /api, the response includes statistics for paths like /api/v1/users and /api/v2/orders. If you don’t specify this parameter, the operation returns top-level path statistics.
4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4010 class GetTopPathStatisticsByTrafficRequest < Struct.new( :web_acl_arn, :scope, :uri_path_prefix, :time_window, :bot_category, :bot_organization, :bot_name, :limit, :number_of_top_traffic_bots_per_path, :next_marker) SENSITIVE = [] include Aws::Structure end |
#web_acl_arn ⇒ String
The Amazon Resource Name (ARN) of the web ACL for which you want to retrieve path statistics.
4010 4011 4012 4013 4014 4015 4016 4017 4018 4019 4020 4021 4022 4023 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4010 class GetTopPathStatisticsByTrafficRequest < Struct.new( :web_acl_arn, :scope, :uri_path_prefix, :time_window, :bot_category, :bot_organization, :bot_name, :limit, :number_of_top_traffic_bots_per_path, :next_marker) SENSITIVE = [] include Aws::Structure end |