Class: Aws::WAFV2::Types::GetTopPathStatisticsByTrafficResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_markerString

When you request a list of objects with a ‘Limit` setting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns a `NextMarker` value in the response. To retrieve the next batch of objects, provide the marker from the prior call in your next request.

Returns:

  • (String)


4348
4349
4350
4351
4352
4353
4354
4355
# File 'lib/aws-sdk-wafv2/types.rb', line 4348

class GetTopPathStatisticsByTrafficResponse < Struct.new(
  :path_statistics,
  :total_request_count,
  :next_marker,
  :top_categories)
  SENSITIVE = []
  include Aws::Structure
end

#path_statisticsArray<Types::PathStatistics>

The list of path statistics, ordered by request count. Each entry includes the path, request count, percentage of total traffic, and the top bots accessing that path.

Returns:



4348
4349
4350
4351
4352
4353
4354
4355
# File 'lib/aws-sdk-wafv2/types.rb', line 4348

class GetTopPathStatisticsByTrafficResponse < Struct.new(
  :path_statistics,
  :total_request_count,
  :next_marker,
  :top_categories)
  SENSITIVE = []
  include Aws::Structure
end

#top_categoriesArray<Types::PathStatistics>

Category-level aggregations for visualizing bot category to path relationships. This field is only populated when no bot filters are applied to the request. Each entry includes the bot category and the paths accessed by bots in that category.

Returns:



4348
4349
4350
4351
4352
4353
4354
4355
# File 'lib/aws-sdk-wafv2/types.rb', line 4348

class GetTopPathStatisticsByTrafficResponse < Struct.new(
  :path_statistics,
  :total_request_count,
  :next_marker,
  :top_categories)
  SENSITIVE = []
  include Aws::Structure
end

#total_request_countInteger

The total number of requests that match the query criteria within the specified time window.

Returns:

  • (Integer)


4348
4349
4350
4351
4352
4353
4354
4355
# File 'lib/aws-sdk-wafv2/types.rb', line 4348

class GetTopPathStatisticsByTrafficResponse < Struct.new(
  :path_statistics,
  :total_request_count,
  :next_marker,
  :top_categories)
  SENSITIVE = []
  include Aws::Structure
end