Class: Aws::WAFV2::Types::GetTopPathStatisticsByTrafficResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetTopPathStatisticsByTrafficResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_marker ⇒ String
When you request a list of objects with a ‘Limit` setting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns a `NextMarker` value in the response.
-
#path_statistics ⇒ Array<Types::PathStatistics>
The list of path statistics, ordered by request count.
-
#top_categories ⇒ Array<Types::PathStatistics>
Category-level aggregations for visualizing bot category to path relationships.
-
#total_request_count ⇒ Integer
The total number of requests that match the query criteria within the specified time window.
Instance Attribute Details
#next_marker ⇒ String
When you request a list of objects with a ‘Limit` setting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns a `NextMarker` value in the response. To retrieve the next batch of objects, provide the marker from the prior call in your next request.
4348 4349 4350 4351 4352 4353 4354 4355 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4348 class GetTopPathStatisticsByTrafficResponse < Struct.new( :path_statistics, :total_request_count, :next_marker, :top_categories) SENSITIVE = [] include Aws::Structure end |
#path_statistics ⇒ Array<Types::PathStatistics>
The list of path statistics, ordered by request count. Each entry includes the path, request count, percentage of total traffic, and the top bots accessing that path.
4348 4349 4350 4351 4352 4353 4354 4355 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4348 class GetTopPathStatisticsByTrafficResponse < Struct.new( :path_statistics, :total_request_count, :next_marker, :top_categories) SENSITIVE = [] include Aws::Structure end |
#top_categories ⇒ Array<Types::PathStatistics>
Category-level aggregations for visualizing bot category to path relationships. This field is only populated when no bot filters are applied to the request. Each entry includes the bot category and the paths accessed by bots in that category.
4348 4349 4350 4351 4352 4353 4354 4355 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4348 class GetTopPathStatisticsByTrafficResponse < Struct.new( :path_statistics, :total_request_count, :next_marker, :top_categories) SENSITIVE = [] include Aws::Structure end |
#total_request_count ⇒ Integer
The total number of requests that match the query criteria within the specified time window.
4348 4349 4350 4351 4352 4353 4354 4355 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4348 class GetTopPathStatisticsByTrafficResponse < Struct.new( :path_statistics, :total_request_count, :next_marker, :top_categories) SENSITIVE = [] include Aws::Structure end |