Class: Aws::WAFV2::Types::GetWebACLRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The unique identifier for the web ACL. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.

Returns:

  • (String)


3340
3341
3342
3343
3344
3345
3346
# File 'lib/aws-sdk-wafv2/types.rb', line 3340

class GetWebACLRequest < Struct.new(
  :name,
  :scope,
  :id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the web ACL. You cannot change the name of a web ACL after you create it.

Returns:

  • (String)


3340
3341
3342
3343
3344
3345
3346
# File 'lib/aws-sdk-wafv2/types.rb', line 3340

class GetWebACLRequest < Struct.new(
  :name,
  :scope,
  :id)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, an Amazon Cognito user pool, an App Runner service, or an Amazon Web Services Verified Access instance.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: ‘–scope=CLOUDFRONT –region=us-east-1`.

  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Returns:

  • (String)


3340
3341
3342
3343
3344
3345
3346
# File 'lib/aws-sdk-wafv2/types.rb', line 3340

class GetWebACLRequest < Struct.new(
  :name,
  :scope,
  :id)
  SENSITIVE = []
  include Aws::Structure
end