Class: Aws::WAFV2::Types::GetWebACLRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetWebACLRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
When making an API call, you may pass GetWebACLRequest data as a hash:
{
name: "EntityName", # required
scope: "CLOUDFRONT", # required, accepts CLOUDFRONT, REGIONAL
id: "EntityId", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the web ACL.
-
#name ⇒ String
The name of the web ACL.
-
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application.
Instance Attribute Details
#id ⇒ String
The unique identifier for the web ACL. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
5118 5119 5120 5121 5122 5123 5124 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5118 class GetWebACLRequest < Struct.new( :name, :scope, :id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the web ACL. You cannot change the name of a web ACL after you create it.
5118 5119 5120 5121 5122 5123 5124 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5118 class GetWebACLRequest < Struct.new( :name, :scope, :id) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope: `–scope=CLOUDFRONT –region=us-east-1`.
-
API and SDKs - For all calls, use the Region endpoint us-east-1.
5118 5119 5120 5121 5122 5123 5124 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5118 class GetWebACLRequest < Struct.new( :name, :scope, :id) SENSITIVE = [] include Aws::Structure end |