Class: Aws::WAFV2::Types::GetWebACLRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass GetWebACLRequest data as a hash:

{
  name: "EntityName", # required
  scope: "CLOUDFRONT", # required, accepts CLOUDFRONT, REGIONAL
  id: "EntityId", # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The unique identifier for the web ACL. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.

Returns:

  • (String)


4372
4373
4374
4375
4376
4377
4378
# File 'lib/aws-sdk-wafv2/types.rb', line 4372

class GetWebACLRequest < Struct.new(
  :name,
  :scope,
  :id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the web ACL. You cannot change the name of a web ACL after you create it.

Returns:

  • (String)


4372
4373
4374
4375
4376
4377
4378
# File 'lib/aws-sdk-wafv2/types.rb', line 4372

class GetWebACLRequest < Struct.new(
  :name,
  :scope,
  :id)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: `–scope=CLOUDFRONT –region=us-east-1`.

  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Returns:

  • (String)


4372
4373
4374
4375
4376
4377
4378
# File 'lib/aws-sdk-wafv2/types.rb', line 4372

class GetWebACLRequest < Struct.new(
  :name,
  :scope,
  :id)
  SENSITIVE = []
  include Aws::Structure
end