Class: Aws::WAFV2::Types::GetWebACLResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::GetWebACLResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lock_token ⇒ String
A token used for optimistic locking.
-
#web_acl ⇒ Types::WebACL
The web ACL specification.
Instance Attribute Details
#lock_token ⇒ String
A token used for optimistic locking. WAF returns a token to your `get` and `list` requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like `update` and `delete`. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a `WAFOptimisticLockException`. If this happens, perform another `get`, and use the new token returned by that operation.
4274 4275 4276 4277 4278 4279 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4274 class GetWebACLResponse < Struct.new( :web_acl, :lock_token) SENSITIVE = [] include Aws::Structure end |
#web_acl ⇒ Types::WebACL
The web ACL specification. You can modify the settings in this web ACL and use it to update this web ACL or create a new one.
4274 4275 4276 4277 4278 4279 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4274 class GetWebACLResponse < Struct.new( :web_acl, :lock_token) SENSITIVE = [] include Aws::Structure end |