Class: Aws::WAFV2::Types::HTTPHeader

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Part of the response from GetSampledRequests. This is a complex type that appears as Headers in the response syntax. HTTPHeader contains the names and values of all of the headers that appear in one of the web requests.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the HTTP header.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
# File 'lib/aws-sdk-wafv2/types.rb', line 4532

class HTTPHeader < Struct.new(
  :name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value of the HTTP header.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
# File 'lib/aws-sdk-wafv2/types.rb', line 4532

class HTTPHeader < Struct.new(
  :name,
  :value)
  SENSITIVE = []
  include Aws::Structure
end