Class: Aws::WAFV2::Types::HeaderMatchPattern

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass HeaderMatchPattern data as a hash:

{
  all: {
  },
  included_headers: ["FieldToMatchData"],
  excluded_headers: ["FieldToMatchData"],
}

The filter to use to identify the subset of headers to inspect in a web request.

You must specify exactly one setting: either `All`, `IncludedHeaders`, or `ExcludedHeaders`.

Example JSON: `“HeaderMatchPattern”: { “ExcludedHeaders”: “KeyToExclude2” }`

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allTypes::All

Inspect all headers.

Returns:



5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-wafv2/types.rb', line 5282

class HeaderMatchPattern < Struct.new(
  :all,
  :included_headers,
  :excluded_headers)
  SENSITIVE = []
  include Aws::Structure
end

#excluded_headersArray<String>

Inspect only the headers whose keys don't match any of the strings specified here.

Returns:

  • (Array<String>)


5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-wafv2/types.rb', line 5282

class HeaderMatchPattern < Struct.new(
  :all,
  :included_headers,
  :excluded_headers)
  SENSITIVE = []
  include Aws::Structure
end

#included_headersArray<String>

Inspect only the headers that have a key that matches one of the strings specified here.

Returns:

  • (Array<String>)


5282
5283
5284
5285
5286
5287
5288
# File 'lib/aws-sdk-wafv2/types.rb', line 5282

class HeaderMatchPattern < Struct.new(
  :all,
  :included_headers,
  :excluded_headers)
  SENSITIVE = []
  include Aws::Structure
end