Class: Aws::WAFV2::Types::IPSetSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::IPSetSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
High-level information about an IPSet, returned by operations like create and list. This provides information like the ID, that you can use to retrieve and manage an `IPSet`, and the ARN, that you provide to the IPSetReferenceStatement to use the address set in a Rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the entity.
-
#description ⇒ String
A description of the IP set that helps with identification.
-
#id ⇒ String
A unique identifier for the set.
-
#lock_token ⇒ String
A token used for optimistic locking.
-
#name ⇒ String
The name of the IP set.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the entity.
4776 4777 4778 4779 4780 4781 4782 4783 4784 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4776 class IPSetSummary < Struct.new( :name, :id, :description, :lock_token, :arn) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the IP set that helps with identification.
4776 4777 4778 4779 4780 4781 4782 4783 4784 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4776 class IPSetSummary < Struct.new( :name, :id, :description, :lock_token, :arn) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
4776 4777 4778 4779 4780 4781 4782 4783 4784 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4776 class IPSetSummary < Struct.new( :name, :id, :description, :lock_token, :arn) SENSITIVE = [] include Aws::Structure end |
#lock_token ⇒ String
A token used for optimistic locking. WAF returns a token to your `get` and `list` requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like `update` and `delete`. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a `WAFOptimisticLockException`. If this happens, perform another `get`, and use the new token returned by that operation.
4776 4777 4778 4779 4780 4781 4782 4783 4784 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4776 class IPSetSummary < Struct.new( :name, :id, :description, :lock_token, :arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the IP set. You cannot change the name of an `IPSet` after you create it.
4776 4777 4778 4779 4780 4781 4782 4783 4784 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4776 class IPSetSummary < Struct.new( :name, :id, :description, :lock_token, :arn) SENSITIVE = [] include Aws::Structure end |