Class: Aws::WAFV2::Types::JA3Fingerprint
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::JA3Fingerprint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Match against the request’s JA3 fingerprint header. The header contains a hash fingerprint of the TLS Client Hello packet for the request.
<note markdown=“1”> You can use this choice only with a string match ‘ByteMatchStatement` with the `PositionalConstraint` set to `EXACTLY`.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fallback_behavior ⇒ String
The match status to assign to the web request if the request doesn’t have a JA3 fingerprint.
Instance Attribute Details
#fallback_behavior ⇒ String
The match status to assign to the web request if the request doesn’t have a JA3 fingerprint.
You can specify the following fallback behaviors:
-
‘MATCH` - Treat the web request as matching the rule statement. WAF applies the rule action to the request.
-
‘NO_MATCH` - Treat the web request as not matching the rule statement.
3859 3860 3861 3862 3863 |
# File 'lib/aws-sdk-wafv2/types.rb', line 3859 class JA3Fingerprint < Struct.new( :fallback_behavior) SENSITIVE = [] include Aws::Structure end |