Class: Aws::WAFV2::Types::JsonBody
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::JsonBody
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
When making an API call, you may pass JsonBody data as a hash:
{
match_pattern: { # required
all: {
},
included_paths: ["JsonPointerPath"],
},
match_scope: "ALL", # required, accepts ALL, KEY, VALUE
invalid_fallback_behavior: "MATCH", # accepts MATCH, NO_MATCH, EVALUATE_AS_STRING
}
The body of a web request, inspected as JSON. The body immediately follows the request headers. This is used in the FieldToMatch specification.
Use the specifications in this object to indicate which parts of the JSON body to inspect using the rule's inspection criteria. WAF inspects only the parts of the JSON that result from the matches that you indicate.
Example JSON: `“JsonBody”: { “MatchPattern”: { “All”: {} }, “MatchScope”: “ALL” }`
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#invalid_fallback_behavior ⇒ String
What WAF should do if it fails to completely parse the JSON body.
-
#match_pattern ⇒ Types::JsonMatchPattern
The patterns to look for in the JSON body.
-
#match_scope ⇒ String
The parts of the JSON to match against using the `MatchPattern`.
Instance Attribute Details
#invalid_fallback_behavior ⇒ String
What WAF should do if it fails to completely parse the JSON body. The options are the following:
-
`EVALUATE_AS_STRING` - Inspect the body as plain text. WAF applies the text transformations and inspection criteria that you defined for the JSON inspection to the body text string.
-
`MATCH` - Treat the web request as matching the rule statement. WAF applies the rule action to the request.
-
`NO_MATCH` - Treat the web request as not matching the rule statement.
If you don't provide this setting, WAF parses and evaluates the content only up to the first parsing failure that it encounters.
WAF does its best to parse the entire JSON body, but might be forced to stop for reasons such as invalid characters, duplicate keys, truncation, and any content whose root node isn't an object or an array.
WAF parses the JSON in the following examples as two valid key, value pairs:
-
Missing comma: `“key1”:“value1”“key2”:“value2”`
-
Missing colon: `“key1”:“value1”,“key2”“value2”`
-
Extra colons: `Aws::WAFV2::Types::JsonBody.“key1”“key1”::“value1”,“key2”“value2”`
4854 4855 4856 4857 4858 4859 4860 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4854 class JsonBody < Struct.new( :match_pattern, :match_scope, :invalid_fallback_behavior) SENSITIVE = [] include Aws::Structure end |
#match_pattern ⇒ Types::JsonMatchPattern
The patterns to look for in the JSON body. WAF inspects the results of these pattern matches against the rule inspection criteria.
4854 4855 4856 4857 4858 4859 4860 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4854 class JsonBody < Struct.new( :match_pattern, :match_scope, :invalid_fallback_behavior) SENSITIVE = [] include Aws::Structure end |
#match_scope ⇒ String
The parts of the JSON to match against using the `MatchPattern`. If you specify `All`, WAF matches against keys and values.
4854 4855 4856 4857 4858 4859 4860 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4854 class JsonBody < Struct.new( :match_pattern, :match_scope, :invalid_fallback_behavior) SENSITIVE = [] include Aws::Structure end |