Class: Aws::WAFV2::Types::JsonMatchPattern
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::JsonMatchPattern
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
The patterns to look for in the JSON body. WAF inspects the results of these pattern matches against the rule inspection criteria. This is used with the FieldToMatch option JsonBody.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#all ⇒ Types::All
Match all of the elements.
-
#included_paths ⇒ Array<String>
Match only the specified include paths.
Instance Attribute Details
#all ⇒ Types::All
Match all of the elements. See also MatchScope in JsonBody.
You must specify either this setting or the IncludedPaths setting, but not both.
4928 4929 4930 4931 4932 4933 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4928 class JsonMatchPattern < Struct.new( :all, :included_paths) SENSITIVE = [] include Aws::Structure end |
#included_paths ⇒ Array<String>
Match only the specified include paths. See also MatchScope in JsonBody.
Provide the include paths using JSON Pointer syntax. For example, ‘“IncludedPaths”: [“/dogs/0/name”, “/dogs/1/name”]`. For information about this syntax, see the Internet Engineering Task Force (IETF) documentation [JavaScript Object Notation (JSON) Pointer].
You must specify either this setting or the All setting, but not both.
<note markdown=“1”> Don’t use this option to include all paths. Instead, use the All setting.
</note>
4928 4929 4930 4931 4932 4933 |
# File 'lib/aws-sdk-wafv2/types.rb', line 4928 class JsonMatchPattern < Struct.new( :all, :included_paths) SENSITIVE = [] include Aws::Structure end |