Class: Aws::WAFV2::Types::ListRuleGroupsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ListRuleGroupsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_marker ⇒ String
When you request a list of objects with a
Limitsetting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns aNextMarkervalue in the response. -
#rule_groups ⇒ Array<Types::RuleGroupSummary>
Array of rule groups.
Instance Attribute Details
#next_marker ⇒ String
When you request a list of objects with a Limit setting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns a NextMarker value in the response. To retrieve the next batch of objects, provide the marker from the prior call in your next request.
5664 5665 5666 5667 5668 5669 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5664 class ListRuleGroupsResponse < Struct.new( :next_marker, :rule_groups) SENSITIVE = [] include Aws::Structure end |
#rule_groups ⇒ Array<Types::RuleGroupSummary>
Array of rule groups. If you specified a Limit in your request, this might not be the full list.
5664 5665 5666 5667 5668 5669 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5664 class ListRuleGroupsResponse < Struct.new( :next_marker, :rule_groups) SENSITIVE = [] include Aws::Structure end |