Class: Aws::WAFV2::Types::LoggingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::LoggingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
When making an API call, you may pass LoggingConfiguration data as a hash:
{
resource_arn: "ResourceArn", # required
log_destination_configs: ["ResourceArn"], # required
redacted_fields: [
{
single_header: {
name: "FieldToMatchData", # required
},
single_query_argument: {
name: "FieldToMatchData", # required
},
all_query_arguments: {
},
uri_path: {
},
query_string: {
},
body: {
},
method: {
},
json_body: {
match_pattern: { # required
all: {
},
included_paths: ["JsonPointerPath"],
},
match_scope: "ALL", # required, accepts ALL, KEY, VALUE
invalid_fallback_behavior: "MATCH", # accepts MATCH, NO_MATCH, EVALUATE_AS_STRING
},
},
],
managed_by_firewall_manager: false,
logging_filter: {
filters: [ # required
{
behavior: "KEEP", # required, accepts KEEP, DROP
requirement: "MEETS_ALL", # required, accepts MEETS_ALL, MEETS_ANY
conditions: [ # required
{
action_condition: {
action: "ALLOW", # required, accepts ALLOW, BLOCK, COUNT, CAPTCHA, EXCLUDED_AS_COUNT
},
label_name_condition: {
label_name: "LabelName", # required
},
},
],
},
],
default_behavior: "KEEP", # required, accepts KEEP, DROP
},
}
Defines an association between logging destinations and a web ACL resource, for logging from WAF. As part of the association, you can specify parts of the standard logging fields to keep out of the logs and you can specify filters so that you log only a subset of the logging records.
<note markdown=“1”> You can define one logging destination per web ACL.
</note>
You can access information about the traffic that WAF inspects using the following steps:
-
Create your logging destination. You can use an Amazon CloudWatch Logs log group, an Amazon Simple Storage Service (Amazon S3) bucket, or an Amazon Kinesis Data Firehose. For information about configuring logging destinations and the permissions that are required for each, see [Logging web ACL traffic information] in the *WAF Developer Guide*.
-
Associate your logging destination to your web ACL using a `PutLoggingConfiguration` request.
When you successfully enable logging using a `PutLoggingConfiguration` request, WAF creates an additional role or policy that is required to write logs to the logging destination. For an Amazon CloudWatch Logs log group, WAF creates a resource policy on the log group. For an Amazon S3 bucket, WAF creates a bucket policy. For an Amazon Kinesis Data Firehose, WAF creates a service-linked role.
For additional information about web ACL logging, see [Logging web ACL traffic information] in the *WAF Developer Guide*.
[1]: docs.aws.amazon.com/waf/latest/developerguide/logging.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_destination_configs ⇒ Array<String>
The logging destination configuration that you want to associate with the web ACL.
-
#logging_filter ⇒ Types::LoggingFilter
Filtering that specifies which web requests are kept in the logs and which are dropped.
-
#managed_by_firewall_manager ⇒ Boolean
Indicates whether the logging configuration was created by Firewall Manager, as part of an WAF policy configuration.
-
#redacted_fields ⇒ Array<Types::FieldToMatch>
The parts of the request that you want to keep out of the logs.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the web ACL that you want to associate with `LogDestinationConfigs`.
Instance Attribute Details
#log_destination_configs ⇒ Array<String>
The logging destination configuration that you want to associate with the web ACL.
<note markdown=“1”> You can associate one logging destination to a web ACL.
</note>
5923 5924 5925 5926 5927 5928 5929 5930 5931 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5923 class LoggingConfiguration < Struct.new( :resource_arn, :log_destination_configs, :redacted_fields, :managed_by_firewall_manager, :logging_filter) SENSITIVE = [] include Aws::Structure end |
#logging_filter ⇒ Types::LoggingFilter
Filtering that specifies which web requests are kept in the logs and which are dropped. You can filter on the rule action and on the web request labels that were applied by matching rules during web ACL evaluation.
5923 5924 5925 5926 5927 5928 5929 5930 5931 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5923 class LoggingConfiguration < Struct.new( :resource_arn, :log_destination_configs, :redacted_fields, :managed_by_firewall_manager, :logging_filter) SENSITIVE = [] include Aws::Structure end |
#managed_by_firewall_manager ⇒ Boolean
Indicates whether the logging configuration was created by Firewall Manager, as part of an WAF policy configuration. If true, only Firewall Manager can modify or delete the configuration.
5923 5924 5925 5926 5927 5928 5929 5930 5931 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5923 class LoggingConfiguration < Struct.new( :resource_arn, :log_destination_configs, :redacted_fields, :managed_by_firewall_manager, :logging_filter) SENSITIVE = [] include Aws::Structure end |
#redacted_fields ⇒ Array<Types::FieldToMatch>
The parts of the request that you want to keep out of the logs. For example, if you redact the `SingleHeader` field, the `HEADER` field in the logs will be `xxx`.
<note markdown=“1”> You can specify only the following fields for redaction: `UriPath`, `QueryString`, `SingleHeader`, `Method`, and `JsonBody`.
</note>
5923 5924 5925 5926 5927 5928 5929 5930 5931 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5923 class LoggingConfiguration < Struct.new( :resource_arn, :log_destination_configs, :redacted_fields, :managed_by_firewall_manager, :logging_filter) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the web ACL that you want to associate with `LogDestinationConfigs`.
5923 5924 5925 5926 5927 5928 5929 5930 5931 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5923 class LoggingConfiguration < Struct.new( :resource_arn, :log_destination_configs, :redacted_fields, :managed_by_firewall_manager, :logging_filter) SENSITIVE = [] include Aws::Structure end |