Class: Aws::WAFV2::Types::ManagedRuleGroupConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Additional information that’s used by a managed rule group. Many managed rule groups don’t require this.

Use the ‘AWSManagedRulesATPRuleSet` configuration object for the account takeover prevention managed rule group, to provide information such as the sign-in page of your application and the type of content to accept or reject from the client.

Use the ‘AWSManagedRulesBotControlRuleSet` configuration object to configure the protection level that you want the Bot Control rule group to use.

For example specifications, see the examples section of CreateWebACL.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_managed_rules_atp_rule_setTypes::AWSManagedRulesATPRuleSet

Additional configuration for using the account takeover prevention (ATP) managed rule group, ‘AWSManagedRulesATPRuleSet`. Use this to provide login request information to the rule group. For web ACLs that protect CloudFront distributions, use this to also provide the information about how your distribution responds to login requests.

This configuration replaces the individual configuration fields in ‘ManagedRuleGroupConfig` and provides additional feature configuration.

For information about using the ATP managed rule group, see [WAF Fraud Control account takeover prevention (ATP) rule group] and

WAF Fraud Control account takeover prevention (ATP)][2

in the *WAF

Developer Guide*.

[1]: docs.aws.amazon.com/waf/latest/developerguide/aws-managed-rule-groups-atp.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-atp.html



4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
# File 'lib/aws-sdk-wafv2/types.rb', line 4440

class ManagedRuleGroupConfig < Struct.new(
  :login_path,
  :payload_type,
  :username_field,
  :password_field,
  :aws_managed_rules_bot_control_rule_set,
  :aws_managed_rules_atp_rule_set)
  SENSITIVE = []
  include Aws::Structure
end

#aws_managed_rules_bot_control_rule_setTypes::AWSManagedRulesBotControlRuleSet

Additional configuration for using the Bot Control managed rule group. Use this to specify the inspection level that you want to use. For information about using the Bot Control managed rule group, see [WAF Bot Control rule group] and [WAF Bot Control] in the *WAF Developer Guide*.

[1]: docs.aws.amazon.com/waf/latest/developerguide/aws-managed-rule-groups-bot.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-bot-control.html



4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
# File 'lib/aws-sdk-wafv2/types.rb', line 4440

class ManagedRuleGroupConfig < Struct.new(
  :login_path,
  :payload_type,
  :username_field,
  :password_field,
  :aws_managed_rules_bot_control_rule_set,
  :aws_managed_rules_atp_rule_set)
  SENSITIVE = []
  include Aws::Structure
end

#login_pathString

<note markdown=“1”> Instead of this setting, provide your configuration under ‘AWSManagedRulesATPRuleSet`.

</note>

Returns:

  • (String)


4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
# File 'lib/aws-sdk-wafv2/types.rb', line 4440

class ManagedRuleGroupConfig < Struct.new(
  :login_path,
  :payload_type,
  :username_field,
  :password_field,
  :aws_managed_rules_bot_control_rule_set,
  :aws_managed_rules_atp_rule_set)
  SENSITIVE = []
  include Aws::Structure
end

#password_fieldTypes::PasswordField

<note markdown=“1”> Instead of this setting, provide your configuration under ‘AWSManagedRulesATPRuleSet` `RequestInspection`.

</note>


4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
# File 'lib/aws-sdk-wafv2/types.rb', line 4440

class ManagedRuleGroupConfig < Struct.new(
  :login_path,
  :payload_type,
  :username_field,
  :password_field,
  :aws_managed_rules_bot_control_rule_set,
  :aws_managed_rules_atp_rule_set)
  SENSITIVE = []
  include Aws::Structure
end

#payload_typeString

<note markdown=“1”> Instead of this setting, provide your configuration under ‘AWSManagedRulesATPRuleSet` `RequestInspection`.

</note>

Returns:

  • (String)


4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
# File 'lib/aws-sdk-wafv2/types.rb', line 4440

class ManagedRuleGroupConfig < Struct.new(
  :login_path,
  :payload_type,
  :username_field,
  :password_field,
  :aws_managed_rules_bot_control_rule_set,
  :aws_managed_rules_atp_rule_set)
  SENSITIVE = []
  include Aws::Structure
end

#username_fieldTypes::UsernameField

<note markdown=“1”> Instead of this setting, provide your configuration under ‘AWSManagedRulesATPRuleSet` `RequestInspection`.

</note>


4440
4441
4442
4443
4444
4445
4446
4447
4448
4449
# File 'lib/aws-sdk-wafv2/types.rb', line 4440

class ManagedRuleGroupConfig < Struct.new(
  :login_path,
  :payload_type,
  :username_field,
  :password_field,
  :aws_managed_rules_bot_control_rule_set,
  :aws_managed_rules_atp_rule_set)
  SENSITIVE = []
  include Aws::Structure
end