Class: Aws::WAFV2::Types::ManagedRuleGroupConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Additional information that's used by a managed rule group. Many managed rule groups don't require this.

Use the `AWSManagedRulesBotControlRuleSet` configuration object to configure the protection level that you want the Bot Control rule group to use.

For example specifications, see the examples section of CreateWebACL.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_managed_rules_bot_control_rule_setTypes::AWSManagedRulesBotControlRuleSet

Additional configuration for using the Bot Control managed rule group. Use this to specify the inspection level that you want to use. For information about using the Bot Control managed rule group, see [WAF Bot Control rule group] and [WAF Bot Control] in the *WAF Developer Guide*.

[1]: docs.aws.amazon.com/waf/latest/developerguide/aws-managed-rule-groups-bot.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-bot-control.html



4252
4253
4254
4255
4256
4257
4258
4259
4260
# File 'lib/aws-sdk-wafv2/types.rb', line 4252

class ManagedRuleGroupConfig < Struct.new(
  :login_path,
  :payload_type,
  :username_field,
  :password_field,
  :aws_managed_rules_bot_control_rule_set)
  SENSITIVE = []
  include Aws::Structure
end

#login_pathString

The path of the login endpoint for your application. For example, for the URL `example.com/web/login`, you would provide the path `/web/login`.

Returns:

  • (String)


4252
4253
4254
4255
4256
4257
4258
4259
4260
# File 'lib/aws-sdk-wafv2/types.rb', line 4252

class ManagedRuleGroupConfig < Struct.new(
  :login_path,
  :payload_type,
  :username_field,
  :password_field,
  :aws_managed_rules_bot_control_rule_set)
  SENSITIVE = []
  include Aws::Structure
end

#password_fieldTypes::PasswordField

Details about your login page password field.



4252
4253
4254
4255
4256
4257
4258
4259
4260
# File 'lib/aws-sdk-wafv2/types.rb', line 4252

class ManagedRuleGroupConfig < Struct.new(
  :login_path,
  :payload_type,
  :username_field,
  :password_field,
  :aws_managed_rules_bot_control_rule_set)
  SENSITIVE = []
  include Aws::Structure
end

#payload_typeString

The payload type for your login endpoint, either JSON or form encoded.

Returns:

  • (String)


4252
4253
4254
4255
4256
4257
4258
4259
4260
# File 'lib/aws-sdk-wafv2/types.rb', line 4252

class ManagedRuleGroupConfig < Struct.new(
  :login_path,
  :payload_type,
  :username_field,
  :password_field,
  :aws_managed_rules_bot_control_rule_set)
  SENSITIVE = []
  include Aws::Structure
end

#username_fieldTypes::UsernameField

Details about your login page username field.



4252
4253
4254
4255
4256
4257
4258
4259
4260
# File 'lib/aws-sdk-wafv2/types.rb', line 4252

class ManagedRuleGroupConfig < Struct.new(
  :login_path,
  :payload_type,
  :username_field,
  :password_field,
  :aws_managed_rules_bot_control_rule_set)
  SENSITIVE = []
  include Aws::Structure
end