Class: Aws::WAFV2::Types::ManagedRuleGroupConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ManagedRuleGroupConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
When making an API call, you may pass ManagedRuleGroupConfig data as a hash:
{
login_path: "LoginPathString",
payload_type: "JSON", # accepts JSON, FORM_ENCODED
username_field: {
identifier: "FieldIdentifier", # required
},
password_field: {
identifier: "FieldIdentifier", # required
},
aws_managed_rules_bot_control_rule_set: {
inspection_level: "COMMON", # required, accepts COMMON, TARGETED
},
}
Additional information that's used by a managed rule group. Many managed rule groups don't require this.
Use the `AWSManagedRulesBotControlRuleSet` configuration object to configure the protection level that you want the Bot Control rule group to use.
For example specifications, see the examples section of CreateWebACL.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_managed_rules_bot_control_rule_set ⇒ Types::AWSManagedRulesBotControlRuleSet
Additional configuration for using the Bot Control managed rule group.
-
#login_path ⇒ String
The path of the login endpoint for your application.
-
#password_field ⇒ Types::PasswordField
Details about your login page password field.
-
#payload_type ⇒ String
The payload type for your login endpoint, either JSON or form encoded.
-
#username_field ⇒ Types::UsernameField
Details about your login page username field.
Instance Attribute Details
#aws_managed_rules_bot_control_rule_set ⇒ Types::AWSManagedRulesBotControlRuleSet
Additional configuration for using the Bot Control managed rule group. Use this to specify the inspection level that you want to use. For information about using the Bot Control managed rule group, see [WAF Bot Control rule group] and [WAF Bot Control] in the *WAF Developer Guide*.
[1]: docs.aws.amazon.com/waf/latest/developerguide/aws-managed-rule-groups-bot.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-bot-control.html
7726 7727 7728 7729 7730 7731 7732 7733 7734 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7726 class ManagedRuleGroupConfig < Struct.new( :login_path, :payload_type, :username_field, :password_field, :aws_managed_rules_bot_control_rule_set) SENSITIVE = [] include Aws::Structure end |
#login_path ⇒ String
The path of the login endpoint for your application. For example, for the URL `example.com/web/login`, you would provide the path `/web/login`.
7726 7727 7728 7729 7730 7731 7732 7733 7734 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7726 class ManagedRuleGroupConfig < Struct.new( :login_path, :payload_type, :username_field, :password_field, :aws_managed_rules_bot_control_rule_set) SENSITIVE = [] include Aws::Structure end |
#password_field ⇒ Types::PasswordField
Details about your login page password field.
7726 7727 7728 7729 7730 7731 7732 7733 7734 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7726 class ManagedRuleGroupConfig < Struct.new( :login_path, :payload_type, :username_field, :password_field, :aws_managed_rules_bot_control_rule_set) SENSITIVE = [] include Aws::Structure end |
#payload_type ⇒ String
The payload type for your login endpoint, either JSON or form encoded.
7726 7727 7728 7729 7730 7731 7732 7733 7734 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7726 class ManagedRuleGroupConfig < Struct.new( :login_path, :payload_type, :username_field, :password_field, :aws_managed_rules_bot_control_rule_set) SENSITIVE = [] include Aws::Structure end |
#username_field ⇒ Types::UsernameField
Details about your login page username field.
7726 7727 7728 7729 7730 7731 7732 7733 7734 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7726 class ManagedRuleGroupConfig < Struct.new( :login_path, :payload_type, :username_field, :password_field, :aws_managed_rules_bot_control_rule_set) SENSITIVE = [] include Aws::Structure end |