Class: Aws::WAFV2::Types::ManagedRuleGroupConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ManagedRuleGroupConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
When making an API call, you may pass ManagedRuleGroupConfig data as a hash:
{
login_path: "LoginPathString",
payload_type: "JSON", # accepts JSON, FORM_ENCODED
username_field: {
identifier: "FieldIdentifier", # required
},
password_field: {
identifier: "FieldIdentifier", # required
},
}
Additional information that's used by a managed rule group. Most managed rule groups don't require this.
Use this for the account takeover prevention managed rule group `AWSManagedRulesATPRuleSet`, to provide information about the sign-in page of your application.
You can provide multiple individual `ManagedRuleGroupConfig` objects for any rule group configuration, for example `UsernameField` and `PasswordField`. The configuration that you provide depends on the needs of the managed rule group. For the ATP managed rule group, you provide the following individual configuration objects: `LoginPath`, `PasswordField`, `PayloadType` and `UsernameField`.
For example specifications, see the examples section of CreateWebACL.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#login_path ⇒ String
The path of the login endpoint for your application.
-
#password_field ⇒ Types::PasswordField
Details about your login page password field.
-
#payload_type ⇒ String
The payload type for your login endpoint, either JSON or form encoded.
-
#username_field ⇒ Types::UsernameField
Details about your login page username field.
Instance Attribute Details
#login_path ⇒ String
The path of the login endpoint for your application. For example, for the URL `example.com/web/login`, you would provide the path `/web/login`.
6964 6965 6966 6967 6968 6969 6970 6971 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6964 class ManagedRuleGroupConfig < Struct.new( :login_path, :payload_type, :username_field, :password_field) SENSITIVE = [] include Aws::Structure end |
#password_field ⇒ Types::PasswordField
Details about your login page password field.
6964 6965 6966 6967 6968 6969 6970 6971 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6964 class ManagedRuleGroupConfig < Struct.new( :login_path, :payload_type, :username_field, :password_field) SENSITIVE = [] include Aws::Structure end |
#payload_type ⇒ String
The payload type for your login endpoint, either JSON or form encoded.
6964 6965 6966 6967 6968 6969 6970 6971 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6964 class ManagedRuleGroupConfig < Struct.new( :login_path, :payload_type, :username_field, :password_field) SENSITIVE = [] include Aws::Structure end |
#username_field ⇒ Types::UsernameField
Details about your login page username field.
6964 6965 6966 6967 6968 6969 6970 6971 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6964 class ManagedRuleGroupConfig < Struct.new( :login_path, :payload_type, :username_field, :password_field) SENSITIVE = [] include Aws::Structure end |