Class: Aws::WAFV2::Types::ManagedRuleGroupSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

High-level information about a managed rule group, returned by ListAvailableManagedRuleGroups. This provides information like the name and vendor name, that you provide when you add a ManagedRuleGroupStatement to a web ACL. Managed rule groups include Amazon Web Services Managed Rules rule groups, which are free of charge to WAF customers, and Amazon Web Services Marketplace managed rule groups, which you can subscribe to through Amazon Web Services Marketplace.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the managed rule group, provided by Amazon Web Services Managed Rules or the Amazon Web Services Marketplace seller who manages it.

Returns:

  • (String)


7569
7570
7571
7572
7573
7574
7575
7576
# File 'lib/aws-sdk-wafv2/types.rb', line 7569

class ManagedRuleGroupSummary < Struct.new(
  :vendor_name,
  :name,
  :versioning_supported,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the managed rule group. You use this, along with the vendor name, to identify the rule group.

Returns:

  • (String)


7569
7570
7571
7572
7573
7574
7575
7576
# File 'lib/aws-sdk-wafv2/types.rb', line 7569

class ManagedRuleGroupSummary < Struct.new(
  :vendor_name,
  :name,
  :versioning_supported,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#vendor_nameString

The name of the managed rule group vendor. You use this, along with the rule group name, to identify the rule group.

Returns:

  • (String)


7569
7570
7571
7572
7573
7574
7575
7576
# File 'lib/aws-sdk-wafv2/types.rb', line 7569

class ManagedRuleGroupSummary < Struct.new(
  :vendor_name,
  :name,
  :versioning_supported,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#versioning_supportedBoolean

Indicates whether the managed rule group is versioned. If it is, you can retrieve the versions list by calling ListAvailableManagedRuleGroupVersions.

Returns:

  • (Boolean)


7569
7570
7571
7572
7573
7574
7575
7576
# File 'lib/aws-sdk-wafv2/types.rb', line 7569

class ManagedRuleGroupSummary < Struct.new(
  :vendor_name,
  :name,
  :versioning_supported,
  :description)
  SENSITIVE = []
  include Aws::Structure
end