Class: Aws::WAFV2::Types::MonetizationConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::MonetizationConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
The monetization configuration for a web ACL or rule group. Specifies the cryptocurrency payment networks and currency mode for AI bot monetization. You must provide this configuration when any rule in the web ACL or rule group uses the ‘Monetize` action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#crypto_config ⇒ Types::CryptoConfig
The cryptocurrency payment configuration, including the blockchain networks and wallet addresses where you receive payments.
-
#currency_mode ⇒ String
Specifies whether the configuration uses real or test currency.
Instance Attribute Details
#crypto_config ⇒ Types::CryptoConfig
The cryptocurrency payment configuration, including the blockchain networks and wallet addresses where you receive payments.
7046 7047 7048 7049 7050 7051 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7046 class MonetizationConfig < Struct.new( :crypto_config, :currency_mode) SENSITIVE = [] include Aws::Structure end |
#currency_mode ⇒ String
Specifies whether the configuration uses real or test currency. Set to ‘REAL` to settle payments in USDC on production blockchain networks (Base, Solana). Set to `TEST` to settle on testnet networks (Base Sepolia, Solana Devnet) with tokens that have no monetary value. If not specified, defaults to `REAL`.
7046 7047 7048 7049 7050 7051 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7046 class MonetizationConfig < Struct.new( :crypto_config, :currency_mode) SENSITIVE = [] include Aws::Structure end |