Class: Aws::WAFV2::Types::PathStatistics
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::PathStatistics
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Statistics about bot traffic to a specific URI path, including the path, request count, percentage of total traffic, and the top bots accessing that path.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#path ⇒ String
The URI path.
-
#percentage ⇒ Float
The percentage of total requests that were made to this path.
-
#request_count ⇒ Integer
The number of requests to this path within the specified time window.
-
#source ⇒ Types::FilterSource
Information about the bot filter that was applied to generate these statistics.
-
#top_bots ⇒ Array<Types::BotStatistics>
The list of top bots accessing this path, ordered by request count.
Instance Attribute Details
#path ⇒ String
The URI path. For example, /api/ or /api/v1/users.
7368 7369 7370 7371 7372 7373 7374 7375 7376 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7368 class PathStatistics < Struct.new( :source, :path, :request_count, :percentage, :top_bots) SENSITIVE = [] include Aws::Structure end |
#percentage ⇒ Float
The percentage of total requests that were made to this path.
7368 7369 7370 7371 7372 7373 7374 7375 7376 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7368 class PathStatistics < Struct.new( :source, :path, :request_count, :percentage, :top_bots) SENSITIVE = [] include Aws::Structure end |
#request_count ⇒ Integer
The number of requests to this path within the specified time window.
7368 7369 7370 7371 7372 7373 7374 7375 7376 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7368 class PathStatistics < Struct.new( :source, :path, :request_count, :percentage, :top_bots) SENSITIVE = [] include Aws::Structure end |
#source ⇒ Types::FilterSource
Information about the bot filter that was applied to generate these statistics. This field is only populated when you filter by bot category, organization, or name.
7368 7369 7370 7371 7372 7373 7374 7375 7376 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7368 class PathStatistics < Struct.new( :source, :path, :request_count, :percentage, :top_bots) SENSITIVE = [] include Aws::Structure end |
#top_bots ⇒ Array<Types::BotStatistics>
The list of top bots accessing this path, ordered by request count.
The number of bots included is determined by the
NumberOfTopTrafficBotsPerPath parameter in the request.
7368 7369 7370 7371 7372 7373 7374 7375 7376 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7368 class PathStatistics < Struct.new( :source, :path, :request_count, :percentage, :top_bots) SENSITIVE = [] include Aws::Structure end |