Class: Aws::WAFV2::Types::PaymentNetwork
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::PaymentNetwork
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
A blockchain payment network configuration for receiving AI bot monetization payments. Specifies the blockchain chain, your wallet address on that chain, and the price per request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#chain ⇒ String
The blockchain network for receiving payments.
-
#prices ⇒ Array<Types::Price>
The price configuration for this payment network.
-
#wallet_address ⇒ String
Your wallet address on the specified blockchain where payments are sent.
Instance Attribute Details
#chain ⇒ String
The blockchain network for receiving payments. Production networks: ‘BASE` (Base mainnet), `SOLANA` (Solana mainnet). Test networks: `BASE_SEPOLIA` (Base Sepolia testnet), `SOLANA_DEVNET` (Solana Devnet).
7386 7387 7388 7389 7390 7391 7392 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7386 class PaymentNetwork < Struct.new( :chain, :wallet_address, :prices) SENSITIVE = [] include Aws::Structure end |
#prices ⇒ Array<Types::Price>
The price configuration for this payment network. Currently supports a single price entry in USDC.
7386 7387 7388 7389 7390 7391 7392 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7386 class PaymentNetwork < Struct.new( :chain, :wallet_address, :prices) SENSITIVE = [] include Aws::Structure end |
#wallet_address ⇒ String
Your wallet address on the specified blockchain where payments are sent. For EVM chains (Base, Base Sepolia), provide a valid Ethereum address (42 characters including 0x prefix). For Solana chains, provide a valid Base58-encoded public key (32-44 characters).
For EVM addresses, WAF performs EIP-55 checksum validation for typo detection when the address uses a mix of lower and upper case letters. You can bypass this validation by providing the address in all lowercase or all uppercase.
7386 7387 7388 7389 7390 7391 7392 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7386 class PaymentNetwork < Struct.new( :chain, :wallet_address, :prices) SENSITIVE = [] include Aws::Structure end |