Class: Aws::WAFV2::Types::PreParseTextTransformation
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::PreParseTextTransformation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
A pre-parse text transformation that normalizes the raw query string
before WAF parses it into individual query arguments. Pre-parse text
transformations are only supported when FieldToMatch is
SingleQueryArgument or AllQueryArguments.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#priority ⇒ Integer
Sets the relative processing order for the pre-parse text transformations that you define.
-
#type ⇒ String
The type of pre-parse text transformation to apply to the raw query string.
Instance Attribute Details
#priority ⇒ Integer
Sets the relative processing order for the pre-parse text transformations that you define. WAF processes all transformations, from lowest priority value to highest, before inspecting the transformed content.
7477 7478 7479 7480 7481 7482 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7477 class PreParseTextTransformation < Struct.new( :priority, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of pre-parse text transformation to apply to the raw query string.
7477 7478 7479 7480 7481 7482 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7477 class PreParseTextTransformation < Struct.new( :priority, :type) SENSITIVE = [] include Aws::Structure end |