Method: Aws::WAFV2::Types::RateBasedStatement#evaluation_window_sec
- Defined in:
- lib/aws-sdk-wafv2/types.rb
#evaluation_window_sec ⇒ Integer
The amount of time, in seconds, that WAF should include in its request counts, looking back from the current time. For example, for a setting of 120, when WAF checks the rate, it counts the requests for the 2 minutes immediately preceding the current time. Valid settings are 60, 120, 300, and 600.
This setting doesn’t determine how often WAF checks the rate, but how far back it looks each time it checks. WAF checks the rate about every 10 seconds.
Default: 300 (5 minutes)
7264 7265 7266 7267 7268 7269 7270 7271 7272 7273 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7264 class RateBasedStatement < Struct.new( :limit, :evaluation_window_sec, :aggregate_key_type, :scope_down_statement, :forwarded_ip_config, :custom_keys) SENSITIVE = [] include Aws::Structure end |