Class: Aws::WAFV2::Types::RegexMatchStatement
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::RegexMatchStatement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
A rule statement used to search web request components for a match against a single regular expression.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_to_match ⇒ Types::FieldToMatch
The part of the web request that you want WAF to inspect.
-
#regex_string ⇒ String
The string representing the regular expression.
-
#text_transformations ⇒ Array<Types::TextTransformation>
Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection.
Instance Attribute Details
#field_to_match ⇒ Types::FieldToMatch
The part of the web request that you want WAF to inspect.
6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6660 class RegexMatchStatement < Struct.new( :regex_string, :field_to_match, :text_transformations) SENSITIVE = [] include Aws::Structure end |
#regex_string ⇒ String
The string representing the regular expression.
6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6660 class RegexMatchStatement < Struct.new( :regex_string, :field_to_match, :text_transformations) SENSITIVE = [] include Aws::Structure end |
#text_transformations ⇒ Array<Types::TextTransformation>
Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. Text transformations are used in rule match statements, to transform the ‘FieldToMatch` request component before inspecting it, and they’re used in rate-based rule statements, to transform request components before using them as custom aggregation keys. If you specify one or more transformations to apply, WAF performs all transformations on the specified content, starting from the lowest priority setting, and then uses the transformed component contents.
6660 6661 6662 6663 6664 6665 6666 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6660 class RegexMatchStatement < Struct.new( :regex_string, :field_to_match, :text_transformations) SENSITIVE = [] include Aws::Structure end |