Class: Aws::WAFV2::Types::RegexMatchStatement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

A rule statement used to search web request components for a match against a single regular expression.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#field_to_matchTypes::FieldToMatch

The part of the web request that you want WAF to inspect.

Returns:



5118
5119
5120
5121
5122
5123
5124
# File 'lib/aws-sdk-wafv2/types.rb', line 5118

class RegexMatchStatement < Struct.new(
  :regex_string,
  :field_to_match,
  :text_transformations)
  SENSITIVE = []
  include Aws::Structure
end

#regex_stringString

The string representing the regular expression.

Returns:

  • (String)


5118
5119
5120
5121
5122
5123
5124
# File 'lib/aws-sdk-wafv2/types.rb', line 5118

class RegexMatchStatement < Struct.new(
  :regex_string,
  :field_to_match,
  :text_transformations)
  SENSITIVE = []
  include Aws::Structure
end

#text_transformationsArray<Types::TextTransformation>

Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, WAF performs all transformations on the content of the request component identified by `FieldToMatch`, starting from the lowest priority setting, before inspecting the content for a match.

Returns:



5118
5119
5120
5121
5122
5123
5124
# File 'lib/aws-sdk-wafv2/types.rb', line 5118

class RegexMatchStatement < Struct.new(
  :regex_string,
  :field_to_match,
  :text_transformations)
  SENSITIVE = []
  include Aws::Structure
end