Class: Aws::WAFV2::Types::RegexMatchStatement
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::RegexMatchStatement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
When making an API call, you may pass RegexMatchStatement data as a hash:
{
regex_string: "RegexPatternString", # required
field_to_match: { # required
single_header: {
name: "FieldToMatchData", # required
},
single_query_argument: {
name: "FieldToMatchData", # required
},
all_query_arguments: {
},
uri_path: {
},
query_string: {
},
body: {
oversize_handling: "CONTINUE", # accepts CONTINUE, MATCH, NO_MATCH
},
method: {
},
json_body: {
match_pattern: { # required
all: {
},
included_paths: ["JsonPointerPath"],
},
match_scope: "ALL", # required, accepts ALL, KEY, VALUE
invalid_fallback_behavior: "MATCH", # accepts MATCH, NO_MATCH, EVALUATE_AS_STRING
oversize_handling: "CONTINUE", # accepts CONTINUE, MATCH, NO_MATCH
},
headers: {
match_pattern: { # required
all: {
},
included_headers: ["FieldToMatchData"],
excluded_headers: ["FieldToMatchData"],
},
match_scope: "ALL", # required, accepts ALL, KEY, VALUE
oversize_handling: "CONTINUE", # required, accepts CONTINUE, MATCH, NO_MATCH
},
cookies: {
match_pattern: { # required
all: {
},
included_cookies: ["SingleCookieName"],
excluded_cookies: ["SingleCookieName"],
},
match_scope: "ALL", # required, accepts ALL, KEY, VALUE
oversize_handling: "CONTINUE", # required, accepts CONTINUE, MATCH, NO_MATCH
},
},
text_transformations: [ # required
{
priority: 1, # required
type: "NONE", # required, accepts NONE, COMPRESS_WHITE_SPACE, HTML_ENTITY_DECODE, LOWERCASE, CMD_LINE, URL_DECODE, BASE64_DECODE, HEX_DECODE, MD5, REPLACE_COMMENTS, ESCAPE_SEQ_DECODE, SQL_HEX_DECODE, CSS_DECODE, JS_DECODE, NORMALIZE_PATH, NORMALIZE_PATH_WIN, REMOVE_NULLS, REPLACE_NULLS, BASE64_DECODE_EXT, URL_DECODE_UNI, UTF8_TO_UNICODE
},
],
}
A rule statement used to search web request components for a match against a single regular expression.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_to_match ⇒ Types::FieldToMatch
The part of the web request that you want WAF to inspect.
-
#regex_string ⇒ String
The string representing the regular expression.
-
#text_transformations ⇒ Array<Types::TextTransformation>
Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection.
Instance Attribute Details
#field_to_match ⇒ Types::FieldToMatch
The part of the web request that you want WAF to inspect.
9819 9820 9821 9822 9823 9824 9825 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9819 class RegexMatchStatement < Struct.new( :regex_string, :field_to_match, :text_transformations) SENSITIVE = [] include Aws::Structure end |
#regex_string ⇒ String
The string representing the regular expression.
9819 9820 9821 9822 9823 9824 9825 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9819 class RegexMatchStatement < Struct.new( :regex_string, :field_to_match, :text_transformations) SENSITIVE = [] include Aws::Structure end |
#text_transformations ⇒ Array<Types::TextTransformation>
Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, WAF performs all transformations on the content of the request component identified by `FieldToMatch`, starting from the lowest priority setting, before inspecting the content for a match.
9819 9820 9821 9822 9823 9824 9825 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9819 class RegexMatchStatement < Struct.new( :regex_string, :field_to_match, :text_transformations) SENSITIVE = [] include Aws::Structure end |