Class: Aws::WAFV2::Types::RegexPatternSet
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::RegexPatternSet
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Contains one or more regular expressions.
WAF assigns an ARN to each ‘RegexPatternSet` that you create. To use a set in a rule, you provide the ARN to the Rule statement RegexPatternSetReferenceStatement.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the entity.
-
#description ⇒ String
A description of the set that helps with identification.
-
#id ⇒ String
A unique identifier for the set.
-
#name ⇒ String
The name of the set.
-
#regular_expression_list ⇒ Array<Types::Regex>
The regular expression patterns in the set.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the entity.
8374 8375 8376 8377 8378 8379 8380 8381 8382 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8374 class RegexPatternSet < Struct.new( :name, :id, :arn, :description, :regular_expression_list) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the set that helps with identification.
8374 8375 8376 8377 8378 8379 8380 8381 8382 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8374 class RegexPatternSet < Struct.new( :name, :id, :arn, :description, :regular_expression_list) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
8374 8375 8376 8377 8378 8379 8380 8381 8382 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8374 class RegexPatternSet < Struct.new( :name, :id, :arn, :description, :regular_expression_list) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the set. You cannot change the name after you create the set.
8374 8375 8376 8377 8378 8379 8380 8381 8382 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8374 class RegexPatternSet < Struct.new( :name, :id, :arn, :description, :regular_expression_list) SENSITIVE = [] include Aws::Structure end |
#regular_expression_list ⇒ Array<Types::Regex>
The regular expression patterns in the set.
8374 8375 8376 8377 8378 8379 8380 8381 8382 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8374 class RegexPatternSet < Struct.new( :name, :id, :arn, :description, :regular_expression_list) SENSITIVE = [] include Aws::Structure end |