Class: Aws::WAFV2::Types::RegexPatternSet
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::RegexPatternSet
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Contains one or more regular expressions.
WAF assigns an ARN to each ‘RegexPatternSet` that you create. To use a set in a rule, you provide the ARN to the Rule statement RegexPatternSetReferenceStatement.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the entity.
-
#description ⇒ String
A description of the set that helps with identification.
-
#id ⇒ String
A unique identifier for the set.
-
#name ⇒ String
The name of the set.
-
#regular_expression_list ⇒ Array<Types::Regex>
The regular expression patterns in the set.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the entity.
6069 6070 6071 6072 6073 6074 6075 6076 6077 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6069 class RegexPatternSet < Struct.new( :name, :id, :arn, :description, :regular_expression_list) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the set that helps with identification.
6069 6070 6071 6072 6073 6074 6075 6076 6077 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6069 class RegexPatternSet < Struct.new( :name, :id, :arn, :description, :regular_expression_list) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
6069 6070 6071 6072 6073 6074 6075 6076 6077 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6069 class RegexPatternSet < Struct.new( :name, :id, :arn, :description, :regular_expression_list) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the set. You cannot change the name after you create the set.
6069 6070 6071 6072 6073 6074 6075 6076 6077 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6069 class RegexPatternSet < Struct.new( :name, :id, :arn, :description, :regular_expression_list) SENSITIVE = [] include Aws::Structure end |
#regular_expression_list ⇒ Array<Types::Regex>
The regular expression patterns in the set.
6069 6070 6071 6072 6073 6074 6075 6076 6077 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6069 class RegexPatternSet < Struct.new( :name, :id, :arn, :description, :regular_expression_list) SENSITIVE = [] include Aws::Structure end |