Class: Aws::WAFV2::Types::RegexPatternSetReferenceStatement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

A rule statement used to search web request components for matches with regular expressions. To use this, create a RegexPatternSet that specifies the expressions that you want to detect, then use the ARN of that set in this statement. A web request matches the pattern set rule statement if the request component matches any of the patterns in the set. To create a regex pattern set, see CreateRegexPatternSet.

Each regex pattern set rule statement references a regex pattern set. You create and maintain the set independent of your rules. This allows you to use the single set in multiple rules. When you update the referenced set, WAF automatically updates all rules that reference it.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the RegexPatternSet that this statement references.

Returns:

  • (String)


5632
5633
5634
5635
5636
5637
5638
# File 'lib/aws-sdk-wafv2/types.rb', line 5632

class RegexPatternSetReferenceStatement < Struct.new(
  :arn,
  :field_to_match,
  :text_transformations)
  SENSITIVE = []
  include Aws::Structure
end

#field_to_matchTypes::FieldToMatch

The part of the web request that you want WAF to inspect.

Returns:



5632
5633
5634
5635
5636
5637
5638
# File 'lib/aws-sdk-wafv2/types.rb', line 5632

class RegexPatternSetReferenceStatement < Struct.new(
  :arn,
  :field_to_match,
  :text_transformations)
  SENSITIVE = []
  include Aws::Structure
end

#text_transformationsArray<Types::TextTransformation>

Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, WAF performs all transformations on the content of the request component identified by ‘FieldToMatch`, starting from the lowest priority setting, before inspecting the content for a match.

Returns:



5632
5633
5634
5635
5636
5637
5638
# File 'lib/aws-sdk-wafv2/types.rb', line 5632

class RegexPatternSetReferenceStatement < Struct.new(
  :arn,
  :field_to_match,
  :text_transformations)
  SENSITIVE = []
  include Aws::Structure
end