Class: Aws::WAFV2::Types::RegexPatternSetReferenceStatement
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::RegexPatternSetReferenceStatement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
A rule statement used to search web request components for matches with regular expressions. To use this, create a RegexPatternSet that specifies the expressions that you want to detect, then use the ARN of that set in this statement. A web request matches the pattern set rule statement if the request component matches any of the patterns in the set. To create a regex pattern set, see CreateRegexPatternSet.
Each regex pattern set rule statement references a regex pattern set. You create and maintain the set independent of your rules. This allows you to use the single set in multiple rules. When you update the referenced set, WAF automatically updates all rules that reference it.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the RegexPatternSet that this statement references.
-
#field_to_match ⇒ Types::FieldToMatch
The part of the web request that you want WAF to inspect.
-
#text_transformations ⇒ Array<Types::TextTransformation>
Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the RegexPatternSet that this statement references.
5287 5288 5289 5290 5291 5292 5293 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5287 class RegexPatternSetReferenceStatement < Struct.new( :arn, :field_to_match, :text_transformations) SENSITIVE = [] include Aws::Structure end |
#field_to_match ⇒ Types::FieldToMatch
The part of the web request that you want WAF to inspect.
5287 5288 5289 5290 5291 5292 5293 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5287 class RegexPatternSetReferenceStatement < Struct.new( :arn, :field_to_match, :text_transformations) SENSITIVE = [] include Aws::Structure end |
#text_transformations ⇒ Array<Types::TextTransformation>
Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, WAF performs all transformations on the content of the request component identified by ‘FieldToMatch`, starting from the lowest priority setting, before inspecting the content for a match.
5287 5288 5289 5290 5291 5292 5293 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5287 class RegexPatternSetReferenceStatement < Struct.new( :arn, :field_to_match, :text_transformations) SENSITIVE = [] include Aws::Structure end |