Class: Aws::WAFV2::Types::RegexPatternSetSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::RegexPatternSetSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
High-level information about a RegexPatternSet, returned by operations like create and list. This provides information like the ID, that you can use to retrieve and manage a ‘RegexPatternSet`, and the ARN, that you provide to the RegexPatternSetReferenceStatement to use the pattern set in a Rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the entity.
-
#description ⇒ String
A description of the set that helps with identification.
-
#id ⇒ String
A unique identifier for the set.
-
#lock_token ⇒ String
A token used for optimistic locking.
-
#name ⇒ String
The name of the data type instance.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the entity.
6806 6807 6808 6809 6810 6811 6812 6813 6814 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6806 class RegexPatternSetSummary < Struct.new( :name, :id, :description, :lock_token, :arn) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the set that helps with identification.
6806 6807 6808 6809 6810 6811 6812 6813 6814 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6806 class RegexPatternSetSummary < Struct.new( :name, :id, :description, :lock_token, :arn) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
6806 6807 6808 6809 6810 6811 6812 6813 6814 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6806 class RegexPatternSetSummary < Struct.new( :name, :id, :description, :lock_token, :arn) SENSITIVE = [] include Aws::Structure end |
#lock_token ⇒ String
A token used for optimistic locking. WAF returns a token to your ‘get` and `list` requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like `update` and `delete`. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a `WAFOptimisticLockException`. If this happens, perform another `get`, and use the new token returned by that operation.
6806 6807 6808 6809 6810 6811 6812 6813 6814 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6806 class RegexPatternSetSummary < Struct.new( :name, :id, :description, :lock_token, :arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the data type instance. You cannot change the name after you create the instance.
6806 6807 6808 6809 6810 6811 6812 6813 6814 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6806 class RegexPatternSetSummary < Struct.new( :name, :id, :description, :lock_token, :arn) SENSITIVE = [] include Aws::Structure end |