Class: Aws::WAFV2::Types::RequestBodyAssociatedResourceTypeConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Customizes the maximum size of the request body that your protected CloudFront distributions forward to WAF for inspection. The default size is 16 KB (16,384 kilobytes).

<note markdown=“1”> You are charged additional fees when your protected resources forward body sizes that are larger than the default. For more information, see [WAF Pricing].

</note>

This is used in the ‘AssociationConfig` of the web ACL.

[1]: aws.amazon.com/waf/pricing/

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_size_inspection_limitString

Specifies the maximum size of the web request body component that an associated CloudFront distribution should send to WAF for inspection. This applies to statements in the web ACL that inspect the body or JSON body.

Default: ‘16 KB (16,384 kilobytes)`

Returns:

  • (String)


6370
6371
6372
6373
6374
# File 'lib/aws-sdk-wafv2/types.rb', line 6370

class RequestBodyAssociatedResourceTypeConfig < Struct.new(
  :default_size_inspection_limit)
  SENSITIVE = []
  include Aws::Structure
end