Class: Aws::WAFV2::Types::RequestInspection
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::RequestInspection
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
The criteria for inspecting login requests, used by the ATP rule group to validate credentials usage.
This is part of the ‘AWSManagedRulesATPRuleSet` configuration in `ManagedRuleGroupConfig`.
In these settings, you specify how your application accepts login attempts by providing the request payload type and the names of the fields within the request body where the username and password are provided.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#password_field ⇒ Types::PasswordField
Details about your login page password field.
-
#payload_type ⇒ String
The payload type for your login endpoint, either JSON or form encoded.
-
#username_field ⇒ Types::UsernameField
Details about your login page username field.
Instance Attribute Details
#password_field ⇒ Types::PasswordField
Details about your login page password field.
How you specify this depends on the payload type.
-
For JSON payloads, specify the field name in JSON pointer syntax. For information about the JSON Pointer syntax, see the Internet Engineering Task Force (IETF) documentation [JavaScript Object Notation (JSON) Pointer].
For example, for the JSON payload ‘{ “login”: { “username”: “THE_USERNAME”, “password”: “THE_PASSWORD” } }`, the username field specification is `/login/username` and the password field specification is `/login/password`.
-
For form encoded payload types, use the HTML form names.
For example, for an HTML form with input elements named ‘username1` and `password1`, the username field specification is `username1` and the password field specification is `password1`.
5433 5434 5435 5436 5437 5438 5439 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5433 class RequestInspection < Struct.new( :payload_type, :username_field, :password_field) SENSITIVE = [] include Aws::Structure end |
#payload_type ⇒ String
The payload type for your login endpoint, either JSON or form encoded.
5433 5434 5435 5436 5437 5438 5439 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5433 class RequestInspection < Struct.new( :payload_type, :username_field, :password_field) SENSITIVE = [] include Aws::Structure end |
#username_field ⇒ Types::UsernameField
Details about your login page username field.
How you specify this depends on the payload type.
-
For JSON payloads, specify the field name in JSON pointer syntax. For information about the JSON Pointer syntax, see the Internet Engineering Task Force (IETF) documentation [JavaScript Object Notation (JSON) Pointer].
For example, for the JSON payload ‘{ “login”: { “username”: “THE_USERNAME”, “password”: “THE_PASSWORD” } }`, the username field specification is `/login/username` and the password field specification is `/login/password`.
-
For form encoded payload types, use the HTML form names.
For example, for an HTML form with input elements named ‘username1` and `password1`, the username field specification is `username1` and the password field specification is `password1`.
5433 5434 5435 5436 5437 5438 5439 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5433 class RequestInspection < Struct.new( :payload_type, :username_field, :password_field) SENSITIVE = [] include Aws::Structure end |