Class: Aws::WAFV2::Types::ResponseInspection

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

The criteria for inspecting responses to login requests, used by the ATP rule group to track login failure rates.

The ATP rule group evaluates the responses that your protected resources send back to client login attempts, keeping count of successful and failed attempts from each IP address and client session. Using this information, the rule group labels and mitigates requests from client sessions and IP addresses that submit too many failed login attempts in a short amount of time.

<note markdown=“1”> Response inspection is available only in web ACLs that protect Amazon CloudFront distributions.

</note>

<note markdown=“1”> For regional web ACLs in Region US East (N. Virginia) us-east-1, it’s possible to configure response inspection through the APIs, but ATP response inspection will not be enabled. You can only use the response inspection capabilities of the ATP managed rule group in web ACLs that protect CloudFront distributions.

</note>

This is part of the ‘AWSManagedRulesATPRuleSet` configuration in `ManagedRuleGroupConfig`.

Enable login response inspection by configuring exactly one component of the response to inspect. You can’t configure more than one. If you don’t configure any of the response inspection options, response inspection is disabled.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#body_containsTypes::ResponseInspectionBodyContains

Configures inspection of the response body.



5507
5508
5509
5510
5511
5512
5513
5514
# File 'lib/aws-sdk-wafv2/types.rb', line 5507

class ResponseInspection < Struct.new(
  :status_code,
  :header,
  :body_contains,
  :json)
  SENSITIVE = []
  include Aws::Structure
end

#headerTypes::ResponseInspectionHeader

Configures inspection of the response header.



5507
5508
5509
5510
5511
5512
5513
5514
# File 'lib/aws-sdk-wafv2/types.rb', line 5507

class ResponseInspection < Struct.new(
  :status_code,
  :header,
  :body_contains,
  :json)
  SENSITIVE = []
  include Aws::Structure
end

#jsonTypes::ResponseInspectionJson

Configures inspection of the response JSON.



5507
5508
5509
5510
5511
5512
5513
5514
# File 'lib/aws-sdk-wafv2/types.rb', line 5507

class ResponseInspection < Struct.new(
  :status_code,
  :header,
  :body_contains,
  :json)
  SENSITIVE = []
  include Aws::Structure
end

#status_codeTypes::ResponseInspectionStatusCode

Configures inspection of the response status code.



5507
5508
5509
5510
5511
5512
5513
5514
# File 'lib/aws-sdk-wafv2/types.rb', line 5507

class ResponseInspection < Struct.new(
  :status_code,
  :header,
  :body_contains,
  :json)
  SENSITIVE = []
  include Aws::Structure
end