Class: Aws::WAFV2::Types::ResponseInspectionBodyContains
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ResponseInspectionBodyContains
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Configures inspection of the response body. WAF can inspect the first
65,536 bytes (64 KB) of the response body. This is part of the
ResponseInspection configuration for AWSManagedRulesATPRuleSet and
AWSManagedRulesACFPRuleSet.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failure_strings ⇒ Array<String>
Strings in the body of the response that indicate a failed login or account creation attempt.
-
#success_strings ⇒ Array<String>
Strings in the body of the response that indicate a successful login or account creation attempt.
Instance Attribute Details
#failure_strings ⇒ Array<String>
Strings in the body of the response that indicate a failed login or account creation attempt. To be counted as a failure, the string can be anywhere in the body and must be an exact match, including case. Each string must be unique among the success and failure strings.
JSON example: "FailureStrings": [ "Request failed" ]
8887 8888 8889 8890 8891 8892 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8887 class ResponseInspectionBodyContains < Struct.new( :success_strings, :failure_strings) SENSITIVE = [] include Aws::Structure end |
#success_strings ⇒ Array<String>
Strings in the body of the response that indicate a successful login or account creation attempt. To be counted as a success, the string can be anywhere in the body and must be an exact match, including case. Each string must be unique among the success and failure strings.
JSON examples: "SuccessStrings": [ "Login successful" ] and
"SuccessStrings": [ "Account creation successful", "Welcome to our site!" ]
8887 8888 8889 8890 8891 8892 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8887 class ResponseInspectionBodyContains < Struct.new( :success_strings, :failure_strings) SENSITIVE = [] include Aws::Structure end |