Class: Aws::WAFV2::Types::ResponseInspectionBodyContains
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ResponseInspectionBodyContains
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Configures inspection of the response body. WAF can inspect the first 65,536 bytes (64 KB) of the response body. This is part of the ‘ResponseInspection` configuration for `AWSManagedRulesATPRuleSet`.
<note markdown=“1”> Response inspection is available only in web ACLs that protect Amazon CloudFront distributions.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failure_strings ⇒ Array<String>
Strings in the body of the response that indicate a failed login attempt.
-
#success_strings ⇒ Array<String>
Strings in the body of the response that indicate a successful login attempt.
Instance Attribute Details
#failure_strings ⇒ Array<String>
Strings in the body of the response that indicate a failed login attempt. To be counted as a failed login, the string can be anywhere in the body and must be an exact match, including case. Each string must be unique among the success and failure strings.
JSON example: ‘“FailureStrings”: [ “Login failed” ]`
5562 5563 5564 5565 5566 5567 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5562 class ResponseInspectionBodyContains < Struct.new( :success_strings, :failure_strings) SENSITIVE = [] include Aws::Structure end |
#success_strings ⇒ Array<String>
Strings in the body of the response that indicate a successful login attempt. To be counted as a successful login, the string can be anywhere in the body and must be an exact match, including case. Each string must be unique among the success and failure strings.
JSON example: ‘“SuccessStrings”: [ “Login successful”, “Welcome to our site!” ]`
5562 5563 5564 5565 5566 5567 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5562 class ResponseInspectionBodyContains < Struct.new( :success_strings, :failure_strings) SENSITIVE = [] include Aws::Structure end |