Class: Aws::WAFV2::Types::ResponseInspectionBodyContains
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ResponseInspectionBodyContains
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Configures inspection of the response body. This is part of the ‘ResponseInspection` configuration for `AWSManagedRulesATPRuleSet`.
<note markdown=“1”> Response inspection is available only in web ACLs that protect Amazon CloudFront distributions.
</note>
<note markdown=“1”> For regional web ACLs in Region US East (N. Virginia) us-east-1, it’s possible to configure response inspection through the APIs, but ATP response inspection will not be enabled. You can only use the response inspection capabilities of the ATP managed rule group in web ACLs that protect CloudFront distributions.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failure_strings ⇒ Array<String>
Strings in the body of the response that indicate a failed login attempt.
-
#success_strings ⇒ Array<String>
Strings in the body of the response that indicate a successful login attempt.
Instance Attribute Details
#failure_strings ⇒ Array<String>
Strings in the body of the response that indicate a failed login attempt. To be counted as a failed login, the string can be anywhere in the body and must be an exact match, including case. Each string must be unique among the success and failure strings.
JSON example: ‘“FailureStrings”: [ “Login failed” ]`
5553 5554 5555 5556 5557 5558 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5553 class ResponseInspectionBodyContains < Struct.new( :success_strings, :failure_strings) SENSITIVE = [] include Aws::Structure end |
#success_strings ⇒ Array<String>
Strings in the body of the response that indicate a successful login attempt. To be counted as a successful login, the string can be anywhere in the body and must be an exact match, including case. Each string must be unique among the success and failure strings.
JSON example: ‘“SuccessStrings”: [ “Login successful”, “Welcome to our site!” ]`
5553 5554 5555 5556 5557 5558 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5553 class ResponseInspectionBodyContains < Struct.new( :success_strings, :failure_strings) SENSITIVE = [] include Aws::Structure end |