Class: Aws::WAFV2::Types::ResponseInspectionHeader
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ResponseInspectionHeader
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Configures inspection of the response header. This is part of the
ResponseInspection configuration for AWSManagedRulesATPRuleSet and
AWSManagedRulesACFPRuleSet.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failure_values ⇒ Array<String>
Values in the response header with the specified name that indicate a failed login or account creation attempt.
-
#name ⇒ String
The name of the header to match against.
-
#success_values ⇒ Array<String>
Values in the response header with the specified name that indicate a successful login or account creation attempt.
Instance Attribute Details
#failure_values ⇒ Array<String>
Values in the response header with the specified name that indicate a failed login or account creation attempt. To be counted as a failure, the value must be an exact match, including case. Each value must be unique among the success and failure values.
JSON examples: "FailureValues": [ "LoginFailed", "Failed login" ]
and "FailureValues": [ "AccountCreationFailed" ]
8933 8934 8935 8936 8937 8938 8939 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8933 class ResponseInspectionHeader < Struct.new( :name, :success_values, :failure_values) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the header to match against. The name must be an exact match, including case.
JSON example: "Name": [ "RequestResult" ]
8933 8934 8935 8936 8937 8938 8939 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8933 class ResponseInspectionHeader < Struct.new( :name, :success_values, :failure_values) SENSITIVE = [] include Aws::Structure end |
#success_values ⇒ Array<String>
Values in the response header with the specified name that indicate a successful login or account creation attempt. To be counted as a success, the value must be an exact match, including case. Each value must be unique among the success and failure values.
JSON examples: "SuccessValues": [ "LoginPassed", "Successful login" ] and "SuccessValues": [ "AccountCreated", "Successful account creation" ]
8933 8934 8935 8936 8937 8938 8939 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8933 class ResponseInspectionHeader < Struct.new( :name, :success_values, :failure_values) SENSITIVE = [] include Aws::Structure end |