Class: Aws::WAFV2::Types::ResponseInspectionHeader

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Configures inspection of the response header. This is part of the ‘ResponseInspection` configuration for `AWSManagedRulesATPRuleSet`.

<note markdown=“1”> Response inspection is available only in web ACLs that protect Amazon CloudFront distributions.

</note>

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failure_valuesArray<String>

Values in the response header with the specified name that indicate a failed login attempt. To be counted as a failed login, the value must be an exact match, including case. Each value must be unique among the success and failure values.

JSON example: ‘“FailureValues”: [ “LoginFailed”, “Failed login” ]`

Returns:

  • (Array<String>)


5711
5712
5713
5714
5715
5716
5717
# File 'lib/aws-sdk-wafv2/types.rb', line 5711

class ResponseInspectionHeader < Struct.new(
  :name,
  :success_values,
  :failure_values)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the header to match against. The name must be an exact match, including case.

JSON example: ‘“Name”: [ “LoginResult” ]`

Returns:

  • (String)


5711
5712
5713
5714
5715
5716
5717
# File 'lib/aws-sdk-wafv2/types.rb', line 5711

class ResponseInspectionHeader < Struct.new(
  :name,
  :success_values,
  :failure_values)
  SENSITIVE = []
  include Aws::Structure
end

#success_valuesArray<String>

Values in the response header with the specified name that indicate a successful login attempt. To be counted as a successful login, the value must be an exact match, including case. Each value must be unique among the success and failure values.

JSON example: ‘“SuccessValues”: [ “LoginPassed”, “Successful login” ]`

Returns:

  • (Array<String>)


5711
5712
5713
5714
5715
5716
5717
# File 'lib/aws-sdk-wafv2/types.rb', line 5711

class ResponseInspectionHeader < Struct.new(
  :name,
  :success_values,
  :failure_values)
  SENSITIVE = []
  include Aws::Structure
end