Class: Aws::WAFV2::Types::ResponseInspectionHeader
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ResponseInspectionHeader
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Configures inspection of the response header. This is part of the ‘ResponseInspection` configuration for `AWSManagedRulesATPRuleSet`.
<note markdown=“1”> Response inspection is available only in web ACLs that protect Amazon CloudFront distributions.
</note>
<note markdown=“1”> For regional web ACLs in Region US East (N. Virginia) us-east-1, it’s possible to configure response inspection through the APIs, but ATP response inspection will not be enabled. You can only use the response inspection capabilities of the ATP managed rule group in web ACLs that protect CloudFront distributions.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failure_values ⇒ Array<String>
Values in the response header with the specified name that indicate a failed login attempt.
-
#name ⇒ String
The name of the header to match against.
-
#success_values ⇒ Array<String>
Values in the response header with the specified name that indicate a successful login attempt.
Instance Attribute Details
#failure_values ⇒ Array<String>
Values in the response header with the specified name that indicate a failed login attempt. To be counted as a failed login, the value must be an exact match, including case. Each value must be unique among the success and failure values.
JSON example: ‘“FailureValues”: [ “LoginFailed”, “Failed login” ]`
5604 5605 5606 5607 5608 5609 5610 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5604 class ResponseInspectionHeader < Struct.new( :name, :success_values, :failure_values) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the header to match against. The name must be an exact match, including case.
JSON example: ‘“Name”: [ “LoginResult” ]`
5604 5605 5606 5607 5608 5609 5610 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5604 class ResponseInspectionHeader < Struct.new( :name, :success_values, :failure_values) SENSITIVE = [] include Aws::Structure end |
#success_values ⇒ Array<String>
Values in the response header with the specified name that indicate a successful login attempt. To be counted as a successful login, the value must be an exact match, including case. Each value must be unique among the success and failure values.
JSON example: ‘“SuccessValues”: [ “LoginPassed”, “Successful login” ]`
5604 5605 5606 5607 5608 5609 5610 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5604 class ResponseInspectionHeader < Struct.new( :name, :success_values, :failure_values) SENSITIVE = [] include Aws::Structure end |