Class: Aws::WAFV2::Types::ResponseInspectionJson

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Configures inspection of the response JSON. This is part of the ‘ResponseInspection` configuration for `AWSManagedRulesATPRuleSet`.

<note markdown=“1”> Response inspection is available only in web ACLs that protect Amazon CloudFront distributions.

</note>

<note markdown=“1”> For regional web ACLs in Region US East (N. Virginia) us-east-1, it’s possible to configure response inspection through the APIs, but ATP response inspection will not be enabled. You can only use the response inspection capabilities of the ATP managed rule group in web ACLs that protect CloudFront distributions.

</note>

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failure_valuesArray<String>

Values for the specified identifier in the response JSON that indicate a failed login attempt. To be counted as a failed login, the value must be an exact match, including case. Each value must be unique among the success and failure values.

JSON example: ‘“FailureValues”: [ “False”, “Failed” ]`

Returns:

  • (Array<String>)


5655
5656
5657
5658
5659
5660
5661
# File 'lib/aws-sdk-wafv2/types.rb', line 5655

class ResponseInspectionJson < Struct.new(
  :identifier,
  :success_values,
  :failure_values)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The identifier for the value to match against in the JSON. The identifier must be an exact match, including case.

JSON example: ‘“Identifier”: [ “/login/success” ]`

Returns:

  • (String)


5655
5656
5657
5658
5659
5660
5661
# File 'lib/aws-sdk-wafv2/types.rb', line 5655

class ResponseInspectionJson < Struct.new(
  :identifier,
  :success_values,
  :failure_values)
  SENSITIVE = []
  include Aws::Structure
end

#success_valuesArray<String>

Values for the specified identifier in the response JSON that indicate a successful login attempt. To be counted as a successful login, the value must be an exact match, including case. Each value must be unique among the success and failure values.

JSON example: ‘“SuccessValues”: [ “True”, “Succeeded” ]`

Returns:

  • (Array<String>)


5655
5656
5657
5658
5659
5660
5661
# File 'lib/aws-sdk-wafv2/types.rb', line 5655

class ResponseInspectionJson < Struct.new(
  :identifier,
  :success_values,
  :failure_values)
  SENSITIVE = []
  include Aws::Structure
end