Class: Aws::WAFV2::Types::ResponseInspectionStatusCode
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::ResponseInspectionStatusCode
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Configures inspection of the response status code. This is part of the ‘ResponseInspection` configuration for `AWSManagedRulesATPRuleSet`.
<note markdown=“1”> Response inspection is available only in web ACLs that protect Amazon CloudFront distributions.
</note>
<note markdown=“1”> For regional web ACLs in Region US East (N. Virginia) us-east-1, it’s possible to configure response inspection through the APIs, but ATP response inspection will not be enabled. You can only use the response inspection capabilities of the ATP managed rule group in web ACLs that protect CloudFront distributions.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failure_codes ⇒ Array<Integer>
Status codes in the response that indicate a failed login attempt.
-
#success_codes ⇒ Array<Integer>
Status codes in the response that indicate a successful login attempt.
Instance Attribute Details
#failure_codes ⇒ Array<Integer>
Status codes in the response that indicate a failed login attempt. To be counted as a failed login, the response status code must match one of these. Each code must be unique among the success and failure status codes.
JSON example: ‘“FailureCodes”: [ 400, 404 ]`
5699 5700 5701 5702 5703 5704 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5699 class ResponseInspectionStatusCode < Struct.new( :success_codes, :failure_codes) SENSITIVE = [] include Aws::Structure end |
#success_codes ⇒ Array<Integer>
Status codes in the response that indicate a successful login attempt. To be counted as a successful login, the response status code must match one of these. Each code must be unique among the success and failure status codes.
JSON example: ‘“SuccessCodes”: [ 200, 201 ]`
5699 5700 5701 5702 5703 5704 |
# File 'lib/aws-sdk-wafv2/types.rb', line 5699 class ResponseInspectionStatusCode < Struct.new( :success_codes, :failure_codes) SENSITIVE = [] include Aws::Structure end |