Class: Aws::WAFV2::Types::RevenuePathStatistics

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Revenue statistics for a single content path, including the path, revenue amount, and request count.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amountString

The total revenue amount from this path in the specified currency.

Returns:

  • (String)


9074
9075
9076
9077
9078
9079
9080
9081
# File 'lib/aws-sdk-wafv2/types.rb', line 9074

class RevenuePathStatistics < Struct.new(
  :path,
  :percentage,
  :amount,
  :request_count)
  SENSITIVE = []
  include Aws::Structure
end

#pathString

The URI path.

Returns:

  • (String)


9074
9075
9076
9077
9078
9079
9080
9081
# File 'lib/aws-sdk-wafv2/types.rb', line 9074

class RevenuePathStatistics < Struct.new(
  :path,
  :percentage,
  :amount,
  :request_count)
  SENSITIVE = []
  include Aws::Structure
end

#percentageFloat

The percentage of total revenue from this path.

Returns:

  • (Float)


9074
9075
9076
9077
9078
9079
9080
9081
# File 'lib/aws-sdk-wafv2/types.rb', line 9074

class RevenuePathStatistics < Struct.new(
  :path,
  :percentage,
  :amount,
  :request_count)
  SENSITIVE = []
  include Aws::Structure
end

#request_countInteger

The number of monetized requests to this path.

Returns:

  • (Integer)


9074
9075
9076
9077
9078
9079
9080
9081
# File 'lib/aws-sdk-wafv2/types.rb', line 9074

class RevenuePathStatistics < Struct.new(
  :path,
  :percentage,
  :amount,
  :request_count)
  SENSITIVE = []
  include Aws::Structure
end