Class: Aws::WAFV2::Types::RuleAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::RuleAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
The action that WAF should take on a web request when it matches a rule's statement. Settings at the web ACL level can override the rule action setting.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allow ⇒ Types::AllowAction
Instructs WAF to allow the web request.
-
#block ⇒ Types::BlockAction
Instructs WAF to block the web request.
-
#captcha ⇒ Types::CaptchaAction
Instructs WAF to run a
CAPTCHAcheck against the web request. -
#challenge ⇒ Types::ChallengeAction
Instructs WAF to run a
Challengecheck against the web request. -
#count ⇒ Types::CountAction
Instructs WAF to count the web request and then continue evaluating the request using the remaining rules in the web ACL.
-
#monetize ⇒ Types::MonetizeAction
Instructs WAF to return an HTTP 402 Payment Required response with a price manifest.
Instance Attribute Details
#allow ⇒ Types::AllowAction
Instructs WAF to allow the web request.
9265 9266 9267 9268 9269 9270 9271 9272 9273 9274 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9265 class RuleAction < Struct.new( :block, :allow, :count, :captcha, :challenge, :monetize) SENSITIVE = [] include Aws::Structure end |
#block ⇒ Types::BlockAction
Instructs WAF to block the web request.
9265 9266 9267 9268 9269 9270 9271 9272 9273 9274 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9265 class RuleAction < Struct.new( :block, :allow, :count, :captcha, :challenge, :monetize) SENSITIVE = [] include Aws::Structure end |
#captcha ⇒ Types::CaptchaAction
Instructs WAF to run a CAPTCHA check against the web request.
9265 9266 9267 9268 9269 9270 9271 9272 9273 9274 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9265 class RuleAction < Struct.new( :block, :allow, :count, :captcha, :challenge, :monetize) SENSITIVE = [] include Aws::Structure end |
#challenge ⇒ Types::ChallengeAction
Instructs WAF to run a Challenge check against the web request.
9265 9266 9267 9268 9269 9270 9271 9272 9273 9274 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9265 class RuleAction < Struct.new( :block, :allow, :count, :captcha, :challenge, :monetize) SENSITIVE = [] include Aws::Structure end |
#count ⇒ Types::CountAction
Instructs WAF to count the web request and then continue evaluating the request using the remaining rules in the web ACL.
9265 9266 9267 9268 9269 9270 9271 9272 9273 9274 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9265 class RuleAction < Struct.new( :block, :allow, :count, :captcha, :challenge, :monetize) SENSITIVE = [] include Aws::Structure end |
#monetize ⇒ Types::MonetizeAction
Instructs WAF to return an HTTP 402 Payment Required response with a
price manifest. The requesting client can complete payment and
resubmit the request to gain access. This is a terminating
action-requests that do not complete payment are blocked. This
action is available only for web ACLs associated with Amazon
CloudFront distributions and requires a MonetizationConfig on the
web ACL.
9265 9266 9267 9268 9269 9270 9271 9272 9273 9274 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9265 class RuleAction < Struct.new( :block, :allow, :count, :captcha, :challenge, :monetize) SENSITIVE = [] include Aws::Structure end |