Class: Aws::WAFV2::Types::RuleAction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

The action that WAF should take on a web request when it matches a rule’s statement. Settings at the web ACL level can override the rule action setting.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowTypes::AllowAction

Instructs WAF to allow the web request.

Returns:



9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
# File 'lib/aws-sdk-wafv2/types.rb', line 9253

class RuleAction < Struct.new(
  :block,
  :allow,
  :count,
  :captcha,
  :challenge,
  :monetize)
  SENSITIVE = []
  include Aws::Structure
end

#blockTypes::BlockAction

Instructs WAF to block the web request.

Returns:



9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
# File 'lib/aws-sdk-wafv2/types.rb', line 9253

class RuleAction < Struct.new(
  :block,
  :allow,
  :count,
  :captcha,
  :challenge,
  :monetize)
  SENSITIVE = []
  include Aws::Structure
end

#captchaTypes::CaptchaAction

Instructs WAF to run a ‘CAPTCHA` check against the web request.



9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
# File 'lib/aws-sdk-wafv2/types.rb', line 9253

class RuleAction < Struct.new(
  :block,
  :allow,
  :count,
  :captcha,
  :challenge,
  :monetize)
  SENSITIVE = []
  include Aws::Structure
end

#challengeTypes::ChallengeAction

Instructs WAF to run a ‘Challenge` check against the web request.



9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
# File 'lib/aws-sdk-wafv2/types.rb', line 9253

class RuleAction < Struct.new(
  :block,
  :allow,
  :count,
  :captcha,
  :challenge,
  :monetize)
  SENSITIVE = []
  include Aws::Structure
end

#countTypes::CountAction

Instructs WAF to count the web request and then continue evaluating the request using the remaining rules in the web ACL.

Returns:



9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
# File 'lib/aws-sdk-wafv2/types.rb', line 9253

class RuleAction < Struct.new(
  :block,
  :allow,
  :count,
  :captcha,
  :challenge,
  :monetize)
  SENSITIVE = []
  include Aws::Structure
end

#monetizeTypes::MonetizeAction

Instructs WAF to return an HTTP 402 Payment Required response with a price manifest. The requesting client can complete payment and resubmit the request to gain access. This is a terminating action-requests that do not complete payment are blocked. This action is available only for web ACLs associated with Amazon CloudFront distributions and requires a ‘MonetizationConfig` on the web ACL.



9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
# File 'lib/aws-sdk-wafv2/types.rb', line 9253

class RuleAction < Struct.new(
  :block,
  :allow,
  :count,
  :captcha,
  :challenge,
  :monetize)
  SENSITIVE = []
  include Aws::Structure
end