Class: Aws::WAFV2::Types::RuleAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::RuleAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
The action that WAF should take on a web request when it matches a rule’s statement. Settings at the web ACL level can override the rule action setting.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allow ⇒ Types::AllowAction
Instructs WAF to allow the web request.
-
#block ⇒ Types::BlockAction
Instructs WAF to block the web request.
-
#captcha ⇒ Types::CaptchaAction
Instructs WAF to run a ‘CAPTCHA` check against the web request.
-
#challenge ⇒ Types::ChallengeAction
Instructs WAF to run a ‘Challenge` check against the web request.
-
#count ⇒ Types::CountAction
Instructs WAF to count the web request and then continue evaluating the request using the remaining rules in the web ACL.
Instance Attribute Details
#allow ⇒ Types::AllowAction
Instructs WAF to allow the web request.
7328 7329 7330 7331 7332 7333 7334 7335 7336 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7328 class RuleAction < Struct.new( :block, :allow, :count, :captcha, :challenge) SENSITIVE = [] include Aws::Structure end |
#block ⇒ Types::BlockAction
Instructs WAF to block the web request.
7328 7329 7330 7331 7332 7333 7334 7335 7336 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7328 class RuleAction < Struct.new( :block, :allow, :count, :captcha, :challenge) SENSITIVE = [] include Aws::Structure end |
#captcha ⇒ Types::CaptchaAction
Instructs WAF to run a ‘CAPTCHA` check against the web request.
7328 7329 7330 7331 7332 7333 7334 7335 7336 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7328 class RuleAction < Struct.new( :block, :allow, :count, :captcha, :challenge) SENSITIVE = [] include Aws::Structure end |
#challenge ⇒ Types::ChallengeAction
Instructs WAF to run a ‘Challenge` check against the web request.
7328 7329 7330 7331 7332 7333 7334 7335 7336 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7328 class RuleAction < Struct.new( :block, :allow, :count, :captcha, :challenge) SENSITIVE = [] include Aws::Structure end |
#count ⇒ Types::CountAction
Instructs WAF to count the web request and then continue evaluating the request using the remaining rules in the web ACL.
7328 7329 7330 7331 7332 7333 7334 7335 7336 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7328 class RuleAction < Struct.new( :block, :allow, :count, :captcha, :challenge) SENSITIVE = [] include Aws::Structure end |