Class: Aws::WAFV2::Types::RuleAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::RuleAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
When making an API call, you may pass RuleAction data as a hash:
{
block: {
custom_response: {
response_code: 1, # required
custom_response_body_key: "EntityName",
response_headers: [
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
},
},
allow: {
custom_request_handling: {
insert_headers: [ # required
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
},
},
count: {
custom_request_handling: {
insert_headers: [ # required
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
},
},
captcha: {
custom_request_handling: {
insert_headers: [ # required
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
},
},
challenge: {
custom_request_handling: {
insert_headers: [ # required
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
},
},
}
The action that WAF should take on a web request when it matches a rule's statement. Settings at the web ACL level can override the rule action setting.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allow ⇒ Types::AllowAction
Instructs WAF to allow the web request.
-
#block ⇒ Types::BlockAction
Instructs WAF to block the web request.
-
#captcha ⇒ Types::CaptchaAction
Instructs WAF to run a `CAPTCHA` check against the web request.
-
#challenge ⇒ Types::ChallengeAction
Instructs WAF to run a `Challenge` check against the web request.
-
#count ⇒ Types::CountAction
Instructs WAF to count the web request and then continue evaluating the request using the remaining rules in the web ACL.
Instance Attribute Details
#allow ⇒ Types::AllowAction
Instructs WAF to allow the web request.
12192 12193 12194 12195 12196 12197 12198 12199 12200 |
# File 'lib/aws-sdk-wafv2/types.rb', line 12192 class RuleAction < Struct.new( :block, :allow, :count, :captcha, :challenge) SENSITIVE = [] include Aws::Structure end |
#block ⇒ Types::BlockAction
Instructs WAF to block the web request.
12192 12193 12194 12195 12196 12197 12198 12199 12200 |
# File 'lib/aws-sdk-wafv2/types.rb', line 12192 class RuleAction < Struct.new( :block, :allow, :count, :captcha, :challenge) SENSITIVE = [] include Aws::Structure end |
#captcha ⇒ Types::CaptchaAction
Instructs WAF to run a `CAPTCHA` check against the web request.
12192 12193 12194 12195 12196 12197 12198 12199 12200 |
# File 'lib/aws-sdk-wafv2/types.rb', line 12192 class RuleAction < Struct.new( :block, :allow, :count, :captcha, :challenge) SENSITIVE = [] include Aws::Structure end |
#challenge ⇒ Types::ChallengeAction
Instructs WAF to run a `Challenge` check against the web request.
12192 12193 12194 12195 12196 12197 12198 12199 12200 |
# File 'lib/aws-sdk-wafv2/types.rb', line 12192 class RuleAction < Struct.new( :block, :allow, :count, :captcha, :challenge) SENSITIVE = [] include Aws::Structure end |
#count ⇒ Types::CountAction
Instructs WAF to count the web request and then continue evaluating the request using the remaining rules in the web ACL.
12192 12193 12194 12195 12196 12197 12198 12199 12200 |
# File 'lib/aws-sdk-wafv2/types.rb', line 12192 class RuleAction < Struct.new( :block, :allow, :count, :captcha, :challenge) SENSITIVE = [] include Aws::Structure end |