Class: Aws::WAFV2::Types::RuleActionOverride
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::RuleActionOverride
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
When making an API call, you may pass RuleActionOverride data as a hash:
{
name: "EntityName", # required
action_to_use: { # required
block: {
custom_response: {
response_code: 1, # required
custom_response_body_key: "EntityName",
response_headers: [
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
},
},
allow: {
custom_request_handling: {
insert_headers: [ # required
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
},
},
count: {
custom_request_handling: {
insert_headers: [ # required
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
},
},
captcha: {
custom_request_handling: {
insert_headers: [ # required
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
},
},
challenge: {
custom_request_handling: {
insert_headers: [ # required
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
},
},
},
}
Action setting to use in the place of a rule action that is configured inside the rule group. You specify one override for each rule whose action you want to change.
You can use overrides for testing, for example you can override all of rule actions to `Count` and then monitor the resulting count metrics to understand how the rule group would handle your web traffic. You can also permanently override some or all actions, to modify how the rule group manages your web traffic.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_to_use ⇒ Types::RuleAction
The override action to use, in place of the configured action of the rule in the rule group.
-
#name ⇒ String
The name of the rule to override.
Instance Attribute Details
#action_to_use ⇒ Types::RuleAction
The override action to use, in place of the configured action of the rule in the rule group.
12324 12325 12326 12327 12328 12329 |
# File 'lib/aws-sdk-wafv2/types.rb', line 12324 class RuleActionOverride < Struct.new( :name, :action_to_use) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the rule to override.
12324 12325 12326 12327 12328 12329 |
# File 'lib/aws-sdk-wafv2/types.rb', line 12324 class RuleActionOverride < Struct.new( :name, :action_to_use) SENSITIVE = [] include Aws::Structure end |