Class: Aws::WAFV2::Types::RuleGroupReferenceStatement
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::RuleGroupReferenceStatement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
When making an API call, you may pass RuleGroupReferenceStatement data as a hash:
{
arn: "ResourceArn", # required
excluded_rules: [
{
name: "EntityName", # required
},
],
rule_action_overrides: [
{
name: "EntityName", # required
action_to_use: { # required
block: {
custom_response: {
response_code: 1, # required
custom_response_body_key: "EntityName",
response_headers: [
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
},
},
allow: {
custom_request_handling: {
insert_headers: [ # required
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
},
},
count: {
custom_request_handling: {
insert_headers: [ # required
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
},
},
captcha: {
custom_request_handling: {
insert_headers: [ # required
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
},
},
challenge: {
custom_request_handling: {
insert_headers: [ # required
{
name: "CustomHTTPHeaderName", # required
value: "CustomHTTPHeaderValue", # required
},
],
},
},
},
},
],
}
A rule statement used to run the rules that are defined in a RuleGroup. To use this, create a rule group with your rules, then provide the ARN of the rule group in this statement.
You cannot nest a `RuleGroupReferenceStatement`, for example for use inside a `NotStatement` or `OrStatement`. You can only use a rule group reference statement at the top level inside a web ACL.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the entity.
-
#excluded_rules ⇒ Array<Types::ExcludedRule>
Rules in the referenced rule group whose actions are set to `Count`.
-
#rule_action_overrides ⇒ Array<Types::RuleActionOverride>
Action settings to use in the place of the rule actions that are configured inside the rule group.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the entity.
12521 12522 12523 12524 12525 12526 12527 |
# File 'lib/aws-sdk-wafv2/types.rb', line 12521 class RuleGroupReferenceStatement < Struct.new( :arn, :excluded_rules, :rule_action_overrides) SENSITIVE = [] include Aws::Structure end |
#excluded_rules ⇒ Array<Types::ExcludedRule>
Rules in the referenced rule group whose actions are set to `Count`.
<note markdown=“1”> Instead of this option, use `RuleActionOverrides`. It accepts any valid action setting, including `Count`.
</note>
12521 12522 12523 12524 12525 12526 12527 |
# File 'lib/aws-sdk-wafv2/types.rb', line 12521 class RuleGroupReferenceStatement < Struct.new( :arn, :excluded_rules, :rule_action_overrides) SENSITIVE = [] include Aws::Structure end |
#rule_action_overrides ⇒ Array<Types::RuleActionOverride>
Action settings to use in the place of the rule actions that are configured inside the rule group. You specify one override for each rule whose action you want to change.
You can use overrides for testing, for example you can override all of rule actions to `Count` and then monitor the resulting count metrics to understand how the rule group would handle your web traffic. You can also permanently override some or all actions, to modify how the rule group manages your web traffic.
12521 12522 12523 12524 12525 12526 12527 |
# File 'lib/aws-sdk-wafv2/types.rb', line 12521 class RuleGroupReferenceStatement < Struct.new( :arn, :excluded_rules, :rule_action_overrides) SENSITIVE = [] include Aws::Structure end |