Class: Aws::WAFV2::Types::RuleGroupReferenceStatement
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::RuleGroupReferenceStatement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
When making an API call, you may pass RuleGroupReferenceStatement data as a hash:
{
arn: "ResourceArn", # required
excluded_rules: [
{
name: "EntityName", # required
},
],
}
A rule statement used to run the rules that are defined in a RuleGroup. To use this, create a rule group with your rules, then provide the ARN of the rule group in this statement.
You cannot nest a `RuleGroupReferenceStatement`, for example for use inside a `NotStatement` or `OrStatement`. You can only use a rule group reference statement at the top level inside a web ACL.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the entity.
-
#excluded_rules ⇒ Array<Types::ExcludedRule>
The rules in the referenced rule group whose actions are set to `Count`.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the entity.
9211 9212 9213 9214 9215 9216 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9211 class RuleGroupReferenceStatement < Struct.new( :arn, :excluded_rules) SENSITIVE = [] include Aws::Structure end |
#excluded_rules ⇒ Array<Types::ExcludedRule>
The rules in the referenced rule group whose actions are set to `Count`. When you exclude a rule, WAF evaluates it exactly as it would if the rule action setting were `Count`. This is a useful option for testing the rules in a rule group without modifying how they handle your web traffic.
9211 9212 9213 9214 9215 9216 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9211 class RuleGroupReferenceStatement < Struct.new( :arn, :excluded_rules) SENSITIVE = [] include Aws::Structure end |