Class: Aws::WAFV2::Types::SampledHTTPRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Represents a single sampled web request. The response from GetSampledRequests includes a `SampledHTTPRequests` complex type that appears as `SampledRequests` in the response syntax. `SampledHTTPRequests` contains an array of `SampledHTTPRequest` objects.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action for the `Rule` that the request matched: `Allow`, `Block`, or `Count`.

Returns:

  • (String)


10979
10980
10981
10982
10983
10984
10985
10986
10987
10988
10989
10990
10991
# File 'lib/aws-sdk-wafv2/types.rb', line 10979

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response)
  SENSITIVE = []
  include Aws::Structure
end

#captcha_responseTypes::CaptchaResponse

The `CAPTCHA` response for the request.



10979
10980
10981
10982
10983
10984
10985
10986
10987
10988
10989
10990
10991
# File 'lib/aws-sdk-wafv2/types.rb', line 10979

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response)
  SENSITIVE = []
  include Aws::Structure
end

#labelsArray<Types::Label>

Labels applied to the web request by matching rules. WAF applies fully qualified labels to matching web requests. A fully qualified label is the concatenation of a label namespace and a rule label. The rule's rule group or web ACL defines the label namespace.

For example, `awswaf:111122223333:myRuleGroup:testRules:testNS1:testNS2:labelNameA` or `awswaf:managed:aws:managed-rule-set:header:encoding:utf8`.

Returns:



10979
10980
10981
10982
10983
10984
10985
10986
10987
10988
10989
10990
10991
# File 'lib/aws-sdk-wafv2/types.rb', line 10979

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response)
  SENSITIVE = []
  include Aws::Structure
end

#requestTypes::HTTPRequest

A complex type that contains detailed information about the request.

Returns:



10979
10980
10981
10982
10983
10984
10985
10986
10987
10988
10989
10990
10991
# File 'lib/aws-sdk-wafv2/types.rb', line 10979

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response)
  SENSITIVE = []
  include Aws::Structure
end

#request_headers_insertedArray<Types::HTTPHeader>

Custom request headers inserted by WAF into the request, according to the custom request configuration for the matching rule action.

Returns:



10979
10980
10981
10982
10983
10984
10985
10986
10987
10988
10989
10990
10991
# File 'lib/aws-sdk-wafv2/types.rb', line 10979

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response)
  SENSITIVE = []
  include Aws::Structure
end

#response_code_sentInteger

The response code that was sent for the request.

Returns:

  • (Integer)


10979
10980
10981
10982
10983
10984
10985
10986
10987
10988
10989
10990
10991
# File 'lib/aws-sdk-wafv2/types.rb', line 10979

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response)
  SENSITIVE = []
  include Aws::Structure
end

#rule_name_within_rule_groupString

The name of the `Rule` that the request matched. For managed rule groups, the format for this name is `<vendor name>#<managed rule group name>#<rule name>`. For your own rule groups, the format for this name is `<rule group name>#<rule name>`. If the rule is not in a rule group, this field is absent.

Returns:

  • (String)


10979
10980
10981
10982
10983
10984
10985
10986
10987
10988
10989
10990
10991
# File 'lib/aws-sdk-wafv2/types.rb', line 10979

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response)
  SENSITIVE = []
  include Aws::Structure
end

#timestampTime

The time at which WAF received the request from your Amazon Web Services resource, in Unix time format (in seconds).

Returns:

  • (Time)


10979
10980
10981
10982
10983
10984
10985
10986
10987
10988
10989
10990
10991
# File 'lib/aws-sdk-wafv2/types.rb', line 10979

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response)
  SENSITIVE = []
  include Aws::Structure
end

#weightInteger

A value that indicates how one result in the response relates proportionally to other results in the response. For example, a result that has a weight of `2` represents roughly twice as many web requests as a result that has a weight of `1`.

Returns:

  • (Integer)


10979
10980
10981
10982
10983
10984
10985
10986
10987
10988
10989
10990
10991
# File 'lib/aws-sdk-wafv2/types.rb', line 10979

class SampledHTTPRequest < Struct.new(
  :request,
  :weight,
  :timestamp,
  :action,
  :rule_name_within_rule_group,
  :request_headers_inserted,
  :response_code_sent,
  :labels,
  :captcha_response)
  SENSITIVE = []
  include Aws::Structure
end