Class: Aws::WAFV2::Types::SampledHTTPRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::SampledHTTPRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Represents a single sampled web request. The response from GetSampledRequests includes a `SampledHTTPRequests` complex type that appears as `SampledRequests` in the response syntax. `SampledHTTPRequests` contains an array of `SampledHTTPRequest` objects.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action for the `Rule` that the request matched: `Allow`, `Block`, or `Count`.
-
#captcha_response ⇒ Types::CaptchaResponse
The `CAPTCHA` response for the request.
-
#labels ⇒ Array<Types::Label>
Labels applied to the web request by matching rules.
-
#request ⇒ Types::HTTPRequest
A complex type that contains detailed information about the request.
-
#request_headers_inserted ⇒ Array<Types::HTTPHeader>
Custom request headers inserted by WAF into the request, according to the custom request configuration for the matching rule action.
-
#response_code_sent ⇒ Integer
The response code that was sent for the request.
-
#rule_name_within_rule_group ⇒ String
The name of the `Rule` that the request matched.
-
#timestamp ⇒ Time
The time at which WAF received the request from your Amazon Web Services resource, in Unix time format (in seconds).
-
#weight ⇒ Integer
A value that indicates how one result in the response relates proportionally to other results in the response.
Instance Attribute Details
#action ⇒ String
The action for the `Rule` that the request matched: `Allow`, `Block`, or `Count`.
9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 9337 9338 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9326 class SampledHTTPRequest < Struct.new( :request, :weight, :timestamp, :action, :rule_name_within_rule_group, :request_headers_inserted, :response_code_sent, :labels, :captcha_response) SENSITIVE = [] include Aws::Structure end |
#captcha_response ⇒ Types::CaptchaResponse
The `CAPTCHA` response for the request.
9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 9337 9338 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9326 class SampledHTTPRequest < Struct.new( :request, :weight, :timestamp, :action, :rule_name_within_rule_group, :request_headers_inserted, :response_code_sent, :labels, :captcha_response) SENSITIVE = [] include Aws::Structure end |
#labels ⇒ Array<Types::Label>
Labels applied to the web request by matching rules. WAF applies fully qualified labels to matching web requests. A fully qualified label is the concatenation of a label namespace and a rule label. The rule's rule group or web ACL defines the label namespace.
For example, `awswaf:111122223333:myRuleGroup:testRules:testNS1:testNS2:labelNameA` or `awswaf:managed:aws:managed-rule-set:header:encoding:utf8`.
9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 9337 9338 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9326 class SampledHTTPRequest < Struct.new( :request, :weight, :timestamp, :action, :rule_name_within_rule_group, :request_headers_inserted, :response_code_sent, :labels, :captcha_response) SENSITIVE = [] include Aws::Structure end |
#request ⇒ Types::HTTPRequest
A complex type that contains detailed information about the request.
9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 9337 9338 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9326 class SampledHTTPRequest < Struct.new( :request, :weight, :timestamp, :action, :rule_name_within_rule_group, :request_headers_inserted, :response_code_sent, :labels, :captcha_response) SENSITIVE = [] include Aws::Structure end |
#request_headers_inserted ⇒ Array<Types::HTTPHeader>
Custom request headers inserted by WAF into the request, according to the custom request configuration for the matching rule action.
9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 9337 9338 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9326 class SampledHTTPRequest < Struct.new( :request, :weight, :timestamp, :action, :rule_name_within_rule_group, :request_headers_inserted, :response_code_sent, :labels, :captcha_response) SENSITIVE = [] include Aws::Structure end |
#response_code_sent ⇒ Integer
The response code that was sent for the request.
9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 9337 9338 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9326 class SampledHTTPRequest < Struct.new( :request, :weight, :timestamp, :action, :rule_name_within_rule_group, :request_headers_inserted, :response_code_sent, :labels, :captcha_response) SENSITIVE = [] include Aws::Structure end |
#rule_name_within_rule_group ⇒ String
The name of the `Rule` that the request matched. For managed rule groups, the format for this name is `<vendor name>#<managed rule group name>#<rule name>`. For your own rule groups, the format for this name is `<rule group name>#<rule name>`. If the rule is not in a rule group, this field is absent.
9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 9337 9338 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9326 class SampledHTTPRequest < Struct.new( :request, :weight, :timestamp, :action, :rule_name_within_rule_group, :request_headers_inserted, :response_code_sent, :labels, :captcha_response) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Time
The time at which WAF received the request from your Amazon Web Services resource, in Unix time format (in seconds).
9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 9337 9338 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9326 class SampledHTTPRequest < Struct.new( :request, :weight, :timestamp, :action, :rule_name_within_rule_group, :request_headers_inserted, :response_code_sent, :labels, :captcha_response) SENSITIVE = [] include Aws::Structure end |
#weight ⇒ Integer
A value that indicates how one result in the response relates proportionally to other results in the response. For example, a result that has a weight of `2` represents roughly twice as many web requests as a result that has a weight of `1`.
9326 9327 9328 9329 9330 9331 9332 9333 9334 9335 9336 9337 9338 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9326 class SampledHTTPRequest < Struct.new( :request, :weight, :timestamp, :action, :rule_name_within_rule_group, :request_headers_inserted, :response_code_sent, :labels, :captcha_response) SENSITIVE = [] include Aws::Structure end |