Class: Aws::WAFV2::Types::SingleHeader
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::SingleHeader
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Inspect one of the headers in the web request, identified by name, for
example, User-Agent or Referer. The name isn't case sensitive.
You can filter and inspect all headers with the FieldToMatch setting
Headers.
This is used to indicate the web request component to inspect, in the FieldToMatch specification.
Example JSON: "SingleHeader": { "Name": "haystack" }
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the query header to inspect.
Instance Attribute Details
#name ⇒ String
The name of the query header to inspect.
9895 9896 9897 9898 9899 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9895 class SingleHeader < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |