Class: Aws::WAFV2::Types::SingleHeader

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass SingleHeader data as a hash:

{
  name: "FieldToMatchData", # required
}

One of the headers in a web request, identified by name, for example, `User-Agent` or `Referer`. This setting isn't case sensitive.

This is used only to indicate the web request component for WAF to inspect, in the FieldToMatch specification.

Example JSON: `“SingleHeader”: { “Name”: “haystack” }`

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the query header to inspect.

Returns:

  • (String)


9303
9304
9305
9306
9307
# File 'lib/aws-sdk-wafv2/types.rb', line 9303

class SingleHeader < Struct.new(
  :name)
  SENSITIVE = []
  include Aws::Structure
end