Class: Aws::WAFV2::Types::SingleHeader
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::SingleHeader
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Note:
When making an API call, you may pass SingleHeader data as a hash:
{
name: "FieldToMatchData", # required
}
One of the headers in a web request, identified by name, for example, `User-Agent` or `Referer`. This setting isn't case sensitive.
This is used only to indicate the web request component for WAF to inspect, in the FieldToMatch specification.
Example JSON: `“SingleHeader”: { “Name”: “haystack” }`
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the query header to inspect.
Instance Attribute Details
#name ⇒ String
The name of the query header to inspect.
8896 8897 8898 8899 8900 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8896 class SingleHeader < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |