Class: Aws::WAFV2::Types::SingleQueryArgument
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::SingleQueryArgument
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Inspect one query argument in the web request, identified by name, for example UserName or SalesRegion. The name isn’t case sensitive.
This is used to indicate the web request component to inspect, in the FieldToMatch specification.
Example JSON: ‘“SingleQueryArgument”: { “Name”: “myArgument” }`
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the query argument to inspect.
Instance Attribute Details
#name ⇒ String
The name of the query argument to inspect.
7673 7674 7675 7676 7677 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7673 class SingleQueryArgument < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |