Class: Aws::WAFV2::Types::SingleQueryArgument
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::SingleQueryArgument
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Inspect one query argument in the web request, identified by name, for example UserName or SalesRegion. The name isn’t case sensitive.
This is used to indicate the web request component to inspect, in the FieldToMatch specification.
Example JSON: ‘“SingleQueryArgument”: { “Name”: “myArgument” }`
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the query argument to inspect.
Instance Attribute Details
#name ⇒ String
The name of the query argument to inspect.
6580 6581 6582 6583 6584 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6580 class SingleQueryArgument < Struct.new( :name) SENSITIVE = [] include Aws::Structure end |