Class: Aws::WAFV2::Types::SingleQueryArgument

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Inspect one query argument in the web request, identified by name, for example UserName or SalesRegion. The name isn’t case sensitive.

This is used to indicate the web request component to inspect, in the FieldToMatch specification.

Example JSON: ‘“SingleQueryArgument”: { “Name”: “myArgument” }`

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the query argument to inspect.

Returns:

  • (String)


6179
6180
6181
6182
6183
# File 'lib/aws-sdk-wafv2/types.rb', line 6179

class SingleQueryArgument < Struct.new(
  :name)
  SENSITIVE = []
  include Aws::Structure
end