Class: Aws::WAFV2::Types::SourceStatistics

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Revenue statistics for a single AI bot source, including the bot name, revenue amount, request count, and verification status.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amountString

The total revenue amount from this source in the specified currency.

Returns:

  • (String)


9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
# File 'lib/aws-sdk-wafv2/types.rb', line 9928

class SourceStatistics < Struct.new(
  :source_name,
  :percentage,
  :amount,
  :request_count,
  :source_category,
  :intent,
  :organization,
  :verified,
  :group_by_value)
  SENSITIVE = []
  include Aws::Structure
end

#group_by_valueString

The value for the group-by dimension, when grouping is applied.

Returns:

  • (String)


9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
# File 'lib/aws-sdk-wafv2/types.rb', line 9928

class SourceStatistics < Struct.new(
  :source_name,
  :percentage,
  :amount,
  :request_count,
  :source_category,
  :intent,
  :organization,
  :verified,
  :group_by_value)
  SENSITIVE = []
  include Aws::Structure
end

#intentString

The declared intent of the AI bot (for example, summarize, index, or train).

Returns:

  • (String)


9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
# File 'lib/aws-sdk-wafv2/types.rb', line 9928

class SourceStatistics < Struct.new(
  :source_name,
  :percentage,
  :amount,
  :request_count,
  :source_category,
  :intent,
  :organization,
  :verified,
  :group_by_value)
  SENSITIVE = []
  include Aws::Structure
end

#organizationString

The organization associated with the AI bot.

Returns:

  • (String)


9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
# File 'lib/aws-sdk-wafv2/types.rb', line 9928

class SourceStatistics < Struct.new(
  :source_name,
  :percentage,
  :amount,
  :request_count,
  :source_category,
  :intent,
  :organization,
  :verified,
  :group_by_value)
  SENSITIVE = []
  include Aws::Structure
end

#percentageFloat

The percentage of total revenue from this source.

Returns:

  • (Float)


9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
# File 'lib/aws-sdk-wafv2/types.rb', line 9928

class SourceStatistics < Struct.new(
  :source_name,
  :percentage,
  :amount,
  :request_count,
  :source_category,
  :intent,
  :organization,
  :verified,
  :group_by_value)
  SENSITIVE = []
  include Aws::Structure
end

#request_countInteger

The number of monetized requests from this source.

Returns:

  • (Integer)


9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
# File 'lib/aws-sdk-wafv2/types.rb', line 9928

class SourceStatistics < Struct.new(
  :source_name,
  :percentage,
  :amount,
  :request_count,
  :source_category,
  :intent,
  :organization,
  :verified,
  :group_by_value)
  SENSITIVE = []
  include Aws::Structure
end

#source_categoryString

The category of this AI bot source.

Returns:

  • (String)


9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
# File 'lib/aws-sdk-wafv2/types.rb', line 9928

class SourceStatistics < Struct.new(
  :source_name,
  :percentage,
  :amount,
  :request_count,
  :source_category,
  :intent,
  :organization,
  :verified,
  :group_by_value)
  SENSITIVE = []
  include Aws::Structure
end

#source_nameString

The name of the AI bot.

Returns:

  • (String)


9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
# File 'lib/aws-sdk-wafv2/types.rb', line 9928

class SourceStatistics < Struct.new(
  :source_name,
  :percentage,
  :amount,
  :request_count,
  :source_category,
  :intent,
  :organization,
  :verified,
  :group_by_value)
  SENSITIVE = []
  include Aws::Structure
end

#verifiedBoolean

Whether the AI bot’s identity was verified.

Returns:

  • (Boolean)


9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
# File 'lib/aws-sdk-wafv2/types.rb', line 9928

class SourceStatistics < Struct.new(
  :source_name,
  :percentage,
  :amount,
  :request_count,
  :source_category,
  :intent,
  :organization,
  :verified,
  :group_by_value)
  SENSITIVE = []
  include Aws::Structure
end