Class: Aws::WAFV2::Types::SqliMatchStatement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

A rule statement that inspects for malicious SQL code. Attackers insert malicious SQL code into web requests to do things like modify your database or extract data from it.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#field_to_matchTypes::FieldToMatch

The part of the web request that you want WAF to inspect.

Returns:



6683
6684
6685
6686
6687
6688
6689
# File 'lib/aws-sdk-wafv2/types.rb', line 6683

class SqliMatchStatement < Struct.new(
  :field_to_match,
  :text_transformations,
  :sensitivity_level)
  SENSITIVE = []
  include Aws::Structure
end

#sensitivity_levelString

The sensitivity that you want WAF to use to inspect for SQL injection attacks.

‘HIGH` detects more attacks, but might generate more false positives, especially if your web requests frequently contain unusual strings. For information about identifying and mitigating false positives, see [Testing and tuning] in the *WAF Developer Guide*.

‘LOW` is generally a better choice for resources that already have other protections against SQL injection attacks or that have a low tolerance for false positives.

Default: ‘LOW`

[1]: docs.aws.amazon.com/waf/latest/developerguide/web-acl-testing.html

Returns:

  • (String)


6683
6684
6685
6686
6687
6688
6689
# File 'lib/aws-sdk-wafv2/types.rb', line 6683

class SqliMatchStatement < Struct.new(
  :field_to_match,
  :text_transformations,
  :sensitivity_level)
  SENSITIVE = []
  include Aws::Structure
end

#text_transformationsArray<Types::TextTransformation>

Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, WAF performs all transformations on the content of the request component identified by ‘FieldToMatch`, starting from the lowest priority setting, before inspecting the content for a match.

Returns:



6683
6684
6685
6686
6687
6688
6689
# File 'lib/aws-sdk-wafv2/types.rb', line 6683

class SqliMatchStatement < Struct.new(
  :field_to_match,
  :text_transformations,
  :sensitivity_level)
  SENSITIVE = []
  include Aws::Structure
end