Class: Aws::WAFV2::Types::SqliMatchStatement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass SqliMatchStatement data as a hash:

{
  field_to_match: { # required
    single_header: {
      name: "FieldToMatchData", # required
    },
    single_query_argument: {
      name: "FieldToMatchData", # required
    },
    all_query_arguments: {
    },
    uri_path: {
    },
    query_string: {
    },
    body: {
      oversize_handling: "CONTINUE", # accepts CONTINUE, MATCH, NO_MATCH
    },
    method: {
    },
    json_body: {
      match_pattern: { # required
        all: {
        },
        included_paths: ["JsonPointerPath"],
      },
      match_scope: "ALL", # required, accepts ALL, KEY, VALUE
      invalid_fallback_behavior: "MATCH", # accepts MATCH, NO_MATCH, EVALUATE_AS_STRING
      oversize_handling: "CONTINUE", # accepts CONTINUE, MATCH, NO_MATCH
    },
    headers: {
      match_pattern: { # required
        all: {
        },
        included_headers: ["FieldToMatchData"],
        excluded_headers: ["FieldToMatchData"],
      },
      match_scope: "ALL", # required, accepts ALL, KEY, VALUE
      oversize_handling: "CONTINUE", # required, accepts CONTINUE, MATCH, NO_MATCH
    },
    cookies: {
      match_pattern: { # required
        all: {
        },
        included_cookies: ["SingleCookieName"],
        excluded_cookies: ["SingleCookieName"],
      },
      match_scope: "ALL", # required, accepts ALL, KEY, VALUE
      oversize_handling: "CONTINUE", # required, accepts CONTINUE, MATCH, NO_MATCH
    },
  },
  text_transformations: [ # required
    {
      priority: 1, # required
      type: "NONE", # required, accepts NONE, COMPRESS_WHITE_SPACE, HTML_ENTITY_DECODE, LOWERCASE, CMD_LINE, URL_DECODE, BASE64_DECODE, HEX_DECODE, MD5, REPLACE_COMMENTS, ESCAPE_SEQ_DECODE, SQL_HEX_DECODE, CSS_DECODE, JS_DECODE, NORMALIZE_PATH, NORMALIZE_PATH_WIN, REMOVE_NULLS, REPLACE_NULLS, BASE64_DECODE_EXT, URL_DECODE_UNI, UTF8_TO_UNICODE
    },
  ],
  sensitivity_level: "LOW", # accepts LOW, HIGH
}

A rule statement that inspects for malicious SQL code. Attackers insert malicious SQL code into web requests to do things like modify your database or extract data from it.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#field_to_matchTypes::FieldToMatch

The part of the web request that you want WAF to inspect.

Returns:



11270
11271
11272
11273
11274
11275
11276
# File 'lib/aws-sdk-wafv2/types.rb', line 11270

class SqliMatchStatement < Struct.new(
  :field_to_match,
  :text_transformations,
  :sensitivity_level)
  SENSITIVE = []
  include Aws::Structure
end

#sensitivity_levelString

The sensitivity that you want WAF to use to inspect for SQL injection attacks.

`HIGH` detects more attacks, but might generate more false positives, especially if your web requests frequently contain unusual strings. For information about identifying and mitigating false positives, see [Testing and tuning] in the *WAF Developer Guide*.

`LOW` is generally a better choice for resources that already have other protections against SQL injection attacks or that have a low tolerance for false positives.

Default: `LOW`

[1]: docs.aws.amazon.com/waf/latest/developerguide/web-acl-testing.html

Returns:

  • (String)


11270
11271
11272
11273
11274
11275
11276
# File 'lib/aws-sdk-wafv2/types.rb', line 11270

class SqliMatchStatement < Struct.new(
  :field_to_match,
  :text_transformations,
  :sensitivity_level)
  SENSITIVE = []
  include Aws::Structure
end

#text_transformationsArray<Types::TextTransformation>

Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, WAF performs all transformations on the content of the request component identified by `FieldToMatch`, starting from the lowest priority setting, before inspecting the content for a match.

Returns:



11270
11271
11272
11273
11274
11275
11276
# File 'lib/aws-sdk-wafv2/types.rb', line 11270

class SqliMatchStatement < Struct.new(
  :field_to_match,
  :text_transformations,
  :sensitivity_level)
  SENSITIVE = []
  include Aws::Structure
end