Class: Aws::WAFV2::Types::SqliMatchStatement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass SqliMatchStatement data as a hash:

{
  field_to_match: { # required
    single_header: {
      name: "FieldToMatchData", # required
    },
    single_query_argument: {
      name: "FieldToMatchData", # required
    },
    all_query_arguments: {
    },
    uri_path: {
    },
    query_string: {
    },
    body: {
      oversize_handling: "CONTINUE", # accepts CONTINUE, MATCH, NO_MATCH
    },
    method: {
    },
    json_body: {
      match_pattern: { # required
        all: {
        },
        included_paths: ["JsonPointerPath"],
      },
      match_scope: "ALL", # required, accepts ALL, KEY, VALUE
      invalid_fallback_behavior: "MATCH", # accepts MATCH, NO_MATCH, EVALUATE_AS_STRING
      oversize_handling: "CONTINUE", # accepts CONTINUE, MATCH, NO_MATCH
    },
    headers: {
      match_pattern: { # required
        all: {
        },
        included_headers: ["FieldToMatchData"],
        excluded_headers: ["FieldToMatchData"],
      },
      match_scope: "ALL", # required, accepts ALL, KEY, VALUE
      oversize_handling: "CONTINUE", # required, accepts CONTINUE, MATCH, NO_MATCH
    },
    cookies: {
      match_pattern: { # required
        all: {
        },
        included_cookies: ["SingleCookieName"],
        excluded_cookies: ["SingleCookieName"],
      },
      match_scope: "ALL", # required, accepts ALL, KEY, VALUE
      oversize_handling: "CONTINUE", # required, accepts CONTINUE, MATCH, NO_MATCH
    },
  },
  text_transformations: [ # required
    {
      priority: 1, # required
      type: "NONE", # required, accepts NONE, COMPRESS_WHITE_SPACE, HTML_ENTITY_DECODE, LOWERCASE, CMD_LINE, URL_DECODE, BASE64_DECODE, HEX_DECODE, MD5, REPLACE_COMMENTS, ESCAPE_SEQ_DECODE, SQL_HEX_DECODE, CSS_DECODE, JS_DECODE, NORMALIZE_PATH, NORMALIZE_PATH_WIN, REMOVE_NULLS, REPLACE_NULLS, BASE64_DECODE_EXT, URL_DECODE_UNI, UTF8_TO_UNICODE
    },
  ],
}

Attackers sometimes insert malicious SQL code into web requests in an effort to extract data from your database. To allow or block web requests that appear to contain malicious SQL code, create one or more SQL injection match conditions. An SQL injection match condition identifies the part of web requests, such as the URI or the query string, that you want WAF to inspect. Later in the process, when you create a web ACL, you specify whether to allow or block requests that appear to contain malicious SQL code.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#field_to_matchTypes::FieldToMatch

The part of the web request that you want WAF to inspect. For more information, see FieldToMatch.

Returns:



11247
11248
11249
11250
11251
11252
# File 'lib/aws-sdk-wafv2/types.rb', line 11247

class SqliMatchStatement < Struct.new(
  :field_to_match,
  :text_transformations)
  SENSITIVE = []
  include Aws::Structure
end

#text_transformationsArray<Types::TextTransformation>

Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, WAF performs all transformations on the content of the request component identified by `FieldToMatch`, starting from the lowest priority setting, before inspecting the content for a match.

Returns:



11247
11248
11249
11250
11251
11252
# File 'lib/aws-sdk-wafv2/types.rb', line 11247

class SqliMatchStatement < Struct.new(
  :field_to_match,
  :text_transformations)
  SENSITIVE = []
  include Aws::Structure
end