Class: Aws::WAFV2::Types::TextTransformation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#priorityInteger

Sets the relative processing order for multiple transformations. WAF processes all transformations, from lowest priority to highest, before inspecting the transformed content. The priorities don’t need to be consecutive, but they must all be different.

Returns:

  • (Integer)


10427
10428
10429
10430
10431
10432
# File 'lib/aws-sdk-wafv2/types.rb', line 10427

class TextTransformation < Struct.new(
  :priority,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

For detailed descriptions of each of the transformation types, see

Text transformations][1

in the *WAF Developer Guide*.

[1]: docs.aws.amazon.com/waf/latest/developerguide/waf-rule-statement-transformation.html

Returns:

  • (String)


10427
10428
10429
10430
10431
10432
# File 'lib/aws-sdk-wafv2/types.rb', line 10427

class TextTransformation < Struct.new(
  :priority,
  :type)
  SENSITIVE = []
  include Aws::Structure
end