Class: Aws::WAFV2::Types::UpdateIPSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#addressesArray<String>

Contains an array of strings that specifies zero or more IP addresses or blocks of IP addresses. All addresses must be specified using Classless Inter-Domain Routing (CIDR) notation. WAF supports all IPv4 and IPv6 CIDR ranges except for ‘/0`.

Example address strings:

  • To configure WAF to allow, block, or count requests that originated from the IP address 192.0.2.44, specify ‘192.0.2.44/32`.

  • To configure WAF to allow, block, or count requests that originated from IP addresses from 192.0.2.0 to 192.0.2.255, specify ‘192.0.2.0/24`.

  • To configure WAF to allow, block, or count requests that originated from the IP address 1111:0000:0000:0000:0000:0000:0000:0111, specify ‘1111:0000:0000:0000:0000:0000:0000:0111/128`.

  • To configure WAF to allow, block, or count requests that originated from IP addresses 1111:0000:0000:0000:0000:0000:0000:0000 to 1111:0000:0000:0000:ffff:ffff:ffff:ffff, specify ‘1111:0000:0000:0000:0000:0000:0000:0000/64`.

For more information about CIDR notation, see the Wikipedia entry [Classless Inter-Domain Routing].

Example JSON ‘Addresses` specifications:

  • Empty array: ‘“Addresses”: []`

  • Array with one address: ‘“Addresses”: [“192.0.2.44/32”]`

  • Array with three addresses: ‘“Addresses”: [“192.0.2.44/32”, “192.0.2.0/24”, “192.0.0.0/16”]`

  • INVALID specification: ‘“Addresses”: [“”]` INVALID

[1]: en.wikipedia.org/wiki/Classless_Inter-Domain_Routing

Returns:

  • (Array<String>)


6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-wafv2/types.rb', line 6978

class UpdateIPSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :description,
  :addresses,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the IP set that helps with identification.

Returns:

  • (String)


6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-wafv2/types.rb', line 6978

class UpdateIPSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :description,
  :addresses,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end

#idString

A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.

Returns:

  • (String)


6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-wafv2/types.rb', line 6978

class UpdateIPSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :description,
  :addresses,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end

#lock_tokenString

A token used for optimistic locking. WAF returns a token to your ‘get` and `list` requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like `update` and `delete`. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a `WAFOptimisticLockException`. If this happens, perform another `get`, and use the new token returned by that operation.

Returns:

  • (String)


6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-wafv2/types.rb', line 6978

class UpdateIPSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :description,
  :addresses,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the IP set. You cannot change the name of an ‘IPSet` after you create it.

Returns:

  • (String)


6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-wafv2/types.rb', line 6978

class UpdateIPSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :description,
  :addresses,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, a Amazon Cognito user pool, or an App Runner service.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: ‘–scope=CLOUDFRONT –region=us-east-1`.

  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Returns:

  • (String)


6978
6979
6980
6981
6982
6983
6984
6985
6986
6987
# File 'lib/aws-sdk-wafv2/types.rb', line 6978

class UpdateIPSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :description,
  :addresses,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end