Class: Aws::WAFV2::Types::UpdateIPSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass UpdateIPSetRequest data as a hash:

{
  name: "EntityName", # required
  scope: "CLOUDFRONT", # required, accepts CLOUDFRONT, REGIONAL
  id: "EntityId", # required
  description: "EntityDescription",
  addresses: ["IPAddress"], # required
  lock_token: "LockToken", # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#addressesArray<String>

Contains an array of strings that specify one or more IP addresses or blocks of IP addresses in Classless Inter-Domain Routing (CIDR) notation. WAF supports all IPv4 and IPv6 CIDR ranges except for /0.

Examples:

  • To configure WAF to allow, block, or count requests that originated from the IP address 192.0.2.44, specify `192.0.2.44/32`.

  • To configure WAF to allow, block, or count requests that originated from IP addresses from 192.0.2.0 to 192.0.2.255, specify `192.0.2.0/24`.

  • To configure WAF to allow, block, or count requests that originated from the IP address 1111:0000:0000:0000:0000:0000:0000:0111, specify `1111:0000:0000:0000:0000:0000:0000:0111/128`.

  • To configure WAF to allow, block, or count requests that originated from IP addresses 1111:0000:0000:0000:0000:0000:0000:0000 to 1111:0000:0000:0000:ffff:ffff:ffff:ffff, specify `1111:0000:0000:0000:0000:0000:0000:0000/64`.

For more information about CIDR notation, see the Wikipedia entry [Classless Inter-Domain Routing].

[1]: en.wikipedia.org/wiki/Classless_Inter-Domain_Routing

Returns:

  • (Array<String>)


11880
11881
11882
11883
11884
11885
11886
11887
11888
11889
# File 'lib/aws-sdk-wafv2/types.rb', line 11880

class UpdateIPSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :description,
  :addresses,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the IP set that helps with identification.

Returns:

  • (String)


11880
11881
11882
11883
11884
11885
11886
11887
11888
11889
# File 'lib/aws-sdk-wafv2/types.rb', line 11880

class UpdateIPSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :description,
  :addresses,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end

#idString

A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.

Returns:

  • (String)


11880
11881
11882
11883
11884
11885
11886
11887
11888
11889
# File 'lib/aws-sdk-wafv2/types.rb', line 11880

class UpdateIPSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :description,
  :addresses,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end

#lock_tokenString

A token used for optimistic locking. WAF returns a token to your `get` and `list` requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like `update` and `delete`. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a `WAFOptimisticLockException`. If this happens, perform another `get`, and use the new token returned by that operation.

Returns:

  • (String)


11880
11881
11882
11883
11884
11885
11886
11887
11888
11889
# File 'lib/aws-sdk-wafv2/types.rb', line 11880

class UpdateIPSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :description,
  :addresses,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the IP set. You cannot change the name of an `IPSet` after you create it.

Returns:

  • (String)


11880
11881
11882
11883
11884
11885
11886
11887
11888
11889
# File 'lib/aws-sdk-wafv2/types.rb', line 11880

class UpdateIPSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :description,
  :addresses,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: `–scope=CLOUDFRONT –region=us-east-1`.

  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Returns:

  • (String)


11880
11881
11882
11883
11884
11885
11886
11887
11888
11889
# File 'lib/aws-sdk-wafv2/types.rb', line 11880

class UpdateIPSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :description,
  :addresses,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end