Class: Aws::WAFV2::Types::UpdateManagedRuleSetVersionExpiryDateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::UpdateManagedRuleSetVersionExpiryDateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expiry_timestamp ⇒ Time
The time that you want the version to expire.
-
#id ⇒ String
A unique identifier for the managed rule set.
-
#lock_token ⇒ String
A token used for optimistic locking.
-
#name ⇒ String
The name of the managed rule set.
-
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application.
-
#version_to_expire ⇒ String
The version that you want to remove from your list of offerings for the named managed rule group.
Instance Attribute Details
#expiry_timestamp ⇒ Time
The time that you want the version to expire.
Times are in Coordinated Universal Time (UTC) format. UTC format includes the special designator, Z. For example, “2016-09-27T14:50Z”.
6641 6642 6643 6644 6645 6646 6647 6648 6649 6650 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6641 class UpdateManagedRuleSetVersionExpiryDateRequest < Struct.new( :name, :scope, :id, :lock_token, :version_to_expire, :expiry_timestamp) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A unique identifier for the managed rule set. The ID is returned in the responses to commands like `list`. You provide it to operations like `get` and `update`.
6641 6642 6643 6644 6645 6646 6647 6648 6649 6650 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6641 class UpdateManagedRuleSetVersionExpiryDateRequest < Struct.new( :name, :scope, :id, :lock_token, :version_to_expire, :expiry_timestamp) SENSITIVE = [] include Aws::Structure end |
#lock_token ⇒ String
A token used for optimistic locking. WAF returns a token to your `get` and `list` requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like `update` and `delete`. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a `WAFOptimisticLockException`. If this happens, perform another `get`, and use the new token returned by that operation.
6641 6642 6643 6644 6645 6646 6647 6648 6649 6650 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6641 class UpdateManagedRuleSetVersionExpiryDateRequest < Struct.new( :name, :scope, :id, :lock_token, :version_to_expire, :expiry_timestamp) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the managed rule set. You use this, along with the rule set ID, to identify the rule set.
This name is assigned to the corresponding managed rule group, which your customers can access and use.
6641 6642 6643 6644 6645 6646 6647 6648 6649 6650 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6641 class UpdateManagedRuleSetVersionExpiryDateRequest < Struct.new( :name, :scope, :id, :lock_token, :version_to_expire, :expiry_timestamp) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, or an Amazon Cognito user pool.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope: `–scope=CLOUDFRONT –region=us-east-1`.
-
API and SDKs - For all calls, use the Region endpoint us-east-1.
6641 6642 6643 6644 6645 6646 6647 6648 6649 6650 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6641 class UpdateManagedRuleSetVersionExpiryDateRequest < Struct.new( :name, :scope, :id, :lock_token, :version_to_expire, :expiry_timestamp) SENSITIVE = [] include Aws::Structure end |
#version_to_expire ⇒ String
The version that you want to remove from your list of offerings for the named managed rule group.
6641 6642 6643 6644 6645 6646 6647 6648 6649 6650 |
# File 'lib/aws-sdk-wafv2/types.rb', line 6641 class UpdateManagedRuleSetVersionExpiryDateRequest < Struct.new( :name, :scope, :id, :lock_token, :version_to_expire, :expiry_timestamp) SENSITIVE = [] include Aws::Structure end |