Class: Aws::WAFV2::Types::UpdateManagedRuleSetVersionExpiryDateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass UpdateManagedRuleSetVersionExpiryDateRequest data as a hash:

{
  name: "EntityName", # required
  scope: "CLOUDFRONT", # required, accepts CLOUDFRONT, REGIONAL
  id: "EntityId", # required
  lock_token: "LockToken", # required
  version_to_expire: "VersionKeyString", # required
  expiry_timestamp: Time.now, # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#expiry_timestampTime

The time that you want the version to expire.

Times are in Coordinated Universal Time (UTC) format. UTC format includes the special designator, Z. For example, “2016-09-27T14:50Z”.

Returns:

  • (Time)


11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
# File 'lib/aws-sdk-wafv2/types.rb', line 11506

class UpdateManagedRuleSetVersionExpiryDateRequest < Struct.new(
  :name,
  :scope,
  :id,
  :lock_token,
  :version_to_expire,
  :expiry_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#idString

A unique identifier for the managed rule set. The ID is returned in the responses to commands like `list`. You provide it to operations like `get` and `update`.

Returns:

  • (String)


11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
# File 'lib/aws-sdk-wafv2/types.rb', line 11506

class UpdateManagedRuleSetVersionExpiryDateRequest < Struct.new(
  :name,
  :scope,
  :id,
  :lock_token,
  :version_to_expire,
  :expiry_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#lock_tokenString

A token used for optimistic locking. WAF returns a token to your `get` and `list` requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like `update` and `delete`. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a `WAFOptimisticLockException`. If this happens, perform another `get`, and use the new token returned by that operation.

Returns:

  • (String)


11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
# File 'lib/aws-sdk-wafv2/types.rb', line 11506

class UpdateManagedRuleSetVersionExpiryDateRequest < Struct.new(
  :name,
  :scope,
  :id,
  :lock_token,
  :version_to_expire,
  :expiry_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the managed rule set. You use this, along with the rule set ID, to identify the rule set.

This name is assigned to the corresponding managed rule group, which your customers can access and use.

Returns:

  • (String)


11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
# File 'lib/aws-sdk-wafv2/types.rb', line 11506

class UpdateManagedRuleSetVersionExpiryDateRequest < Struct.new(
  :name,
  :scope,
  :id,
  :lock_token,
  :version_to_expire,
  :expiry_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: `–scope=CLOUDFRONT –region=us-east-1`.

  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Returns:

  • (String)


11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
# File 'lib/aws-sdk-wafv2/types.rb', line 11506

class UpdateManagedRuleSetVersionExpiryDateRequest < Struct.new(
  :name,
  :scope,
  :id,
  :lock_token,
  :version_to_expire,
  :expiry_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#version_to_expireString

The version that you want to remove from your list of offerings for the named managed rule group.

Returns:

  • (String)


11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
# File 'lib/aws-sdk-wafv2/types.rb', line 11506

class UpdateManagedRuleSetVersionExpiryDateRequest < Struct.new(
  :name,
  :scope,
  :id,
  :lock_token,
  :version_to_expire,
  :expiry_timestamp)
  SENSITIVE = []
  include Aws::Structure
end