Method: Aws::WAFV2::Types::UpdateManagedRuleSetVersionExpiryDateRequest#name
- Defined in:
- lib/aws-sdk-wafv2/types.rb
#name ⇒ String
The name of the managed rule set. You use this, along with the rule set ID, to identify the rule set.
This name is assigned to the corresponding managed rule group, which your customers can access and use.
9830 9831 9832 9833 9834 9835 9836 9837 9838 9839 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9830 class UpdateManagedRuleSetVersionExpiryDateRequest < Struct.new( :name, :scope, :id, :lock_token, :version_to_expire, :expiry_timestamp) SENSITIVE = [] include Aws::Structure end |