Class: Aws::WAFV2::Types::UpdateManagedRuleSetVersionExpiryDateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::UpdateManagedRuleSetVersionExpiryDateResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expiring_version ⇒ String
The version that is set to expire.
-
#expiry_timestamp ⇒ Time
The time that the version will expire.
-
#next_lock_token ⇒ String
A token used for optimistic locking.
Instance Attribute Details
#expiring_version ⇒ String
The version that is set to expire.
10724 10725 10726 10727 10728 10729 10730 |
# File 'lib/aws-sdk-wafv2/types.rb', line 10724 class UpdateManagedRuleSetVersionExpiryDateResponse < Struct.new( :expiring_version, :expiry_timestamp, :next_lock_token) SENSITIVE = [] include Aws::Structure end |
#expiry_timestamp ⇒ Time
The time that the version will expire.
Times are in Coordinated Universal Time (UTC) format. UTC format includes the special designator, Z. For example, "2016-09-27T14:50Z".
10724 10725 10726 10727 10728 10729 10730 |
# File 'lib/aws-sdk-wafv2/types.rb', line 10724 class UpdateManagedRuleSetVersionExpiryDateResponse < Struct.new( :expiring_version, :expiry_timestamp, :next_lock_token) SENSITIVE = [] include Aws::Structure end |
#next_lock_token ⇒ String
A token used for optimistic locking. WAF returns a token to your
get and list requests, to mark the state of the entity at the
time of the request. To make changes to the entity associated with
the token, you provide the token to operations like update and
delete. WAF uses the token to ensure that no changes have been
made to the entity since you last retrieved it. If a change has been
made, the update fails with a WAFOptimisticLockException. If this
happens, perform another get, and use the new token returned by
that operation.
10724 10725 10726 10727 10728 10729 10730 |
# File 'lib/aws-sdk-wafv2/types.rb', line 10724 class UpdateManagedRuleSetVersionExpiryDateResponse < Struct.new( :expiring_version, :expiry_timestamp, :next_lock_token) SENSITIVE = [] include Aws::Structure end |