Class: Aws::WAFV2::Types::UpdateRegexPatternSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::UpdateRegexPatternSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
When making an API call, you may pass UpdateRegexPatternSetRequest data as a hash:
{
name: "EntityName", # required
scope: "CLOUDFRONT", # required, accepts CLOUDFRONT, REGIONAL
id: "EntityId", # required
description: "EntityDescription",
regular_expression_list: [ # required
{
regex_string: "RegexPatternString",
},
],
lock_token: "LockToken", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the set that helps with identification.
-
#id ⇒ String
A unique identifier for the set.
-
#lock_token ⇒ String
A token used for optimistic locking.
-
#name ⇒ String
The name of the set.
- #regular_expression_list ⇒ Array<Types::Regex>
-
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application.
Instance Attribute Details
#description ⇒ String
A description of the set that helps with identification.
17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 |
# File 'lib/aws-sdk-wafv2/types.rb', line 17034 class UpdateRegexPatternSetRequest < Struct.new( :name, :scope, :id, :description, :regular_expression_list, :lock_token) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 |
# File 'lib/aws-sdk-wafv2/types.rb', line 17034 class UpdateRegexPatternSetRequest < Struct.new( :name, :scope, :id, :description, :regular_expression_list, :lock_token) SENSITIVE = [] include Aws::Structure end |
#lock_token ⇒ String
A token used for optimistic locking. WAF returns a token to your `get` and `list` requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like `update` and `delete`. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a `WAFOptimisticLockException`. If this happens, perform another `get`, and use the new token returned by that operation.
17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 |
# File 'lib/aws-sdk-wafv2/types.rb', line 17034 class UpdateRegexPatternSetRequest < Struct.new( :name, :scope, :id, :description, :regular_expression_list, :lock_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the set. You cannot change the name after you create the set.
17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 |
# File 'lib/aws-sdk-wafv2/types.rb', line 17034 class UpdateRegexPatternSetRequest < Struct.new( :name, :scope, :id, :description, :regular_expression_list, :lock_token) SENSITIVE = [] include Aws::Structure end |
#regular_expression_list ⇒ Array<Types::Regex>
17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 |
# File 'lib/aws-sdk-wafv2/types.rb', line 17034 class UpdateRegexPatternSetRequest < Struct.new( :name, :scope, :id, :description, :regular_expression_list, :lock_token) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, an AppSync GraphQL API, or an Amazon Cognito user pool.
To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:
-
CLI - Specify the Region when you use the CloudFront scope: `–scope=CLOUDFRONT –region=us-east-1`.
-
API and SDKs - For all calls, use the Region endpoint us-east-1.
17034 17035 17036 17037 17038 17039 17040 17041 17042 17043 |
# File 'lib/aws-sdk-wafv2/types.rb', line 17034 class UpdateRegexPatternSetRequest < Struct.new( :name, :scope, :id, :description, :regular_expression_list, :lock_token) SENSITIVE = [] include Aws::Structure end |