Class: Aws::WAFV2::Types::UpdateRegexPatternSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass UpdateRegexPatternSetRequest data as a hash:

{
  name: "EntityName", # required
  scope: "CLOUDFRONT", # required, accepts CLOUDFRONT, REGIONAL
  id: "EntityId", # required
  description: "EntityDescription",
  regular_expression_list: [ # required
    {
      regex_string: "RegexPatternString",
    },
  ],
  lock_token: "LockToken", # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the set that helps with identification.

Returns:

  • (String)


12178
12179
12180
12181
12182
12183
12184
12185
12186
12187
# File 'lib/aws-sdk-wafv2/types.rb', line 12178

class UpdateRegexPatternSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :description,
  :regular_expression_list,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end

#idString

A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.

Returns:

  • (String)


12178
12179
12180
12181
12182
12183
12184
12185
12186
12187
# File 'lib/aws-sdk-wafv2/types.rb', line 12178

class UpdateRegexPatternSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :description,
  :regular_expression_list,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end

#lock_tokenString

A token used for optimistic locking. WAF returns a token to your `get` and `list` requests, to mark the state of the entity at the time of the request. To make changes to the entity associated with the token, you provide the token to operations like `update` and `delete`. WAF uses the token to ensure that no changes have been made to the entity since you last retrieved it. If a change has been made, the update fails with a `WAFOptimisticLockException`. If this happens, perform another `get`, and use the new token returned by that operation.

Returns:

  • (String)


12178
12179
12180
12181
12182
12183
12184
12185
12186
12187
# File 'lib/aws-sdk-wafv2/types.rb', line 12178

class UpdateRegexPatternSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :description,
  :regular_expression_list,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the set. You cannot change the name after you create the set.

Returns:

  • (String)


12178
12179
12180
12181
12182
12183
12184
12185
12186
12187
# File 'lib/aws-sdk-wafv2/types.rb', line 12178

class UpdateRegexPatternSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :description,
  :regular_expression_list,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end

#regular_expression_listArray<Types::Regex>

Returns:



12178
12179
12180
12181
12182
12183
12184
12185
12186
12187
# File 'lib/aws-sdk-wafv2/types.rb', line 12178

class UpdateRegexPatternSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :description,
  :regular_expression_list,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end

#scopeString

Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.

To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:

  • CLI - Specify the Region when you use the CloudFront scope: `–scope=CLOUDFRONT –region=us-east-1`.

  • API and SDKs - For all calls, use the Region endpoint us-east-1.

Returns:

  • (String)


12178
12179
12180
12181
12182
12183
12184
12185
12186
12187
# File 'lib/aws-sdk-wafv2/types.rb', line 12178

class UpdateRegexPatternSetRequest < Struct.new(
  :name,
  :scope,
  :id,
  :description,
  :regular_expression_list,
  :lock_token)
  SENSITIVE = []
  include Aws::Structure
end