Class: Aws::WAFV2::Types::UriPath Private
- Inherits:
-
EmptyStructure
- Object
- EmptyStructure
- Aws::WAFV2::Types::UriPath
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
The path component of the URI of a web request. This is the part of a web request that identifies a resource. For example, `/images/daily-ad.jpg`.
This is used only to indicate the web request component for WAF to inspect, in the FieldToMatch specification.
JSON specification: `“UriPath”: {}`