Class: Aws::WAFV2::Types::VersionToPublish

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass VersionToPublish data as a hash:

{
  associated_rule_group_arn: "ResourceArn",
  forecasted_lifetime: 1,
}

A version of the named managed rule group, that the rule group's vendor publishes for use by customers.

<note markdown=“1”> This is intended for use only by vendors of managed rule sets. Vendors are Amazon Web Services and Amazon Web Services Marketplace sellers.

Vendors, you can use the managed rule set APIs to provide controlled

rollout of your versioned managed rule group offerings for your customers. The APIs are `ListManagedRuleSets`, `GetManagedRuleSet`, `PutManagedRuleSetVersions`, and `UpdateManagedRuleSetVersionExpiryDate`.

</note>

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#associated_rule_group_arnString

The Amazon Resource Name (ARN) of the vendor's rule group that's used in the published managed rule group version.

Returns:

  • (String)


16108
16109
16110
16111
16112
16113
# File 'lib/aws-sdk-wafv2/types.rb', line 16108

class VersionToPublish < Struct.new(
  :associated_rule_group_arn,
  :forecasted_lifetime)
  SENSITIVE = []
  include Aws::Structure
end

#forecasted_lifetimeInteger

The amount of time the vendor expects this version of the managed rule group to last, in days.

Returns:

  • (Integer)


16108
16109
16110
16111
16112
16113
# File 'lib/aws-sdk-wafv2/types.rb', line 16108

class VersionToPublish < Struct.new(
  :associated_rule_group_arn,
  :forecasted_lifetime)
  SENSITIVE = []
  include Aws::Structure
end