Class: Aws::WAFV2::Types::VisibilityConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::VisibilityConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Defines and enables Amazon CloudWatch metrics and web request sample collection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_watch_metrics_enabled ⇒ Boolean
A boolean indicating whether the associated resource sends metrics to Amazon CloudWatch.
-
#metric_name ⇒ String
A name of the Amazon CloudWatch metric dimension.
-
#sampled_requests_enabled ⇒ Boolean
A boolean indicating whether WAF should store a sampling of the web requests that match the rules.
Instance Attribute Details
#cloud_watch_metrics_enabled ⇒ Boolean
A boolean indicating whether the associated resource sends metrics to Amazon CloudWatch. For the list of available metrics, see [WAF Metrics] in the *WAF Developer Guide*.
For web ACLs, the metrics are for web requests that have the web ACL default action applied. WAF applies the default action to web requests that pass the inspection of all rules in the web ACL without being either allowed or blocked. For more information, see
- The web ACL default action][2
-
in the *WAF Developer Guide*.
[1]: docs.aws.amazon.com/waf/latest/developerguide/monitoring-cloudwatch.html#waf-metrics [2]: docs.aws.amazon.com/waf/latest/developerguide/web-acl-default-action.html
8434 8435 8436 8437 8438 8439 8440 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8434 class VisibilityConfig < Struct.new( :sampled_requests_enabled, :cloud_watch_metrics_enabled, :metric_name) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
A name of the Amazon CloudWatch metric dimension. The name can contain only the characters: A-Z, a-z, 0-9, - (hyphen), and _ (underscore). The name can be from one to 128 characters long. It can’t contain whitespace or metric names that are reserved for WAF, for example ‘All` and `Default_Action`.
8434 8435 8436 8437 8438 8439 8440 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8434 class VisibilityConfig < Struct.new( :sampled_requests_enabled, :cloud_watch_metrics_enabled, :metric_name) SENSITIVE = [] include Aws::Structure end |
#sampled_requests_enabled ⇒ Boolean
A boolean indicating whether WAF should store a sampling of the web requests that match the rules. You can view the sampled requests through the WAF console.
8434 8435 8436 8437 8438 8439 8440 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8434 class VisibilityConfig < Struct.new( :sampled_requests_enabled, :cloud_watch_metrics_enabled, :metric_name) SENSITIVE = [] include Aws::Structure end |