Class: Aws::WAFV2::Types::VisibilityConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::VisibilityConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Defines and enables Amazon CloudWatch metrics and web request sample collection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_watch_metrics_enabled ⇒ Boolean
A boolean indicating whether the associated resource sends metrics to Amazon CloudWatch.
-
#metric_name ⇒ String
A name of the Amazon CloudWatch metric dimension.
-
#sampled_requests_enabled ⇒ Boolean
A boolean indicating whether WAF should store a sampling of the web requests that match the rules.
Instance Attribute Details
#cloud_watch_metrics_enabled ⇒ Boolean
A boolean indicating whether the associated resource sends metrics to Amazon CloudWatch. For the list of available metrics, see [WAF Metrics] in the *WAF Developer Guide*.
[1]: docs.aws.amazon.com/waf/latest/developerguide/monitoring-cloudwatch.html#waf-metrics
7884 7885 7886 7887 7888 7889 7890 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7884 class VisibilityConfig < Struct.new( :sampled_requests_enabled, :cloud_watch_metrics_enabled, :metric_name) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
A name of the Amazon CloudWatch metric dimension. The name can contain only the characters: A-Z, a-z, 0-9, - (hyphen), and _ (underscore). The name can be from one to 128 characters long. It can’t contain whitespace or metric names that are reserved for WAF, for example ‘All` and `Default_Action`.
7884 7885 7886 7887 7888 7889 7890 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7884 class VisibilityConfig < Struct.new( :sampled_requests_enabled, :cloud_watch_metrics_enabled, :metric_name) SENSITIVE = [] include Aws::Structure end |
#sampled_requests_enabled ⇒ Boolean
A boolean indicating whether WAF should store a sampling of the web requests that match the rules. You can view the sampled requests through the WAF console.
7884 7885 7886 7887 7888 7889 7890 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7884 class VisibilityConfig < Struct.new( :sampled_requests_enabled, :cloud_watch_metrics_enabled, :metric_name) SENSITIVE = [] include Aws::Structure end |