Class: Aws::WAFV2::Types::VisibilityConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::VisibilityConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
Defines and enables Amazon CloudWatch metrics and web request sample collection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_watch_metrics_enabled ⇒ Boolean
A boolean indicating whether the associated resource sends metrics to Amazon CloudWatch.
-
#metric_name ⇒ String
A name of the Amazon CloudWatch metric.
-
#sampled_requests_enabled ⇒ Boolean
A boolean indicating whether WAF should store a sampling of the web requests that match the rules.
Instance Attribute Details
#cloud_watch_metrics_enabled ⇒ Boolean
A boolean indicating whether the associated resource sends metrics to Amazon CloudWatch. For the list of available metrics, see [WAF Metrics].
[1]: docs.aws.amazon.com/waf/latest/developerguide/monitoring-cloudwatch.html#waf-metrics
7096 7097 7098 7099 7100 7101 7102 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7096 class VisibilityConfig < Struct.new( :sampled_requests_enabled, :cloud_watch_metrics_enabled, :metric_name) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
A name of the Amazon CloudWatch metric. The name can contain only the characters: A-Z, a-z, 0-9, - (hyphen), and _ (underscore). The name can be from one to 128 characters long. It can't contain whitespace or metric names reserved for WAF, for example `All` and `Default_Action`.
7096 7097 7098 7099 7100 7101 7102 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7096 class VisibilityConfig < Struct.new( :sampled_requests_enabled, :cloud_watch_metrics_enabled, :metric_name) SENSITIVE = [] include Aws::Structure end |
#sampled_requests_enabled ⇒ Boolean
A boolean indicating whether WAF should store a sampling of the web requests that match the rules. You can view the sampled requests through the WAF console.
7096 7097 7098 7099 7100 7101 7102 |
# File 'lib/aws-sdk-wafv2/types.rb', line 7096 class VisibilityConfig < Struct.new( :sampled_requests_enabled, :cloud_watch_metrics_enabled, :metric_name) SENSITIVE = [] include Aws::Structure end |