Class: Aws::WAFV2::Types::VisibilityConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass VisibilityConfig data as a hash:

{
  sampled_requests_enabled: false, # required
  cloud_watch_metrics_enabled: false, # required
  metric_name: "MetricName", # required
}

Defines and enables Amazon CloudWatch metrics and web request sample collection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_watch_metrics_enabledBoolean

A boolean indicating whether the associated resource sends metrics to Amazon CloudWatch. For the list of available metrics, see [WAF Metrics].

[1]: docs.aws.amazon.com/waf/latest/developerguide/monitoring-cloudwatch.html#waf-metrics

Returns:

  • (Boolean)


16197
16198
16199
16200
16201
16202
16203
# File 'lib/aws-sdk-wafv2/types.rb', line 16197

class VisibilityConfig < Struct.new(
  :sampled_requests_enabled,
  :cloud_watch_metrics_enabled,
  :metric_name)
  SENSITIVE = []
  include Aws::Structure
end

#metric_nameString

A name of the Amazon CloudWatch metric. The name can contain only the characters: A-Z, a-z, 0-9, - (hyphen), and _ (underscore). The name can be from one to 128 characters long. It can't contain whitespace or metric names reserved for WAF, for example `All` and `Default_Action`.

Returns:

  • (String)


16197
16198
16199
16200
16201
16202
16203
# File 'lib/aws-sdk-wafv2/types.rb', line 16197

class VisibilityConfig < Struct.new(
  :sampled_requests_enabled,
  :cloud_watch_metrics_enabled,
  :metric_name)
  SENSITIVE = []
  include Aws::Structure
end

#sampled_requests_enabledBoolean

A boolean indicating whether WAF should store a sampling of the web requests that match the rules. You can view the sampled requests through the WAF console.

Returns:

  • (Boolean)


16197
16198
16199
16200
16201
16202
16203
# File 'lib/aws-sdk-wafv2/types.rb', line 16197

class VisibilityConfig < Struct.new(
  :sampled_requests_enabled,
  :cloud_watch_metrics_enabled,
  :metric_name)
  SENSITIVE = []
  include Aws::Structure
end