Class: Aws::WAFV2::Types::WAFAssociatedItemException
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::WAFAssociatedItemException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
WAF couldn’t perform the operation because your resource is being used by another resource or it’s associated with another resource.
For `DeleteWebACL`, you will only get this exception if the web ACL is still associated with a regional resource. Deleting a web ACL that is still associated with an Amazon CloudFront distribution won't get this exception.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
16147 16148 16149 16150 16151 |
# File 'lib/aws-sdk-wafv2/types.rb', line 16147 class WAFAssociatedItemException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |