Class: Aws::WAFV2::Types::WAFExpiredManagedRuleGroupVersionException
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::WAFExpiredManagedRuleGroupVersionException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
The operation failed because the specified version for the managed rule group has expired. You can retrieve the available versions for the managed rule group by calling ListAvailableManagedRuleGroupVersions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
8447 8448 8449 8450 8451 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8447 class WAFExpiredManagedRuleGroupVersionException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |