Class: Aws::WAFV2::Types::WAFExpiredManagedRuleGroupVersionException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

The operation failed because the specified version for the managed rule group has expired. You can retrieve the available versions for the managed rule group by calling ListAvailableManagedRuleGroupVersions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


16268
16269
16270
16271
16272
# File 'lib/aws-sdk-wafv2/types.rb', line 16268

class WAFExpiredManagedRuleGroupVersionException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end