Class: Aws::WAFV2::Types::WAFLimitsExceededException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

WAF couldn’t perform the operation because you exceeded your resource limit. For example, the maximum number of WebACL objects that you can create for an Amazon Web Services account. For more information, see WAF quotas in the WAF Developer Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


11622
11623
11624
11625
11626
11627
# File 'lib/aws-sdk-wafv2/types.rb', line 11622

class WAFLimitsExceededException < Struct.new(
  :message,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end

#source_typeString

Source type for the exception.

Returns:

  • (String)


11622
11623
11624
11625
11626
11627
# File 'lib/aws-sdk-wafv2/types.rb', line 11622

class WAFLimitsExceededException < Struct.new(
  :message,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end