Class: Aws::WAFV2::Types::WAFOptimisticLockException
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::WAFOptimisticLockException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
WAF couldn’t save your changes because you tried to update or delete a resource that has changed since you last retrieved it. Get the resource again, make any changes you need to make to the new copy, and retry your operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
9399 9400 9401 9402 9403 |
# File 'lib/aws-sdk-wafv2/types.rb', line 9399 class WAFOptimisticLockException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |