Class: Aws::WAFV2::Types::WAFOptimisticLockException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

WAF couldn’t save your changes because you tried to update or delete a resource that has changed since you last retrieved it. Get the resource again, make any changes you need to make to the new copy, and retry your operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


8848
8849
8850
8851
8852
# File 'lib/aws-sdk-wafv2/types.rb', line 8848

class WAFOptimisticLockException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end