Class: Aws::WAFV2::Types::WAFUnavailableEntityException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

WAF couldn’t retrieve a resource that you specified for this operation. Verify the resources that you are specifying in your request parameters and then retry the operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


16442
16443
16444
16445
16446
# File 'lib/aws-sdk-wafv2/types.rb', line 16442

class WAFUnavailableEntityException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end