Class: Aws::WAFV2::Types::WebACL
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::WebACL
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
A web ACL defines a collection of rules to use to inspect and control web requests. Each rule has an action defined (allow, block, or count) for requests that match the statement of the rule. In the web ACL, you assign a default action to take (allow, block) for any request that does not match any of the rules. The rules in a web ACL can be a combination of the types Rule, RuleGroup, and managed rule group. You can associate a web ACL with one or more Amazon Web Services resources to protect. The resources can be an Amazon CloudFront distribution, an Amazon API Gateway REST API, an Application Load Balancer, an AppSync GraphQL API, or an Amazon Cognito user pool.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the web ACL that you want to associate with the resource.
-
#capacity ⇒ Integer
The web ACL capacity units (WCUs) currently being used by this web ACL.
-
#captcha_config ⇒ Types::CaptchaConfig
Specifies how WAF should handle `CAPTCHA` evaluations for rules that don't have their own `CaptchaConfig` settings.
-
#challenge_config ⇒ Types::ChallengeConfig
Specifies how WAF should handle challenge evaluations for rules that don't have their own `ChallengeConfig` settings.
-
#custom_response_bodies ⇒ Hash<String,Types::CustomResponseBody>
A map of custom response keys and content bodies.
-
#default_action ⇒ Types::DefaultAction
The action to perform if none of the `Rules` contained in the `WebACL` match.
-
#description ⇒ String
A description of the web ACL that helps with identification.
-
#id ⇒ String
A unique identifier for the `WebACL`.
-
#label_namespace ⇒ String
The label namespace prefix for this web ACL.
-
#managed_by_firewall_manager ⇒ Boolean
Indicates whether this web ACL is managed by Firewall Manager.
-
#name ⇒ String
The name of the web ACL.
-
#post_process_firewall_manager_rule_groups ⇒ Array<Types::FirewallManagerRuleGroup>
The last set of rules for WAF to process in the web ACL.
-
#pre_process_firewall_manager_rule_groups ⇒ Array<Types::FirewallManagerRuleGroup>
The first set of rules for WAF to process in the web ACL.
-
#rules ⇒ Array<Types::Rule>
The Rule statements used to identify the web requests that you want to allow, block, or count.
-
#token_domains ⇒ Array<String>
Specifies the domains that WAF should accept in a web request token.
-
#visibility_config ⇒ Types::VisibilityConfig
Defines and enables Amazon CloudWatch metrics and web request sample collection.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the web ACL that you want to associate with the resource.
19296 19297 19298 19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 19314 19315 |
# File 'lib/aws-sdk-wafv2/types.rb', line 19296 class WebACL < Struct.new( :name, :id, :arn, :default_action, :description, :rules, :visibility_config, :capacity, :pre_process_firewall_manager_rule_groups, :post_process_firewall_manager_rule_groups, :managed_by_firewall_manager, :label_namespace, :custom_response_bodies, :captcha_config, :challenge_config, :token_domains) SENSITIVE = [] include Aws::Structure end |
#capacity ⇒ Integer
The web ACL capacity units (WCUs) currently being used by this web ACL.
WAF uses WCUs to calculate and control the operating resources that are used to run your rules, rule groups, and web ACLs. WAF calculates capacity differently for each rule type, to reflect the relative cost of each rule. Simple rules that cost little to run use fewer WCUs than more complex rules that use more processing power. Rule group capacity is fixed at creation, which helps users plan their web ACL WCU usage when they use a rule group. The WCU limit for web ACLs is 1,500.
19296 19297 19298 19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 19314 19315 |
# File 'lib/aws-sdk-wafv2/types.rb', line 19296 class WebACL < Struct.new( :name, :id, :arn, :default_action, :description, :rules, :visibility_config, :capacity, :pre_process_firewall_manager_rule_groups, :post_process_firewall_manager_rule_groups, :managed_by_firewall_manager, :label_namespace, :custom_response_bodies, :captcha_config, :challenge_config, :token_domains) SENSITIVE = [] include Aws::Structure end |
#captcha_config ⇒ Types::CaptchaConfig
Specifies how WAF should handle `CAPTCHA` evaluations for rules that don't have their own `CaptchaConfig` settings. If you don't specify this, WAF uses its default settings for `CaptchaConfig`.
19296 19297 19298 19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 19314 19315 |
# File 'lib/aws-sdk-wafv2/types.rb', line 19296 class WebACL < Struct.new( :name, :id, :arn, :default_action, :description, :rules, :visibility_config, :capacity, :pre_process_firewall_manager_rule_groups, :post_process_firewall_manager_rule_groups, :managed_by_firewall_manager, :label_namespace, :custom_response_bodies, :captcha_config, :challenge_config, :token_domains) SENSITIVE = [] include Aws::Structure end |
#challenge_config ⇒ Types::ChallengeConfig
Specifies how WAF should handle challenge evaluations for rules that don't have their own `ChallengeConfig` settings. If you don't specify this, WAF uses its default settings for `ChallengeConfig`.
19296 19297 19298 19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 19314 19315 |
# File 'lib/aws-sdk-wafv2/types.rb', line 19296 class WebACL < Struct.new( :name, :id, :arn, :default_action, :description, :rules, :visibility_config, :capacity, :pre_process_firewall_manager_rule_groups, :post_process_firewall_manager_rule_groups, :managed_by_firewall_manager, :label_namespace, :custom_response_bodies, :captcha_config, :challenge_config, :token_domains) SENSITIVE = [] include Aws::Structure end |
#custom_response_bodies ⇒ Hash<String,Types::CustomResponseBody>
A map of custom response keys and content bodies. When you create a rule with a block action, you can send a custom response to the web request. You define these for the web ACL, and then use them in the rules and default actions that you define in the web ACL.
For information about customizing web requests and responses, see
- Customizing web requests and responses in WAF][1
-
in the [WAF
Developer Guide].
For information about the limits on count and size for custom request and response settings, see [WAF quotas] in the [WAF Developer Guide].
[1]: docs.aws.amazon.com/waf/latest/developerguide/waf-custom-request-response.html [2]: docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html [3]: docs.aws.amazon.com/waf/latest/developerguide/limits.html
19296 19297 19298 19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 19314 19315 |
# File 'lib/aws-sdk-wafv2/types.rb', line 19296 class WebACL < Struct.new( :name, :id, :arn, :default_action, :description, :rules, :visibility_config, :capacity, :pre_process_firewall_manager_rule_groups, :post_process_firewall_manager_rule_groups, :managed_by_firewall_manager, :label_namespace, :custom_response_bodies, :captcha_config, :challenge_config, :token_domains) SENSITIVE = [] include Aws::Structure end |
#default_action ⇒ Types::DefaultAction
The action to perform if none of the `Rules` contained in the `WebACL` match.
19296 19297 19298 19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 19314 19315 |
# File 'lib/aws-sdk-wafv2/types.rb', line 19296 class WebACL < Struct.new( :name, :id, :arn, :default_action, :description, :rules, :visibility_config, :capacity, :pre_process_firewall_manager_rule_groups, :post_process_firewall_manager_rule_groups, :managed_by_firewall_manager, :label_namespace, :custom_response_bodies, :captcha_config, :challenge_config, :token_domains) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the web ACL that helps with identification.
19296 19297 19298 19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 19314 19315 |
# File 'lib/aws-sdk-wafv2/types.rb', line 19296 class WebACL < Struct.new( :name, :id, :arn, :default_action, :description, :rules, :visibility_config, :capacity, :pre_process_firewall_manager_rule_groups, :post_process_firewall_manager_rule_groups, :managed_by_firewall_manager, :label_namespace, :custom_response_bodies, :captcha_config, :challenge_config, :token_domains) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A unique identifier for the `WebACL`. This ID is returned in the responses to create and list commands. You use this ID to do things like get, update, and delete a `WebACL`.
19296 19297 19298 19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 19314 19315 |
# File 'lib/aws-sdk-wafv2/types.rb', line 19296 class WebACL < Struct.new( :name, :id, :arn, :default_action, :description, :rules, :visibility_config, :capacity, :pre_process_firewall_manager_rule_groups, :post_process_firewall_manager_rule_groups, :managed_by_firewall_manager, :label_namespace, :custom_response_bodies, :captcha_config, :challenge_config, :token_domains) SENSITIVE = [] include Aws::Structure end |
#label_namespace ⇒ String
The label namespace prefix for this web ACL. All labels added by rules in this web ACL have this prefix.
-
The syntax for the label namespace prefix for a web ACL is the following:
`awswaf:<account ID>:webacl:<web ACL name>:`
-
When a rule with a label matches a web request, WAF adds the fully qualified label to the request. A fully qualified label is made up of the label namespace from the rule group or web ACL where the rule is defined and the label from the rule, separated by a colon:
`<label namespace>:<label from rule>`
19296 19297 19298 19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 19314 19315 |
# File 'lib/aws-sdk-wafv2/types.rb', line 19296 class WebACL < Struct.new( :name, :id, :arn, :default_action, :description, :rules, :visibility_config, :capacity, :pre_process_firewall_manager_rule_groups, :post_process_firewall_manager_rule_groups, :managed_by_firewall_manager, :label_namespace, :custom_response_bodies, :captcha_config, :challenge_config, :token_domains) SENSITIVE = [] include Aws::Structure end |
#managed_by_firewall_manager ⇒ Boolean
Indicates whether this web ACL is managed by Firewall Manager. If true, then only Firewall Manager can delete the web ACL or any Firewall Manager rule groups in the web ACL.
19296 19297 19298 19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 19314 19315 |
# File 'lib/aws-sdk-wafv2/types.rb', line 19296 class WebACL < Struct.new( :name, :id, :arn, :default_action, :description, :rules, :visibility_config, :capacity, :pre_process_firewall_manager_rule_groups, :post_process_firewall_manager_rule_groups, :managed_by_firewall_manager, :label_namespace, :custom_response_bodies, :captcha_config, :challenge_config, :token_domains) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the web ACL. You cannot change the name of a web ACL after you create it.
19296 19297 19298 19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 19314 19315 |
# File 'lib/aws-sdk-wafv2/types.rb', line 19296 class WebACL < Struct.new( :name, :id, :arn, :default_action, :description, :rules, :visibility_config, :capacity, :pre_process_firewall_manager_rule_groups, :post_process_firewall_manager_rule_groups, :managed_by_firewall_manager, :label_namespace, :custom_response_bodies, :captcha_config, :challenge_config, :token_domains) SENSITIVE = [] include Aws::Structure end |
#post_process_firewall_manager_rule_groups ⇒ Array<Types::FirewallManagerRuleGroup>
The last set of rules for WAF to process in the web ACL. This is defined in an Firewall Manager WAF policy and contains only rule group references. You can't alter these. Any rules and rule groups that you define for the web ACL are prioritized before these.
In the Firewall Manager WAF policy, the Firewall Manager administrator can define a set of rule groups to run first in the web ACL and a set of rule groups to run last. Within each set, the administrator prioritizes the rule groups, to determine their relative processing order.
19296 19297 19298 19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 19314 19315 |
# File 'lib/aws-sdk-wafv2/types.rb', line 19296 class WebACL < Struct.new( :name, :id, :arn, :default_action, :description, :rules, :visibility_config, :capacity, :pre_process_firewall_manager_rule_groups, :post_process_firewall_manager_rule_groups, :managed_by_firewall_manager, :label_namespace, :custom_response_bodies, :captcha_config, :challenge_config, :token_domains) SENSITIVE = [] include Aws::Structure end |
#pre_process_firewall_manager_rule_groups ⇒ Array<Types::FirewallManagerRuleGroup>
The first set of rules for WAF to process in the web ACL. This is defined in an Firewall Manager WAF policy and contains only rule group references. You can't alter these. Any rules and rule groups that you define for the web ACL are prioritized after these.
In the Firewall Manager WAF policy, the Firewall Manager administrator can define a set of rule groups to run first in the web ACL and a set of rule groups to run last. Within each set, the administrator prioritizes the rule groups, to determine their relative processing order.
19296 19297 19298 19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 19314 19315 |
# File 'lib/aws-sdk-wafv2/types.rb', line 19296 class WebACL < Struct.new( :name, :id, :arn, :default_action, :description, :rules, :visibility_config, :capacity, :pre_process_firewall_manager_rule_groups, :post_process_firewall_manager_rule_groups, :managed_by_firewall_manager, :label_namespace, :custom_response_bodies, :captcha_config, :challenge_config, :token_domains) SENSITIVE = [] include Aws::Structure end |
#rules ⇒ Array<Types::Rule>
The Rule statements used to identify the web requests that you want to allow, block, or count. Each rule includes one top-level statement that WAF uses to identify matching web requests, and parameters that govern how WAF handles them.
19296 19297 19298 19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 19314 19315 |
# File 'lib/aws-sdk-wafv2/types.rb', line 19296 class WebACL < Struct.new( :name, :id, :arn, :default_action, :description, :rules, :visibility_config, :capacity, :pre_process_firewall_manager_rule_groups, :post_process_firewall_manager_rule_groups, :managed_by_firewall_manager, :label_namespace, :custom_response_bodies, :captcha_config, :challenge_config, :token_domains) SENSITIVE = [] include Aws::Structure end |
#token_domains ⇒ Array<String>
Specifies the domains that WAF should accept in a web request token. This enables the use of tokens across multiple protected websites. When WAF provides a token, it uses the domain of the Amazon Web Services resource that the web ACL is protecting. If you don't specify a list of token domains, WAF accepts tokens only for the domain of the protected resource. With a token domain list, WAF accepts the resource's host domain plus all domains in the token domain list, including their prefixed subdomains.
19296 19297 19298 19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 19314 19315 |
# File 'lib/aws-sdk-wafv2/types.rb', line 19296 class WebACL < Struct.new( :name, :id, :arn, :default_action, :description, :rules, :visibility_config, :capacity, :pre_process_firewall_manager_rule_groups, :post_process_firewall_manager_rule_groups, :managed_by_firewall_manager, :label_namespace, :custom_response_bodies, :captcha_config, :challenge_config, :token_domains) SENSITIVE = [] include Aws::Structure end |
#visibility_config ⇒ Types::VisibilityConfig
Defines and enables Amazon CloudWatch metrics and web request sample collection.
19296 19297 19298 19299 19300 19301 19302 19303 19304 19305 19306 19307 19308 19309 19310 19311 19312 19313 19314 19315 |
# File 'lib/aws-sdk-wafv2/types.rb', line 19296 class WebACL < Struct.new( :name, :id, :arn, :default_action, :description, :rules, :visibility_config, :capacity, :pre_process_firewall_manager_rule_groups, :post_process_firewall_manager_rule_groups, :managed_by_firewall_manager, :label_namespace, :custom_response_bodies, :captcha_config, :challenge_config, :token_domains) SENSITIVE = [] include Aws::Structure end |