Class: Aws::WAFV2::Types::XssMatchStatement
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFV2::Types::XssMatchStatement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafv2/types.rb
Overview
A rule statement that inspects for cross-site scripting (XSS) attacks. In XSS attacks, the attacker uses vulnerabilities in a benign website as a vehicle to inject malicious client-site scripts into other legitimate web browsers.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_to_match ⇒ Types::FieldToMatch
The part of the web request that you want WAF to inspect.
-
#text_transformations ⇒ Array<Types::TextTransformation>
Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection.
Instance Attribute Details
#field_to_match ⇒ Types::FieldToMatch
The part of the web request that you want WAF to inspect.
8505 8506 8507 8508 8509 8510 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8505 class XssMatchStatement < Struct.new( :field_to_match, :text_transformations) SENSITIVE = [] include Aws::Structure end |
#text_transformations ⇒ Array<Types::TextTransformation>
Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, WAF performs all transformations on the content of the request component identified by ‘FieldToMatch`, starting from the lowest priority setting, before inspecting the content for a match.
8505 8506 8507 8508 8509 8510 |
# File 'lib/aws-sdk-wafv2/types.rb', line 8505 class XssMatchStatement < Struct.new( :field_to_match, :text_transformations) SENSITIVE = [] include Aws::Structure end |