Class: Aws::WAFV2::Types::XssMatchStatement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafv2/types.rb

Overview

Note:

When making an API call, you may pass XssMatchStatement data as a hash:

{
  field_to_match: { # required
    single_header: {
      name: "FieldToMatchData", # required
    },
    single_query_argument: {
      name: "FieldToMatchData", # required
    },
    all_query_arguments: {
    },
    uri_path: {
    },
    query_string: {
    },
    body: {
    },
    method: {
    },
    json_body: {
      match_pattern: { # required
        all: {
        },
        included_paths: ["JsonPointerPath"],
      },
      match_scope: "ALL", # required, accepts ALL, KEY, VALUE
      invalid_fallback_behavior: "MATCH", # accepts MATCH, NO_MATCH, EVALUATE_AS_STRING
    },
  },
  text_transformations: [ # required
    {
      priority: 1, # required
      type: "NONE", # required, accepts NONE, COMPRESS_WHITE_SPACE, HTML_ENTITY_DECODE, LOWERCASE, CMD_LINE, URL_DECODE, BASE64_DECODE, HEX_DECODE, MD5, REPLACE_COMMENTS, ESCAPE_SEQ_DECODE, SQL_HEX_DECODE, CSS_DECODE, JS_DECODE, NORMALIZE_PATH, NORMALIZE_PATH_WIN, REMOVE_NULLS, REPLACE_NULLS, BASE64_DECODE_EXT, URL_DECODE_UNI, UTF8_TO_UNICODE
    },
  ],
}

A rule statement that defines a cross-site scripting (XSS) match search for WAF to apply to web requests. XSS attacks are those where the attacker uses vulnerabilities in a benign website as a vehicle to inject malicious client-site scripts into other legitimate web browsers. The XSS match statement provides the location in requests that you want WAF to search and text transformations to use on the search area before WAF searches for character sequences that are likely to be malicious strings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#field_to_matchTypes::FieldToMatch

The part of a web request that you want WAF to inspect. For more information, see FieldToMatch.

Returns:



13957
13958
13959
13960
13961
13962
# File 'lib/aws-sdk-wafv2/types.rb', line 13957

class XssMatchStatement < Struct.new(
  :field_to_match,
  :text_transformations)
  SENSITIVE = []
  include Aws::Structure
end

#text_transformationsArray<Types::TextTransformation>

Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, WAF performs all transformations on the content of the request component identified by `FieldToMatch`, starting from the lowest priority setting, before inspecting the content for a match.

Returns:



13957
13958
13959
13960
13961
13962
# File 'lib/aws-sdk-wafv2/types.rb', line 13957

class XssMatchStatement < Struct.new(
  :field_to_match,
  :text_transformations)
  SENSITIVE = []
  include Aws::Structure
end